from os.path import join
from dotenv import load_dotenv
import logging
import os
import sys

load_dotenv()

HOME = os.path.expanduser('~')

YEEDU_HIDDEN_DIR = join(HOME, '.yeedu')

DEFAULT_CLI_LOG_PATH = join(join(YEEDU_HIDDEN_DIR, 'cli'), 'logs')

if os.getenv('YEEDU_RESTAPI_TOKEN_FILE_PATH') is not None:

    if os.path.isdir(os.getenv('YEEDU_RESTAPI_TOKEN_FILE_PATH')):
        logging.error(
            f"Provided environment variable: 'YEEDU_RESTAPI_TOKEN_FILE_PATH: {os.getenv('YEEDU_RESTAPI_TOKEN_FILE_PATH')}' doesnot contain filename or directory not found.")
        sys.exit(-1)
    else:
        CONFIG_FILE_PATH = os.getenv('YEEDU_RESTAPI_TOKEN_FILE_PATH')
else:
    CONFIG_FILE_PATH = join(YEEDU_HIDDEN_DIR, 'yeedu_cli.config')


CREDENTIALS_FILE_PATH = join(YEEDU_HIDDEN_DIR, 'yeedu_credentials.config')

# CLOUD PROVIDERS
CLOUD_PROVIDERS_LIST = ['GCP', 'AWS', 'AZURE']

# COMPUTE TYPES
COMPUTE_TYPES_LIST = ['compute_optimized', 'memory_optimized',
                      'general_purpose', 'storage_optimized', 'gpu_accelerated']

# CLUSTER TYPEs
CLUSTER_TYPE_LIST = ['YEEDU', 'STANDALONE', 'CLUSTER']

NOTEBOOK_LANGUAGE_LIST = ['python3', 'scala']

# JOB TYPE lang
JOB_TYPE_LIST = ['Raw Scala', 'Jar', 'Python3', 'SQL']

# SPARK JOB STATUS
SPARK_JOB_STATUS = ['submitted', 'running', 'done',
                    'error', 'terminated', 'stopping', 'stopped']

# RESOURCE SUBCOMMANDS LIST
RESOURCE_LIST = ['list-providers', 'list-disk-machine-types', 'list-credential-types', 'list-engine-cluster-instance-status', 'get-provider', 'list-provider-availability-zones', 'get-provider-availability-zone', 'list-provider-machine-types', 'get-provider-machine-type', 'list-spark-compute-types', 'list-spark-infra-versions', 'list-spark-job-status', 'list-workflow-execution-states', 'list-workflow-types', 'create-volume-conf', 'get-volume-conf', 'list-volume-confs', 'search-volume-confs', 'edit-volume-conf', 'delete-volume-conf', 'create-network-conf', 'list-network-confs', 'search-network-confs', 'get-network-conf', 'edit-network-conf', 'delete-network-conf', 'create-boot-disk-image-conf', 'list-boot-disk-image-confs', 'search-boot-disk-image-confs', 'get-boot-disk-image-conf', 'edit-boot-disk-image-conf', 'delete-boot-disk-image-conf',
                 'create-cloud-env', 'list-cloud-envs', 'search-cloud-envs', 'get-cloud-env', 'edit-cloud-env', 'delete-cloud-env', 'create-object-storage-manager', 'get-object-storage-manager', 'list-object-storage-managers', 'search-object-storage-managers', 'edit-object-storage-manager', 'delete-object-storage-manager', 'create-object-storage-manager-file', 'get-object-storage-manager-file', 'list-object-storage-manager-files', 'search-object-storage-manager-files', 'delete-object-storage-manager-file', 'create-hive-metastore-conf', 'list-hive-metastore-confs', 'search-hive-metastore-confs', 'get-hive-metastore-conf', 'edit-hive-metastore-conf', 'delete-hive-metastore-conf', 'create-credential-conf', 'list-credential-confs', 'search-credential-confs', 'get-credential-conf', 'edit-credential-conf', 'delete-credential-conf']

# CLUSTER SUBCOMMANDS LIST
CLUSTER_LIST = ['create-conf', 'list-confs', 'search-confs', 'get-conf', 'edit-conf', 'delete-conf', 'create', 'list', 'search', 'get', 'edit', 'destroy', 'start', 'stop', 'get-stats',
                'list-status', 'logs', 'associate-workspace', 'dissociate-workspace', 'list-workspaces', 'list-workspace-clusters', 'search-workspace-clusters', 'get-user-access', 'get-group-access']

# WORKSPACE SUBCOMMANDS LIST
WORKSPACE_LIST = ['create', 'list', 'search', 'get', 'edit', 'enable', 'disable', 'create-user-access', 'create-group-access', 'delete-user-access', 'delete-group-access',
                  'list-users', 'list-users-access', 'search-users', 'match-user', 'list-groups', 'list-groups-access', 'search-groups', 'match-group', 'get-user-access', 'get-group-access']

# JOB SUBCOMMANDS LIST
JOB_LIST = ['create-conf', 'get-conf', 'list-confs', 'search-confs', 'edit-conf', 'enable-conf',
            'disable-conf', 'start', 'get', 'search', 'list', 'stop', 'get-status', 'logs', 'get-workflow-job-instance']

# NOTEBOOK SUBCOMMANDS LIST
NOTEBOOK_LIST = ['create-conf', 'get-conf', 'list-confs', 'search-confs', 'edit-conf', 'enable-conf', 'disable-conf',
                 'start', 'kernel-start', 'kernel-interrupt', 'kernel-restart', 'get', 'search', 'list', 'stop', 'logs']

# IAM SUBCOMMANDS LIST
IAM_LIST = ['list-tenants', 'associate-tenant', 'get-user-info', 'get-user-roles', 'sync-user', 'sync-group', 'list-user-groups', 'list-users', 'list-group-users', 'list-groups', 'list-resources', 'get-resource',            'list-permissions',
            'get-permission', 'list-roles', 'get-role', 'list-rules', 'get-rule', 'search-users',  'match-user', 'search-groups', 'match-group', 'list-workspace-permissions', 'get-workspace-permission']

# ADMIN SUBCOMMANDS LIST
ADMIN_LIST = ['list-users', 'search-users', 'get-user', 'get-user-roles', 'list-users-roles', 'get-role-users', 'list-groups', 'search-groups',
              'get-group', 'get-group-roles', 'list-groups-roles', 'get-role-groups', 'create-user-role', 'delete-user-role', 'create-group-role', 'delete-group-role']

# PLATFORM ADMIN SUBCOMMANDS LIST
PLATFORM_ADMIN_LIST = ['create-tenant', 'list-tenants', 'get-tenant', 'edit-tenant', 'delete-tenant', 'list-tenant-users', 'search-tenant-users', 'list-tenant-groups', 'search-tenant-groups', 'get-tenant-user', 'get-tenant-group',
                       'get-user-roles', 'get-group-roles', 'list-user-tenants', 'get-role-users', 'list-users-roles', 'list-groups-roles', 'get-role-groups', 'create-user-role', 'delete-user-role', 'create-group-role', 'delete-group-role', 'search-tenants']

# COMMON PLATFORM AND ADMIN SUBCOMMANDS LIST
COMMON_PLATFORM_AND_ADMIN_LIST = ['list-users', 'get-user', 'get-user-roles', 'get-role-users', 'list-groups', 'get-group', 'get-group-roles', 'get-role-groups', 'create-user-role', 'delete-user-role',
                                  'create-group-role', 'delete-group-role' 'list-tenant-users', 'list-tenant-groups', 'get-tenant-user', 'get-tenant-group', 'get-user-roles', 'get-group-roles', 'get-role-users', 'get-role-groups']

# Columns list having data type as varchar array
VARCHAR_ARRAY_COLUMN_LIST = ['files', 'properties_file',
                             'packages', 'repositories', 'jars', 'archives']

VARCHAR_ARRAY_COLUMN_FULL_LIST = ['labels', 'conf', 'conf_secret', 'env_var', 'env_var_secret',
                                  'network_tags', 'files', 'properties_file', 'packages', 'repositories', 'jars', 'archives']

# Columns list having data type as json
# JSON_ARGUMENTS_LIST = []

# JSON Samples used in validateJSON
VALID_JSON = """'{"a":"b","c":1}'"""

INVALID_JSON = '''{"a":"b","c":1}'''

# TAG Samples used in network_tags_validator
VALID_NETWORK_TAG = 'key1,value1,key2,value2'

INVALID_NETWORK_TAG = 'key1,value1,key2'

CLOUD_PROVIDER_AVAILABILITY_ZONE_ORDER = [
    'availability_zone_id', 'cloud_provider', 'name', 'region', 'description', 'from_date', 'to_date']

CLOUD_PROVIDER_MACHINE_TYPE_ORDER = [
    'machine_type_id', 'cloud_provider', 'name', 'vcpus', 'memory', 'has_cuda', 'gpu_model', 'gpus', 'gpu_memory',  'from_date', 'to_date']

CLOUD_PROVIDER_DISK_MACHINE_TYPE_ORDER = ['disk_type_id', 'cloud_provider',
                                          'name', 'has_fixed_size', 'min_size', 'max_size', 'from_date', 'to_date']

VOLUME_CONFIG_ORDER = ['volume_conf_id', 'name', 'availability_zone', 'encrypted', 'size', 'disk_type', 'machine_volume_num',
                       'machine_volume_strip_num', 'tenant_id', 'created_by', 'modified_by', 'last_update_date', 'from_date', 'to_date']

OBJECT_STORAGE_MANAGER_FILES_ORDER = ['object_storage_manager_file_id', 'object_storage_manager', 'file_name', 'full_file_path',
                                      'file_size_bytes', 'file_type', 'local_file_path', 'tenant_id', 'created_by', 'modified_by', 'last_update_date', 'from_date', 'to_date']

CLUSTER_INSTANCE_USERS_ORDER = ['auth_engine_cluster_instance_user_id', 'engine_cluster_instance',
                                'engine_cluster_instance_perm', 'user', 'created_by', 'modified_by', 'last_update_date', 'from_date', 'to_date']

USER_ROLES_ORDER = ['user_roles_id', 'tenant',
                    'user', 'role', 'from_date', 'to_date']

ADMIN_GROUP_ORDER = ['group_id', 'group_name', 'from_date', 'to_date']

USER_GROUP_ORDER = ['group', 'user', 'from_date', 'to_date']

GROUP_ROLE_ORDER = ['group_roles_id', 'tenant',
                    'group', 'role', 'from_date', 'to_date']

LOOKUP_AUTH_RULES_ORDER = ['rule_id', 'permission_type',
                           'resource', 'role', 'from_date', 'to_date']

LOOKUP_CREDENTIAL_TYPES_ORDER = [
    'credential_type_id', 'name', 'cloud_provider', 'from_date', 'to_date']
