from argparse import SUPPRESS, ArgumentDefaultsHelpFormatter
from yeedu.utility.json_utils import check_boolean, check_non_empty_string


class ObjectStorageManagerFilesParser:

    def object_storage_manager_files_parser(subparser):
        create_object_storage_manager_files = subparser.add_parser(
            'create-object-storage-manager-file',
            help='To create a Object Storage Manager Files.',
            formatter_class=ArgumentDefaultsHelpFormatter)
        create_object_storage_manager_files.add_argument(
            "--object_storage_manager_id",
            type=int,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Id to create-object-storage-manager-file."
        )
        create_object_storage_manager_files.add_argument(
            "--object_storage_manager_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Name to to create-object-storage-manager-file."
        )
        create_object_storage_manager_files.add_argument(
            "--local_file_path",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            required=True,
            help="Provide local_file_path to create-object-storage-manager-file."
        )
        create_object_storage_manager_files.add_argument(
            "--cluster_id",
            type=int,
            nargs=1,
            default=SUPPRESS,
            help="Provide Cluster Instance Id [OPTIONAL] to check permissions before create-object-storage-manager-file."
        )
        create_object_storage_manager_files.add_argument(
            "--cluster_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            help="Provide Cluster Instance Name [OPTIONAL] to check permissions before create-object-storage-manager-file."
        )
        create_object_storage_manager_files.add_argument(
            "--overwrite",
            type=check_boolean,
            nargs='?',
            choices=['true', 'false'],
            default='false',
            help="Provide overwrite to create-object-storage-manager-file."
        )
        create_object_storage_manager_files.add_argument(
            "--json-output",
            type=check_non_empty_string,
            nargs='?',
            choices=['pretty', 'default'],
            default='pretty',
            help="Provide the format of JSON output."
        )
        create_object_storage_manager_files.add_argument(
            "--yaml-output",
            type=check_boolean,
            nargs='?',
            choices=['true', 'false'],
            default='false',
            help="Provide true to get output in YAML format."
        )

        list_object_storage_manager_files = subparser.add_parser(
            'list-object-storage-manager-files',
            help='To list all the available Object Storage Manager Files.',
            formatter_class=ArgumentDefaultsHelpFormatter)
        list_object_storage_manager_files.add_argument(
            "--object_storage_manager_id",
            type=int,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Id to list all the available Object Storage Manager Files."
        )
        list_object_storage_manager_files.add_argument(
            "--object_storage_manager_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Name to list all the available Object Storage Manager Files."
        )
        list_object_storage_manager_files.add_argument(
            "--page_number",
            type=int,
            nargs=1,
            default=1,
            help="To list Object Storage Manager Files for a specific page_number."
        )
        list_object_storage_manager_files.add_argument(
            "--limit",
            type=int,
            nargs=1,
            default=100,
            help="Provide limit to list number of Object Storage Manager Files."
        )
        list_object_storage_manager_files.add_argument(
            "--json-output",
            type=check_non_empty_string,
            nargs='?',
            choices=['pretty', 'default'],
            default='pretty',
            help="Provide the format of JSON output."
        )
        list_object_storage_manager_files.add_argument(
            "--yaml-output",
            type=check_boolean,
            nargs='?',
            choices=['true', 'false'],
            default='false',
            help="Provide true to get output in YAML format."
        )

        search_object_storage_manager_files = subparser.add_parser(
            'search-object-storage-manager-files',
            help='To search all the available Object Storage Manager Files.',
            formatter_class=ArgumentDefaultsHelpFormatter)
        search_object_storage_manager_files.add_argument(
            "--file_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            required=True,
            help="Provide File Name to search all the available Object Storage Manager Files."
        )
        search_object_storage_manager_files.add_argument(
            "--object_storage_manager_id",
            type=int,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Id to search all the available Object Storage Manager Files."
        )
        search_object_storage_manager_files.add_argument(
            "--object_storage_manager_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Name to search all the available Object Storage Manager Files."
        )
        search_object_storage_manager_files.add_argument(
            "--page_number",
            type=int,
            nargs=1,
            default=1,
            help="To search Object Storage Manager Files for a specific page_number."
        )
        search_object_storage_manager_files.add_argument(
            "--limit",
            type=int,
            nargs=1,
            default=100,
            help="Provide limit to search number of Object Storage Manager Files."
        )
        search_object_storage_manager_files.add_argument(
            "--json-output",
            type=check_non_empty_string,
            nargs='?',
            choices=['pretty', 'default'],
            default='pretty',
            help="Provide the format of JSON output."
        )
        search_object_storage_manager_files.add_argument(
            "--yaml-output",
            type=check_boolean,
            nargs='?',
            choices=['true', 'false'],
            default='false',
            help="Provide true to get output in YAML format."
        )

        describe_object_storage_manager_files = subparser.add_parser(
            'get-object-storage-manager-file',
            help='To get information about a specific Object Storage Manager File.',
            formatter_class=ArgumentDefaultsHelpFormatter)
        describe_object_storage_manager_files.add_argument(
            "--object_storage_manager_id",
            type=int,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Id to get information about a specific Object Storage Manager Files."
        )
        describe_object_storage_manager_files.add_argument(
            "--object_storage_manager_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Name to get information about a specific Object Storage Manager Files."
        )
        describe_object_storage_manager_files.add_argument(
            "--file_id",
            type=int,
            nargs=1,
            default=SUPPRESS,
            help="Provide File Id to get information about a specific Object Storage Manager Files."
        )
        describe_object_storage_manager_files.add_argument(
            "--file_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            help="Provide File Name to get information about a specific Object Storage Manager Files."
        )
        describe_object_storage_manager_files.add_argument(
            "--json-output",
            type=check_non_empty_string,
            nargs='?',
            choices=['pretty', 'default'],
            default='pretty',
            help="Provide the format of JSON output."
        )
        describe_object_storage_manager_files.add_argument(
            "--yaml-output",
            type=check_boolean,
            nargs='?',
            choices=['true', 'false'],
            default='false',
            help="Provide true to get output in YAML format."
        )

        delete_object_storage_manager_files = subparser.add_parser(
            'delete-object-storage-manager-file',
            help='To delete a specific Object Storage Manager File.',
            formatter_class=ArgumentDefaultsHelpFormatter)
        delete_object_storage_manager_files.add_argument(
            "--object_storage_manager_id",
            type=int,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Id to delete a specific Object Storage Manager File."
        )
        delete_object_storage_manager_files.add_argument(
            "--object_storage_manager_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            help="Provide Object Storage Manager Name to delete a specific Object Storage Manager File."
        )
        delete_object_storage_manager_files.add_argument(
            "--file_id",
            type=int,
            nargs=1,
            default=SUPPRESS,
            help="Provide File Id to delete a specific Object Storage Manager Files."
        )
        delete_object_storage_manager_files.add_argument(
            "--file_name",
            type=check_non_empty_string,
            nargs=1,
            default=SUPPRESS,
            help="Provide File Name to delete a specific Object Storage Manager Files."
        )
        delete_object_storage_manager_files.add_argument(
            "--json-output",
            type=check_non_empty_string,
            nargs='?',
            choices=['pretty', 'default'],
            default='pretty',
            help="Provide the format of JSON output."
        )
        delete_object_storage_manager_files.add_argument(
            "--yaml-output",
            type=check_boolean,
            nargs='?',
            choices=['true', 'false'],
            default='false',
            help="Provide true to get output in YAML format."
        )
