from yeedu.openapi.job.spark_job_config import SparkJobConfig
from yeedu.openapi.job.spark_job_instance import SparkJobInstance
from yeedu.openapi.job.download_job_instance_logs import DownloadJobInstanceLogs
from yeedu.utility.logger_utils import Logger
from yeedu.utility.json_utils import *
import sys

logger = Logger.get_logger(__name__, True)


# Spark Job Configuration
def create_spark_job_config(args):
    try:
        trim_json_data = trim_namespace_json(args)
        json_data = change_output(
            remove_output(args, subcommand='create-conf'))

        del json_data["workspace_id"]

        if hasattr(args, 'job_raw_scala_code') and trim_json_data.get('job_raw_scala_code')[0] != None:
            rawScalaCodeFilePath = checkFilePathExists(
                trim_json_data.get('job_raw_scala_code')[0], 'job_raw_scala_code')

            json_data['job_rawScalaCode'] = readFileContent(
                rawScalaCodeFilePath)

            del json_data["job_raw_scala_code"]
            response_json, status_code = SparkJobConfig.add_spark_job_config(
                trim_json_data.get('workspace_id')[0],
                json_data
            )
            confirm_output(response_json, status_code, trim_json_data)

        else:
            response_json, status_code = SparkJobConfig.add_spark_job_config(
                trim_json_data.get('workspace_id')[0],
                json_data
            )
            confirm_output(response_json, status_code, trim_json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def describe_spark_job_config(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobConfig.get_spark_job_config_by_id_or_name(
            json_data.get('workspace_id'),
            json_data.get('job_conf_id'),
            json_data.get('job_conf_name')
        )
        confirm_output(response_json, status_code, json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def search_spark_job_configs(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobConfig.search_spark_job_config_by_workspaceId_and_name(
            json_data.get('workspace_id'),
            json_data.get('job_conf_name'),
            json_data.get('enable'),
            json_data.get('page_number'),
            json_data.get('limit')
        )

        confirm_output(response_json, status_code, json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def list_spark_job_config(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobConfig.list_spark_job_config(
            json_data.get('workspace_id'),
            json_data.get('enable'),
            json_data.get('page_number'),
            json_data.get('limit')
        )
        confirm_output(response_json, status_code, json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def edit_spark_job_config(args):
    try:
        trim_json_data = change_output(trim_namespace_json(args))
        json_data = remove_output(args, subcommand='edit-conf')

        if json_data.get('job_conf_id') is not None:
            del json_data["job_conf_id"]
        if json_data.get('job_conf_name') is not None:
            del json_data["job_conf_name"]

        del json_data["workspace_id"]

        if hasattr(args, 'job_raw_scala_code') and trim_json_data.get('job_raw_scala_code') != None:
            rawScalaCodeFilePath = checkFilePathExists(
                trim_json_data.get('job_raw_scala_code'), 'job_raw_scala_code')

            json_data['job_rawScalaCode'] = readFileContent(
                rawScalaCodeFilePath)

            del json_data["job_raw_scala_code"]
            response_json, status_code = SparkJobConfig.edit_spark_job_config(
                trim_json_data.get('workspace_id'),
                json_data,
                trim_json_data.get('job_conf_id'),
                trim_json_data.get('job_conf_name')
            )
            confirm_output(response_json, status_code, trim_json_data)

        else:
            response_json, status_code = SparkJobConfig.edit_spark_job_config(
                trim_json_data.get('workspace_id'),
                json_data,
                trim_json_data.get('job_conf_id'),
                trim_json_data.get('job_conf_name')
            )
            confirm_output(response_json, status_code, trim_json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def enable_spark_job_config(args):
    try:
        trim_json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobConfig.enable_spark_job_config_by_id_or_name(
            trim_json_data.get('workspace_id'),
            trim_json_data.get('job_conf_id'),
            trim_json_data.get('job_conf_name')
        )
        confirm_output(response_json, status_code, trim_json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def disable_spark_job_config(args):
    try:
        trim_json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobConfig.disable_spark_job_config_by_id_or_name(
            trim_json_data.get('workspace_id'),
            trim_json_data.get('job_conf_id'),
            trim_json_data.get('job_conf_name')
        )
        confirm_output(response_json, status_code, trim_json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)

# Spark Job Instance


def start_spark_job_run(args):
    try:
        trim_json_data = trim_namespace_json(args)
        json_data = change_output(remove_output(args))

        del json_data['workspace_id']

        response_json, status_code = SparkJobInstance.add_spark_job_instance(
            trim_json_data.get('workspace_id')[0],
            json_data)
        confirm_output(response_json, status_code, trim_json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def describe_spark_job_inst(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobInstance.get_spark_job_inst_by_id(
            json_data.get('workspace_id'),
            json_data.get('job_id'))
        confirm_output(response_json, status_code, json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def search_spark_job_inst(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobInstance.search_spark_job_instance_by_workspaceId_and_name(
            json_data.get('workspace_id'),
            json_data.get('job_id'),
            json_data.get('page_number'),
            json_data.get('limit')
        )

        confirm_output(response_json, status_code, json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def list_spark_job_inst(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobInstance.list_spark_job_instances(
            json_data.get('workspace_id'),
            json_data.get('page_number'),
            json_data.get('limit'),
            json_data.get('cluster_id'),
            json_data.get('job_conf_id'),
            json_data.get('job_conf_name'),
            json_data.get('job_status')
        )

        confirm_output(response_json, status_code, json_data)

    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def stop_spark_job_inst(args):
    try:
        trim_json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobInstance.stop_spark_job_instance_by_id(
            trim_json_data.get('workspace_id'),
            trim_json_data.get('job_id')
        )

        confirm_output(response_json, status_code, trim_json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def get_workflow_job_instance_details(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobInstance.get_workflow_job_instance_details_by_appId(
            json_data.get('workspace_id'),
            json_data.get('job_application_id'))
        confirm_output(response_json, status_code, json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


def get_spark_job_inst_status(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = SparkJobInstance.get_spark_job_status_by_id(
            json_data.get('workspace_id'),
            json_data.get('job_id'))
        confirm_output(response_json, status_code, json_data)
    except Exception as e:
        logger.exception(e)
        sys.exit(-1)


# Download Job Instance Log Files
def download_job_instance_log_records(args):
    try:
        json_data = change_output(trim_namespace_json(args))

        response_json, status_code = DownloadJobInstanceLogs.get_job_instance_log_records(
            json_data.get('workspace_id'),
            json_data.get('log_type'),
            json_data.get('job_id')
        )
        if (response_json is not True):
            confirm_output(response_json, status_code, json_data)

    except Exception as e:
        logger.exception(e)
        sys.exit(-1)
