# Command-Line-Interface

CLI(Command Line Interface) is a standard CLI to run interactively with Yeedu's [RESTful-API](https://github.com/yeedu-io/RESTful-API).

# CLI Features

- [CLI Setup](#cli-setup)
  - [Windows](#windows)
    - [Generate Executable file for yeedu CLI](#generate-executable-file-for-yeedu-cli)
  - [Linux](#linux)
  - [Environment Variable Setup](#environment-variable-setup)
  - [Authentication Setup](#authentication-setup)
    - [Storing the credentials as Environment Variables](#storing-the-credentials-as-environment-variables)
    - [Storing the credentials inside a `yeedu_credentials.config` file](#storing-the-credentials-inside-a-yeedu_credentialsconfig-file)
    - [Storing the Yeedu Session Token inside a file](#storing-the-yeedu-session-token-inside-a-file)
    - [Configure](#configure)
    - [list-tenants](#list-tenants)
    - [associate-tenant](#associate-tenant)
- [Resource](#resource)
  - [Lookup](#lookup)
    - [list-providers](#list-providers)
    - [get-provider](#get-provider)
    - [list-provider-availability-zones](#list-provider-availability-zones)
    - [get-provider-availability-zone](#get-provider-availability-zone)
    - [list-provider-machine-types](#list-provider-machine-types)
    - [get-provider-machine-type](#get-provider-machine-type)
    - [list-disk-machine-types](#list-disk-machine-types)
    - [list-credential-types](#list-credential-types)
    - [list-engine-cluster-instance-status](#list-engine-cluster-instance-status)
    - [list-spark-compute-types](#list-spark-compute-types)
    - [list-spark-infra-versions](#list-spark-infra-versions)
    - [list-spark-job-status](#list-spark-job-status)
    - [list-workflow-execution-states](#list-workflow-execution-states)
    - [list-workflow-types](#list-workflow-types)
  - [Volume Configuration](#volume-configuration)
    - [create-volume-conf](#create-volume-conf)
    - [list-volume-confs](#list-volume-confs)
    - [search-volume-confs](#search-volume-confs)
    - [get-volume-conf](#get-volume-conf)
    - [edit-volume-conf](#edit-volume-conf)
    - [delete-volume-conf](#delete-volume-conf)
  - [Network Configuration](#network-configuration)
    - [create-network-conf](#create-network-conf)
    - [list-network-confs](#list-network-confs)
    - [search-network-confs](#search-network-confs)
    - [get-network-conf](#get-network-conf)
    - [edit-network-conf](#edit-network-conf)
    - [delete-network-conf](#delete-network-conf)
  - [Boot Disk Image Config](#boot-disk-image-config)
    - [create-boot-disk-image-conf](#create-boot-disk-image-conf)
    - [get-boot-disk-image-conf](#get-boot-disk-image-conf)
    - [list-boot-disk-image-confs](#list-boot-disk-image-confs)
    - [search-boot-disk-image-confs](#search-boot-disk-image-confs)
    - [edit-boot-disk-image-conf](#edit-boot-disk-image-conf)
    - [delete-boot-disk-image-conf](#delete-boot-disk-image-conf)
  - [Credentials Configuration](#credentials-configuration)
    - [create-credential-conf](#create-credential-conf)
    - [list-credential-confs](#list-credential-confs)
    - [search-credential-confs](#search-credential-confs)
    - [get-credential-conf](#get-credential-conf)
    - [edit-credential-conf](#edit-credential-conf)
    - [delete-credential-conf](#delete-credential-conf)
  - [Cloud Env](#cloud-env)
    - [create-cloud-env](#create-cloud-env)
    - [list-cloud-envs](#list-cloud-envs)
    - [search-cloud-envs](#search-cloud-envs)
    - [get-cloud-env](#get-cloud-env)
    - [edit-cloud-env](#edit-cloud-env)
    - [delete-cloud-env](#delete-cloud-env)
  - [Object Storage Manager](#object-storage-manager)
    - [create-object-storage-manager](#create-object-storage-manager)
    - [list-object-storage-managers](#list-object-storage-managers)
    - [search-object-storage-managers](#search-object-storage-managers)
    - [get-object-storage-manager](#get-object-storage-manager)
    - [edit-object-storage-manager](#edit-object-storage-manager)
    - [delete-object-storage-manager](#delete-object-storage-manager)
  - [Object Storage Manager Files](#object-storage-manager-files)
    - [create-object-storage-manager-file](#create-object-storage-manager-file)
    - [list-object-storage-manager-files](#list-object-storage-manager-files)
    - [search-object-storage-manager-files](#search-object-storage-manager-files)
    - [get-object-storage-manager-file](#get-object-storage-manager-file)
    - [delete-object-storage-manager-file](#delete-object-storage-manager-file)
  - [Hive Metastore Configuration](#hive-metastore-configuration)
    - [create-hive-metastore-conf](#create-hive-metastore-conf)
    - [list-hive-metastore-confs](#list-hive-metastore-confs)
    - [search-hive-metastore-confs](#search-hive-metastore-confs)
    - [get-hive-metastore-conf](#get-hive-metastore-conf)
    - [edit-hive-metastore-conf](#edit-hive-metastore-conf)
    - [delete-hive-metastore-conf](#delete-hive-metastore-conf)
- [Cluster](#cluster)
  - [Cluster Configuration](#cluster-configuration)
    - [create-conf](#create-conf)
    - [list-confs](#list-confs)
    - [search-confs](#search-confs)
    - [get-conf](#get-conf)
    - [edit-conf](#edit-conf)
    - [delete-conf](#delete-conf)
  - [Cluster Instance](#cluster-instance)
    - [create](#create)
    - [list](#list)
    - [search](#search)
    - [get](#get)
    - [edit](#edit)
    - [start](#start)
    - [stop](#stop)
    - [destroy](#destroy)
    - [get-stats](#get-stats)
    - [list-status](#list-status)
    - [logs](#logs)
  - [Cluster Access Control](#cluster-access-control)
    - [associate-workspace](#associate-workspace)
    - [dissociate-workspace](#dissociate-workspace)
    - [list-workspaces](#list-workspaces)
    - [list-workspace-clusters](#list-workspace-clusters)
    - [search-workspace-clusters](#search-workspace-clusters)
- [Workspace](#workspace)
  - [Worksapce](#workspace)
    - [create](#create-1)
    - [list](#list-1)
    - [search](#search-1)
    - [get](#get-1)
    - [edit](#edit-1)
    - [enable](#enable)
    - [disable](#disable)
  - [Workspace Access Control](#workspace-access-control)
    - [create-user-access](#create-user-access)
    - [create-group-access](#create-group-access)
    - [delete-user-access](#delete-user-access)
    - [delete-group-access](#delete-group-access)
    - [list-users](#list-users)
    - [search-users](#search-users)
    - [match-user](#match-user)
    - [list-groups](#list-groups)
    - [search-groups](#search-groups)
    - [match-group](#match-group)
    - [get-user-access](#get-user-access)
    - [get-group-access](#get-group-access)
    - [list-users-access](#list-users-access)
    - [list-groups-access](#list-groups-access)
- [Job](#job)
  - [Spark Job Configuration](#spark-job-configuration)
    - [create-conf](#create-conf-1)
    - [list-confs](#list-confs-1)
    - [search-confs](#search-confs-1)
    - [get-conf](#get-conf-1)
    - [edit-conf](#edit-conf-1)
    - [enable-conf](#enable-conf)
    - [disable-conf](#disable-conf)
  - [Spark Job Instance](#spark-job-instance)
    - [start](#start-1)
    - [list](#list-2)
    - [search](#search-2)
    - [get](#get-2)
    - [stop](#stop-1)
    - [get-status](#get-status)
    - [logs](#logs-1)
  - [Workflow Details By Spark Job Application Id](#workflow-details-by-spark-job-application-id)
    - [get-workflow-job-instance](#get-workflow-job-instance)
- [Notebook](#notebook)
  - [Notebook Configuration](#notebook-configuration)
    - [create-conf](#create-conf-2)
    - [list-confs](#list-confs-2)
    - [search-confs](#search-confs-2)
    - [get-conf](#get-conf-2)
    - [edit-conf](#edit-conf-2)
    - [enable-conf](#enable-conf-1)
    - [disable-conf](#disable-conf-1)
  - [Notebook Instance](#notebook-instance)
    - [start](#start-2)
    - [kernel-start](#kernel-start)
    - [kernel-interrupt](#kernel-interrupt)
    - [kernel-restart](#kernel-restart)
    - [list](#list-3)
    - [search](#search-3)
    - [get](#get-3)
    - [stop](#stop-2)
    - [logs](#logs-2)
- [IAM](#iam-identity-and-access-management)
  - [User](#user)
    - [get-user-info](#get-user-info)
    - [get-user-roles](#get-user-roles)
  - [Shared Platform and Admin](#shared-platform-and-admin)
    - [sync-user](#sync-user)
    - [sync-group](#sync-group)
    - [list-user-groups](#list-user-groups)
    - [list-users](#list-users-1)
    - [search-users](#search-users-1)  
    - [match-user](#match-user-1)
    - [list-group-users](#list-group-users)
    - [list-groups](#list-groups-1)
    - [search-groups](#search-groups-1)
    - [match-group](#match-group-1)
  - [Lookup](#lookup-1)
    - [list-resources](#list-resources)
    - [get-resource](#get-resource)
    - [list-permissions](#list-permissions)
    - [get-permission](#get-permission)  
    - [list-roles](#list-roles)
    - [get-role](#get-role)
    - [list-rules](#list-rules)
    - [get-rule](#get-rule)
    - [list-workspace-permissions](#list-workspace-permissions)
    - [get-workspace-permission](#get-workspace-permission)
- [Platform-Admin](#platform-admin)
  - [Tenant](#tenant)
    - [create-tenant](#create-tenant)
    - [list-tenants](#list-tenants-1)
    - [search-tenants](#search-tenants)
    - [get-tenant](#get-tenant)
    - [edit-tenant](#edit-tenant)
    - [delete-tenant](#delete-tenant)
  - [User](#user-1)
    - [list-user-tenants](#list-user-tenants)
    - [list-tenant-users](#list-tenant-users)
    - [search-tenant-users](#search-tenant-users)
    - [get-tenant-user](#get-tenant-user)
    - [get-user-roles](#get-user-roles-1)
    - [list-users-roles](#list-users-roles)
    - [get-role-users](#get-role-users)
    - [create-user-role](#create-user-role)
    - [delete-user-role](#delete-user-role)  
  - [Group](#group)
    - [list-tenant-groups](#list-tenant-groups)
    - [search-tenant-groups](#search-tenant-groups)
    - [get-tenant-group](#get-tenant-group)
    - [get-group-roles](#get-group-roles)
    - [list-groups-roles](#list-groups-roles)
    - [get-role-groups](#get-role-groups)
    - [create-group-role](#create-group-role)
    - [delete-group-role](#delete-group-role)
- [Admin](#admin)
  - [User](#user-2)
    - [list-users](#list-users-2)
    - [search-users](#search-users-2)
    - [get-user](#get-user)
    - [get-user-roles](#get-user-roles-2)
    - [list-users-roles](#list-users-roles-1)
    - [get-role-users](#get-role-users-1)
    - [create-user-role](#create-user-role-1)
    - [delete-user-role](#delete-user-role-1)
  - [Group](#group-1)
    - [list-groups](#list-groups-2)
    - [search-groups](#search-groups-2)
    - [get-group](#get-group)
    - [get-group-roles](#get-group-roles-1)
    - [list-groups-roles](#list-groups-roles-1)
    - [get-role-groups](#get-role-groups-1)
    - [create-group-role](#create-group-role-1)
    - [delete-group-role](#delete-group-role-1)

# CLI Setup

Need to run below command from the project directory to setup the yeedu CLI on the environment.

## Windows

```cmd
pip install --editable .
```

### Generate Executable file for yeedu CLI

- Need to install `pyinstaller` using below mentioned command

```cmd
pip install pyinstaller
```

- From project directory execute below mention command

```cmd
pyinstaller --onefile yeedu.py
```

Traverse to `\dist` directory and get the executable file `yeedu.exe`

- The yeedu.exe commands can be formed as shown below:

```cmd
yeedu.exe [-h]
yeedu.exe <command> [-h]
yeedu.exe <command> <subcommand> [-h]
```

- Example of yeedu CLI command using executable file

```cmd
yeedu.exe resource list-providers
```

## Linux

- WSL

```bash
sudo apt install python3-pip
```

```bash
pip3 install --editable .
```

- Bash

```bash
sudo python3 setup.py develop
```

### Tab-Autocomplete

- From project directory traverse to the `/scripts` directory and get the `yeedu_autocompletion.sh`.

```bash
# Add the following to ~/.bashrc
source /path/to/yeedu_autocompletion.sh
```

- Restart the shell or open a new shell after adding the above in `~/.bashrc`.

## Environment Variable Setup

Create a `.env` file in the project directory and provide below environment variables.

```bash
# Below mentioned values are the default values of Environment Variables 
YEEDU_RESTAPI_URL="http://localhost:8080"
YEEDU_CLI_LOG_DIR=/.yeedu/cli/logs/
YEEDU_USERNAME=USER
YEEDU_PASSWORD=PASS
YEEDU_RESTAPI_TOKEN=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1c2VybmFtZSI6ImFiY2RlZiIsImlkIjoiMSIsImlhdCI6MTY2NzgwOTYwMX0.HwhdTHBttnR0NFtmUDjcxTLMSLfyNuBs7t7GO9zOf08
YEEDU_RESTAPI_TOKEN_FILE_PATH=/home/user/yeedu_cli.config
```

Alternative of `.env` file

- Windows CMD

```cmd
SET YEEDU_RESTAPI_URL="http://localhost:8080"
SET YEEDU_CLI_LOG_DIR=/.yeedu/cli/logs/
SET YEEDU_USERNAME=USER
SET YEEDU_PASSWORD=PASS
SET YEEDU_RESTAPI_TOKEN=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1c2VybmFtZSI6ImFiY2RlZiIsImlkIjoiMSIsImlhdCI6MTY2NzgwOTYwMX0.HwhdTHBttnR0NFtmUDjcxTLMSLfyNuBs7t7GO9zOf08
SET YEEDU_RESTAPI_TOKEN_FILE_PATH=/home/user/yeedu_cli.config
```

- Linux

```bash
export YEEDU_RESTAPI_URL="http://localhost:8080"
export YEEDU_CLI_LOG_DIR=/.yeedu/cli/logs/
export YEEDU_USERNAME=USER
export YEEDU_PASSWORD=PASS
export YEEDU_RESTAPI_TOKEN=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1c2VybmFtZSI6ImFiY2RlZiIsImlkIjoiMSIsImlhdCI6MTY2NzgwOTYwMX0.HwhdTHBttnR0NFtmUDjcxTLMSLfyNuBs7t7GO9zOf08
export YEEDU_RESTAPI_TOKEN_FILE_PATH=/home/user/yeedu_cli.config
```

## Authentication Setup

- Below mentions ways of storing the credentials which will be used [Environment Variables will be given a priority] to generate the token.

### Storing the credentials as Environment Variables

```env
YEEDU_USERNAME=USER
YEEDU_PASSWORD=PASS
```

### Storing the credentials inside a `yeedu_credentials.config` file

- The yeedu_credentials.config file needs to be created inside the directory `home/user/.yeedu/` which consists of JSON as shown below:

```JSON
{
  "YEEDU_USERNAME": "USER",
  "YEEDU_PASSWORD": "PASS"
}
```

### Storing the Yeedu Session Token inside a file

- If the user is already having the Yeedu Session Token. Then user can save the token at the any location and provide the file path in enviroment variable `YEEDU_RESTAPI_TOKEN_FILE_PATH`
  - For example `YEEDU_RESTAPI_TOKEN_FILE_PATH="/home/user/Documents/YeeduToken/{FileName}"`
- Format to store the token is as shown below:

```JSON
{
  "token": "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJ1c2VyX2lkIjoxLCJpYXQiOjE2ODg3MjA0MjIsImV4cCI6MTY4ODg5MzIyMn0.EfxuXKPBISQB4ep-sPQbo6R7tg2irlnAC_krqnuXJ5Q"
}
```

| Command Name                         | Utility                                                   |
|--------------------------------------|-----------------------------------------------------------|
|[configure](#configure)               | Used to generate the token.                               |
|[list-tenants](#list-tenants)         | To list all the available tenants for the session user.   |
|[associate-tenant](#associate-tenant) | To associate tenant with the current users session Token. |

### Configure

```bash
yeedu configure -h
```

```bash
Yeedu CLI

positional arguments:
  {configure}

options:
  -h, --help            Show this help message and exit.
  --timeout [TIMEOUT]   Provide token expiration timeout in hour Example: --timeout=24,
                        --timeout=infinity (infinity for no expiration time) to generate
                        Yeedu Token. (default: 48)
  --no-browser [{true,false}]
                        If 'no-browser=true' is provided, the browser will not open
                        automatically for the SSO login URL. (default: false)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- User can provide the file path to stored the configured token using the environment variable `YEEDU_RESTAPI_TOKEN_FILE_PATH`.
  - For example `YEEDU_RESTAPI_TOKEN_FILE_PATH="/home/user/Documents/YeeduToken/{FileName}"`
- configure example with optional argument passed.

```bash
yeedu configure --timeout=72
```

- Console output

```bash
{
  "message": "The token has been configured for the username: USER and stored at location: /home/user/.yeedu/yeedu_cli.config"
}
```

The generated token will be used internally for accessing the yeedu features based on the acess level provided to the given username

- To list the tenants a user has access to, execute the `yeedu iam list-tenants` command.

### list-tenants

```bash
yeedu iam list-tenants -h
```

```bash
usage:  list-tenants [-h] [--page_number PAGE_NUMBER] [--limit LIMIT]
                     [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --page_number PAGE_NUMBER
                        To list the available tenants for a specific page_number.
                        (default: 1)
  --limit LIMIT         Provide limit to list number of available tenants. (default:
                        100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-tenants example without optional arguments passed.

```bash
yeedu iam list-tenants
```

- Console output

```bash
{
  "data": [
    {
      "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
      "name": "tenant1",
      "description": "Yeedu Tenant 1"
    },
    {
      "tenant_id": "066a702d-6b9d-4176-afc5-51c24a651739",
      "name": "tenant2",
      "description": "Yeedu Tenant 2"
    },
    {
      "tenant_id": "cf1f945f-01ce-4ac6-a070-8c733f2fa791",
      "name": "tenant3",
      "description": "Yeedu Tenant 3"
    },
    {
      "tenant_id": "6b682ef1-ede4-4d96-bab6-cd008aadd534",
      "name": "tenant4",
      "description": "Yeedu Tenant 4"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 4,
    "total_pages": 1,
    "limit": 100
  }
}
```

- Execute `yeedu iam associate-tenant --tenant_id={tenant_id}` to associate a tenant id from the `yeedu iam list-tenants` response to the session token.

### associate-tenant

```bash
yeedu iam associate-tenant -h
```

```bash
usage:  associate-tenant [-h] --tenant_id TENANT_ID [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide tenant_id to associate it with session token
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- associate-tenant example with required argument '--tenant_id' passed.

```bash
yeedu iam associate-tenant --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38"
```

- Console output

```bash
{
  "message": "Successfully associated Tenant"
}
```

# Resource

## Lookup

| Command Name                                                         | Utility                                                                              |
|----------------------------------------------------------------------|--------------------------------------------------------------------------------------|
|[list-providers](#list-providers)                                     | To get information about all Cloud Providers.                                        |
|[get-provider](#get-provider)                                         | To get information about a specific Cloud Provider.                                  |
|[list-provider-availability-zones](#list-provider-availability-zones) | To get information about Availability Zones for a specific Cloud Provider.           |
|[get-provider-availability-zone](#get-provider-availability-zone)     | To get information about a specific Availability Zone for a specific Cloud Provider. |
|[list-provider-machine-types](#list-provider-machine-types)           | To get information about Machine Types for a specific Cloud Provider.                |
|[get-provider-machine-type](#get-provider-machine-type)               | To get information about a specific Machine Type for a specific Cloud Provider.      |
|[list-disk-machine-types](#list-disk-machine-types)                   | To get information about all disk machine types.                                     |
|[list-credential-types](#list-credential-types)                       | To get information about all credential types.                                       |
|[list-engine-cluster-instance-status](#list-engine-cluster-instance-status) | To get information about all available engine cluster instance status.         |
|[list-spark-compute-types](#list-spark-compute-types)                 | To get information about all spark compute types.                                    |
|[list-spark-infra-versions](#list-spark-infra-versions)               | To get information about spark infra version.                                        |
|[list-spark-job-status](#list-spark-job-status)                       | To get information about spark job status.                                           |
|[list-workflow-execution-states](#list-workflow-execution-states)     | To get information about workflow execution state.                                   |
|[list-workflow-types](#list-workflow-types)                           | To get information about workflow type.                                              |

### list-providers

```bash
yeedu resource list-providers -h
```

```bash
usage:  list-providers [-h] [--json-output [{pretty,default}]]
                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-providers example without any optional argument passed for output format.

```bash
yeedu resource list-providers
```

- Console output

```bash
[
  {
    "cloud_provider_id": "0",
    "name": "gcp",
    "description": "Provider for creating infrastructure on Google Cloud Platform",
    "from_date": "2023-09-27T06:11:53.179Z",
    "to_date": null
  },
  {
    "cloud_provider_id": "1",
    "name": "aws",
    "description": "Provider for creating infrastructure on Amazon Web Services",
    "from_date": "2023-09-27T06:11:53.179Z",
    "to_date": null
  },
  {
    "cloud_provider_id": "2",
    "name": "azure",
    "description": "Provider for creating infrastructure on Azure Cloud Platform",
    "from_date": "2023-09-27T06:11:53.179Z",
    "to_date": null
  }
]
```

### get-provider

```bash
yeedu resource get-provider -h
```

```bash
usage:  get-provider [-h] --cloud_provider_id CLOUD_PROVIDER_ID
                     [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider_id CLOUD_PROVIDER_ID
                        Provide specific cloud provider id to get-provider.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-provider example with required '--cloud_provider_id' argument passed.

```bash
yeedu resource get-provider --cloud_provider_id=0
```

- Console output

```bash
{
  "cloud_provider_id": "0",
  "name": "gcp",
  "description": "Provider for creating infrastructure on Google Cloud Platform",
  "from_date": "2023-09-27T06:11:53.179Z",
  "to_date": null
}
```

### list-provider-availability-zones

```bash
yeedu resource list-provider-availability-zones -h
```

```bash
usage:  list-provider-availability-zones [-h] --cloud_provider_id CLOUD_PROVIDER_ID
                                         [--json-output [{pretty,default}]]
                                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider_id CLOUD_PROVIDER_ID
                        Provide specific Cloud Provider id to list-provider-
                        availability-zones.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-provider-availability-zones example with required '--cloud_provider_id' argument passed.

```bash
yeedu resource list-provider-availability-zones --cloud_provider_id=0
```

- Console output

```bash
[
  {
    "availability_zone_id": "0",
    "cloud_provider": {
      "name": "gcp",
      "description": "Provider for creating infrastructure on Google Cloud Platform"
    },
    "name": "asia-east1-a",
    "region": "asia-east1",
    "description": "Changhua County, Taiwan, APAC",
    "from_date": "2023-09-27T06:11:53.246Z",
    "to_date": null
  },
  ...
  {
    "availability_zone_id": "102",
    "cloud_provider": {
      "name": "gcp",
      "description": "Provider for creating infrastructure on Google Cloud Platform"
    },
    "name": "us-south1-c",
    "region": "us-south1",
    "description": "Dallas, Texas, North America",
    "from_date": "2023-09-27T06:11:53.246Z",
    "to_date": null
  }
]
```

### get-provider-availability-zone

```bash
yeedu resource get-provider-availability-zone -h
```

```bash
usage:  get-provider-availability-zone [-h] --cloud_provider_id CLOUD_PROVIDER_ID
                                       --availability_zone_id AVAILABILITY_ZONE_ID
                                       [--json-output [{pretty,default}]]
                                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider_id CLOUD_PROVIDER_ID
                        Provide specific cloud provider id to get-provider-
                        availability-zone.
  --availability_zone_id AVAILABILITY_ZONE_ID
                        Provide specific Availability Zone id to get-provider-
                        availability-zone.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-provider-availability-zone example with required arguments passed.

```bash
yeedu resource get-provider-availability-zone --cloud_provider_id=1 --availability_zone_id=116
```

- Console output

```bash
{
  "availability_zone_id": "116",
  "cloud_provider": {
    "name": "aws",
    "description": "Provider for creating infrastructure on Amazon Web Services"
  },
  "name": "Canada",
  "region": "ca-central-1",
  "description": "central",
  "from_date": "2023-09-27T06:11:53.246Z",
  "to_date": null
}
```

### list-provider-machine-types

```bash
yeedu resource list-provider-machine-types -h
```

```bash
usage:  list-provider-machine-types [-h] --cloud_provider_id CLOUD_PROVIDER_ID
                                    [--json-output [{pretty,default}]]
                                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider_id CLOUD_PROVIDER_ID
                        Provide specific cloud provider id to list-provider-machine-
                        types.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-provider-machine-types example with required '--cloud_provider_id' argument passed.

```bash
yeedu resource list-provider-machine-types --cloud_provider_id=0
```

- Console output

```bash
[
  {
    "machine_type_id": "0",
    "cloud_provider": {
      "name": "gcp",
      "description": "Provider for creating infrastructure on Google Cloud Platform"
    },
    "name": "a2-highgpu-1g",
    "vcpus": 12,
    "memory": "85 GiB",
    "has_cuda": false,
    "gpu_model": null,
    "gpus": null,
    "gpu_memory": null,
    "from_date": "2023-09-27T06:11:53.193Z",
    "to_date": null
  },
  ...
  {
    "machine_type_id": "723",
    "cloud_provider": {
      "name": "gcp",
      "description": "Provider for creating infrastructure on Google Cloud Platform"
    },
    "name": "n1-standard-4-4g",
    "vcpus": 4,
    "memory": "15 GiB",
    "has_cuda": true,
    "gpu_model": "nvidia-tesla-t4",
    "gpus": 4,
    "gpu_memory": "64 GB GDDR6",
    "from_date": "2023-09-27T06:11:53.193Z",
    "to_date": null
  }
]
```

### get-provider-machine-type

```bash
yeedu resource get-provider-machine-type -h
```

```bash
usage:  get-provider-machine-type [-h] --cloud_provider_id CLOUD_PROVIDER_ID
                                  --machine_type_id MACHINE_TYPE_ID
                                  [--json-output [{pretty,default}]]
                                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider_id CLOUD_PROVIDER_ID
                        Provide specific cloud provider id to get-provider-machine-type.
  --machine_type_id MACHINE_TYPE_ID
                        Provide specific machine type id to get-provider-machine-type.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-provider-machine-type example with all the required arguments passed.

```bash
yeedu resource get-provider-machine-type --cloud_provider_id=0 --machine_type_id=108
```

- Console output

```bash
{
  "machine_type_id": "108",
  "cloud_provider": {
    "name": "gcp",
    "description": "Provider for creating infrastructure on Google Cloud Platform"
  },
  "name": "n2d-highmem-64",
  "vcpus": 64,
  "memory": "512 GiB",
  "has_cuda": false,
  "gpu_model": null,
  "gpus": null,
  "gpu_memory": null,
  "from_date": "2023-09-27T06:11:53.193Z",
  "to_date": null
}
```

### list-disk-machine-types

```bash
yeedu resource list-disk-machine-types -h
```

```bash
usage:  list-disk-machine-types [-h] [--json-output [{pretty,default}]]
                                [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-disk-machine-types example without optional argument passed for output format.

```bash
yeedu resource list-disk-machine-types
```

- Console output

```bash
[
  {
    "disk_type_id": "0",
    "cloud_provider": {
      "name": "gcp",
      "description": "Provider for creating infrastructure on Google Cloud Platform"
    },
    "name": "pd-ssd",
    "has_fixed_size": false,
    "min_size": 10,
    "max_size": 64000,
    "from_date": "2023-09-27T06:11:53.242Z",
    "to_date": null
  },
  ...
  {
    "disk_type_id": "15",
    "cloud_provider": {
      "name": "azure",
      "description": "Provider for creating infrastructure on Azure Cloud Platform"
    },
    "name": "UltraSSD_LRS",
    "has_fixed_size": false,
    "min_size": 4,
    "max_size": 65536,
    "from_date": "2023-09-27T06:11:53.242Z",
    "to_date": null
  }
]
```

### list-credential-types

```bash
yeedu resource list-credential-types -h
```

```bash
usage:  list-credential-types [-h] [--json-output [{pretty,default}]]
                              [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-credential-types example without optional argument passed for output format.

```bash
yeedu resource list-credential-types
```

- Console output

```bash
[
  {
    "credential_type_id": "0",
    "name": "gcp",
    "cloud_provider": {
      "name": "gcp",
      "description": "Provider for creating infrastructure on Google Cloud Platform"
    },
    "from_date": "2023-09-27T06:11:53.188Z",
    "to_date": null
  },
  {
    "credential_type_id": "1",
    "name": "aws",
    "cloud_provider": {
      "name": "aws",
      "description": "Provider for creating infrastructure on Amazon Web Services"
    },
    "from_date": "2023-09-27T06:11:53.188Z",
    "to_date": null
  },
  {
    "credential_type_id": "2",
    "name": "azure",
    "cloud_provider": {
      "name": "azure",
      "description": "Provider for creating infrastructure on Azure Cloud Platform"
    },
    "from_date": "2023-09-27T06:11:53.188Z",
    "to_date": null
  }
]
```

### list-engine-cluster-instance-status

```bash
yeedu resource list-engine-cluster-instance-status -h
```

```bash
usage:  list-engine-cluster-instance-status [-h] [--json-output [{pretty,default}]]
                                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-engine-cluster-instance-status example without optional argument passed for output format.

```bash
yeedu resource list-engine-cluster-instance-status
```

- Console output

```bash
[
  {
    "engine_cluster_instance_status_id": "0",
    "name": "INITIATING",
    "description": "Cluster will be eventually created",
    "from_date": "2023-09-27T06:11:53.186Z",
    "to_date": null
  },
  ...
  {
    "engine_cluster_instance_status_id": "8",
    "name": "RESIZING_DOWN",
    "description": "The cluster instance will scale down",
    "from_date": "2023-09-27T06:11:53.186Z",
    "to_date": null
  }
]
```

### list-spark-compute-types

```bash
yeedu resource list-spark-compute-types -h
```

```bash
usage:  list-spark-compute-types [-h] [--json-output [{pretty,default}]]
                                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-spark-compute-types example without optional argument passed for output format.

```bash
yeedu resource list-spark-compute-types
```

- Console output

```bash
[
  {
    "spark_compute_type_id": "0",
    "name": "YEEDU",
    "description": null,
    "from_date": "2023-09-27T06:11:53.265Z",
    "to_date": null
  }
]
```

### list-spark-infra-versions

```bash
yeedu resource list-spark-infra-versions -h
```

```bash
usage:  list-spark-infra-versions [-h] [--json-output [{pretty,default}]]
                                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-spark-infra-versions example without optional argument passed for output format.

```bash
yeedu resource list-spark-infra-versions
```

- Console output

```bash
[
  {
    "spark_infra_version_id": "0",
    "spark_version": "2.4.8",
    "hive_version": "3.2.3",
    "hadoop_version": "2.10.1",
    "scala_version": "2.11.10",
    "python_version": "3.9.5",
    "notebook_support": false,
    "from_date": "2023-10-18T12:28:01.395Z",
    "to_date": null
  },
  {
    "spark_infra_version_id": "1",
    "spark_version": "3.2.2",
    "hive_version": "3.2.3",
    "hadoop_version": "3.2.4",
    "scala_version": "2.12.15",
    "python_version": "3.9.5",
    "notebook_support": true,
    "from_date": "2023-10-18T12:28:01.395Z",
    "to_date": null
  },
  {
    "spark_infra_version_id": "2",
    "spark_version": "v3.2.2-rc5",
    "hive_version": "3.2.3",
    "hadoop_version": "3.2.4",
    "scala_version": "2.12.15",
    "python_version": "3.9.5",
    "notebook_support": true,
    "from_date": "2023-10-18T12:28:01.395Z",
    "to_date": null
  }
]
```

### list-spark-job-status

```bash
yeedu resource list-spark-job-status -h
```

```bash
usage:  list-spark-job-status [-h] [--json-output [{pretty,default}]]
                              [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-spark-job-status example without optional argument passed for output format.

```bash
yeedu resource list-spark-job-status
```

- Console output

```bash
[
  {
    "spark_job_status_id": "0",
    "name": "SUBMITTED",
    "description": "Job was submitted, waiting for Application ID",
    "from_date": "2023-09-27T06:11:53.266Z",
    "to_date": null
  },
  ...
  {
    "spark_job_status_id": "8",
    "name": "STOPPED",
    "description": "The process was successfully stopped",
    "from_date": "2023-09-27T06:11:53.266Z",
    "to_date": null
  }
]
```

### list-workflow-execution-states

```bash
yeedu resource list-workflow-execution-states -h
```

```bash
usage:  list-workflow-execution-states [-h] [--json-output [{pretty,default}]]
                                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-workflow-execution-states example without optional argument passed for output format.

```bash
yeedu resource list-workflow-execution-states
```

- Console output

```bash
[
  {
    "workflow_execution_state_id": -1,
    "name": "NONE",
    "description": "NONE",
    "from_date": "2023-09-27T06:11:53.255Z",
    "to_date": null
  },
  ...
  {
    "workflow_execution_state_id": 99,
    "name": "DONE",
    "description": "NONE",
    "from_date": "2023-09-27T06:11:53.255Z",
    "to_date": null
  }
]
```

### list-workflow-types

```bash
yeedu resource list-workflow-types -h
```

```bash
usage:  list-workflow-types [-h] [--json-output [{pretty,default}]]
                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-workflow-types example without optional argument passed for output format.

```bash
yeedu resource list-workflow-types
```

- Console output

```bash
[
  {
    "workflow_type_id": "0",
    "name": "spark_start",
    "queue_name": "yeedu.workflows.usi.start",
    "description": null,
    "from_date": "2023-09-27T06:11:53.257Z",
    "to_date": null
  },
  ...
  {
    "workflow_type_id": "8",
    "name": "cosi_resize_down",
    "queue_name": "yeedu.workflows.cosi",
    "description": null,
    "from_date": "2023-09-27T06:11:53.257Z",
    "to_date": null
  }
]
```

## Volume Configuration

| Command Name                              | Utility                                                   |
|-------------------------------------------|-----------------------------------------------------------|
|[create-volume-conf](#create-volume-conf)  | To create the Volume Configuration.                       |
|[list-volume-confs](#list-volume-confs)    | To list all the available Volume Configurations.          |
|[search-volume-confs](#search-volume-confs)| To search all the available Volume Configurations.        |
|[get-volume-conf](#get-volume-conf)        | To get information about a specific Volume Configuration. |
|[edit-volume-conf](#edit-volume-conf)      | To edit a specific Volume Configuration.                  |

### create-volume-conf

```bash
yeedu resource create-volume-conf -h
```

```bash
usage:  create-volume-conf [-h] --name [NAME] [--description [DESCRIPTION]] --encrypted {true,false} [--size [SIZE]] --disk_type_id DISK_TYPE_ID
                           --machine_volume_num MACHINE_VOLUME_NUM --machine_volume_strip_num MACHINE_VOLUME_STRIP_NUM
                           [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name [NAME]         Provide name to create-volume-conf.
  --description [DESCRIPTION]
                        Provide description to create-volume-conf.
  --encrypted {true,false}
                        Provide encrypted to create-volume-conf.
  --size [SIZE]         Provide size to create-volume-conf.
  --disk_type_id DISK_TYPE_ID
                        Provide disk_type to create-volume-conf.
  --machine_volume_num MACHINE_VOLUME_NUM
                        Provide machine_volume_num to create-volume-conf.
  --machine_volume_strip_num MACHINE_VOLUME_STRIP_NUM
                        Provide machine_volume_strip_num to create-volume-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-volume-conf example with all the required arguments passed.

```bash
yeedu resource create-volume-conf --name="yeedu_volume" --encrypted=false --disk_type_id=1  --machine_volume_num=1 --machine_volume_strip_num=1
```

- Console output

```bash
{
  "volume_conf_id": "1",
  "name": "yeedu_volume",
  "description": null,
  "encrypted": false,
  "size": "375",
  "disk_type_id": "4",
  "disk_type_name": "local-ssd",
  "machine_volume_num": 1,
  "machine_volume_strip_num": 1,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-09-28T14:52:41.175Z",
  "from_date": "2023-09-28T14:52:41.175Z",
  "to_date": null
}
```

### list-volume-confs

```bash
yeedu resource list-volume-confs -h
```

```bash
usage:  list-volume-confs [-h] [--page_number PAGE_NUMBER] [--limit LIMIT] [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --page_number PAGE_NUMBER
                        To list Volume Configurations for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Volume Configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-volume-confs example with optional arguments passed for output format.

```bash
yeedu resource list-volume-confs --cloud_provider="GCP"
```

- Console output

```bash
{
  "data": [
    {
      "volume_conf_id": 1,
      "name": "yeedu_volume",
      "description": null,
      "encrypted": false,
      "size": 375,
      "disk_type": {
        "disk_type_id": 4,
        "name": "local-ssd",
        "has_fixed_size": true,
        "min_size": 375,
        "max_size": 375,
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        }
      },
      "machine_volume_num": 1,
      "machine_volume_strip_num": 1,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-05T09:27:59.407362+00:00",
      "from_date": "2024-01-05T09:27:59.407362+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-volume-confs

```bash
yeedu resource search-volume-confs -h
```

```bash
usage:  search-volume-confs [-h] --volume_conf_name VOLUME_CONF_NAME [--page_number PAGE_NUMBER] [--limit LIMIT]
                            [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --volume_conf_name VOLUME_CONF_NAME
                        Provide volume_conf_name to search all the available Volume Configurations.
  --page_number PAGE_NUMBER
                        To search Volume Configurations for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of Volume Configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-volume-confs example with required argument '--volume_conf_name' passed.

```bash
yeedu resource search-volume-confs --volume_conf_name="yeedu_"
```

- Console output

```bash
{
  "data": [
    {
      "volume_conf_id": 1,
      "name": "yeedu_volume",
      "description": null,
      "encrypted": false,
      "size": 375,
      "disk_type": {
        "disk_type_id": 4,
        "name": "local-ssd",
        "has_fixed_size": true,
        "min_size": 375,
        "max_size": 375,
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        }
      },
      "machine_volume_num": 1,
      "machine_volume_strip_num": 1,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-05T09:27:59.407362+00:00",
      "from_date": "2024-01-05T09:27:59.407362+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-volume-conf

```bash
yeedu resource get-volume-conf -h
```

```bash
usage:  get-volume-conf [-h] [--volume_conf_id VOLUME_CONF_ID] [--volume_conf_name VOLUME_CONF_NAME] [--json-output [{pretty,default}]]
                        [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --volume_conf_id VOLUME_CONF_ID
                        Provide volume_conf_id to get information about a specific Volume Configuration.
  --volume_conf_name VOLUME_CONF_NAME
                        Provide volume_conf_name to get information about a specific Volume Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)```

- get-volume-conf example with any one of required argument '--volume_conf_id' passed.

```bash
yeedu resource get-volume-conf --volume_conf_id=1
```

- Console output

```bash
    {
      "volume_conf_id": 1,
      "name": "yeedu_volume",
      "description": null,
      "encrypted": false,
      "size": 375,
      "disk_type": {
        "disk_type_id": 4,
        "name": "local-ssd",
        "has_fixed_size": true,
        "min_size": 375,
        "max_size": 375,
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        }
      },
      "machine_volume_num": 1,
      "machine_volume_strip_num": 1,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-05T09:27:59.407362+00:00",
      "from_date": "2024-01-05T09:27:59.407362+00:00",
      "to_date": "infinity"
    }
```

### edit-volume-conf

```bash
yeedu resource edit-volume-conf -h
```

```bash
usage:  edit-volume-conf [-h] [--volume_conf_id VOLUME_CONF_ID] [--volume_conf_name VOLUME_CONF_NAME] [--name [NAME]]
                         [--description [DESCRIPTION]] [--encrypted [{true,false}]] [--machine_volume_num MACHINE_VOLUME_NUM]
                         [--machine_volume_strip_num MACHINE_VOLUME_STRIP_NUM] [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --volume_conf_id VOLUME_CONF_ID
                        Provide specific volume_conf_id to edit-volume-conf.
  --volume_conf_name VOLUME_CONF_NAME
                        Provide specific volume_conf_name to edit-volume-conf.
  --name [NAME]         Provide name to edit-volume-conf.
  --description [DESCRIPTION]
                        Provide description to edit-volume-conf.
  --encrypted [{true,false}]
                        Provide encrypted to edit-volume-conf.
  --machine_volume_num MACHINE_VOLUME_NUM
                        Provide machine_volume_num to edit-volume-conf.
  --machine_volume_strip_num MACHINE_VOLUME_STRIP_NUM
                        Provide machine_volume_strip_num to edit-volume-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit-volume-conf example with any one of the required argument '--volume_conf_name' and other optional argument is passed which is to be updated.

```bash
yeedu resource edit-volume-conf --volume_conf_name="yeedu_volume" --encrypted=true
```

- Console output

```bash
{
  "volume_conf_id": "1",
  "name": "yeedu_volume",
  "description": null,
  "encrypted": true,
  "size": "375",
  "disk_type_id": "4",
  "disk_type_name": "local-ssd",
  "machine_volume_num": 1,
  "machine_volume_strip_num": 1,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-05T09:36:06.435Z",
  "from_date": "2024-01-05T09:27:59.407Z",
  "to_date": null
}
```

### delete-volume-conf

```bash
yeedu resource delete-volume-conf -h
```

```bash
usage:  delete-volume-conf [-h] [--volume_conf_id VOLUME_CONF_ID] [--volume_conf_name VOLUME_CONF_NAME] [--json-output [{pretty,default}]]
                           [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --volume_conf_id VOLUME_CONF_ID
                        Provide volume_conf_id to delete a specific Volume Configuration.
  --volume_conf_name VOLUME_CONF_NAME
                        Provide volume_conf_name to delete a specific Volume Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-volume-conf example with any one of the required argument '--volume_conf_name' which is to be deleted.

```bash
yeedu resource delete-volume-conf --volume_conf_name="yeedu_volume"
```

- Console output

```bash
{
  "message": "Deleted volume config name: 'yeedu_volume'."
}
```

## Network Configuration

## Network Configuration

| Command Name                                 | Utility                                                                                  |
|----------------------------------------------|------------------------------------------------------------------------------------------|
|[create-network-conf](#create-network-conf)   | To create the Network Configuration.                                                     |
|[list-network-confs](#list-network-confs)     | To get information about Network Configurations for a specific specific network.           |
|[search-network-confs](#search-network-confs) | To get information about Network Configurations for a specific specific network.           |
|[get-network-conf](#get-network-conf)         | To get information about a specific Network Configuration for a specific network|
|[edit-network-conf](#edit-network-conf)       | To edit a specific Network Configuration for a specific network.      |
|[delete-network-conf](#delete-network-conf)   | To delete a specific Network Configuration for a specific network.|

### create-network-conf

```bash
yeedu resource create-network-conf -h
```

```bash
usage:  create-network-conf [-h] --name NAME
                            [--description DESCRIPTION]
                            --network_project_id NETWORK_PROJECT_ID
                            --network_name NETWORK_NAME --subnet
                            SUBNET --availability_zone_id
                            AVAILABILITY_ZONE_ID
                            [--network_tags ['value1,value2']]
                            [--json-output [{pretty,default}]]
                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create-network-conf.
  --description DESCRIPTION
                        Provide description to create-network-conf.
  --network_project_id NETWORK_PROJECT_ID
                        Provide network_project_id to create-network-
                        conf.
  --network_name NETWORK_NAME
                        Provide network_name to create-network-conf.
  --subnet SUBNET       Provide subnet to create-network-conf.
  --availability_zone_id AVAILABILITY_ZONE_ID
                        Provide availability_zone_id to create-
                        network-conf.
  --network_tags ['value1,value2']
                        Provide network_tags to create-network-conf.
                        (default: [])
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:
                        pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format.
                        (default: false)
```

- create-network-conf example with all the required and optional arguments passed.

```bash
yeedu resource create-network-conf --name="yeedu_network" --network_project_id="modak-yeedu" --network_name='modak-yeedu-spark-vpc' --subnet='custom-subnet-modak-yeedu' --availability_zone_id=75 --network_tags="yeedu,iap-allow"
```

- Console output

```bash
{
  "network_conf_id": "1",
  "name": "yeedu_network",
  "description": null,
  "network_project_id": "modak-yeedu",
  "network_name": "modak-yeedu-spark-vpc",
  "network_tags": [
    "yeedu",
    "iap-allow"
  ],
  "subnet": "custom-subnet-modak-yeedu",
  "availability_zone_id": "75",
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-05T09:43:06.687Z",
  "from_date": "2024-01-05T09:43:06.687Z",
  "to_date": null
}
```

### list-network-confs

```bash
yeedu resource list-network-confs -h
```

```bash
usage:  list-network-confs [-h] [--cloud_provider [{GCP,AWS,AZURE}]] [--page_number PAGE_NUMBER] [--limit LIMIT]
                           [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider [{GCP,AWS,AZURE}]
                        Provide specific cloud_provider_id to get information about related Network Configurations.
  --page_number PAGE_NUMBER
                        To list Network Configurations for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Network Configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-network-confs example with optional argument `--cloud_provider` passed.

```bash
yeedu resource list-network-confs --cloud_provider="GCP"
```

- Console output

```bash
{
  "data": [
    {
      "network_conf_id": 1,
      "network_conf_name": "yeedu_network",
      "description": null,
      "network_project_id": "modak-yeedu",
      "network_name": "modak-yeedu-spark-vpc",
      "network_tags": [
        "yeedu",
        "iap-allow"
      ],
      "subnet": "custom-subnet-modak-yeedu",
      "availability_zone": {
        "availability_zone_id": 75,
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp",
          "description": "Provider for creating infrastructure on Google Cloud Platform"
        },
        "name": "us-central1-a",
        "region": "us-central1",
        "description": "Council Bluffs, Iowa, North America"
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-05T09:43:06.687724+00:00",
      "from_date": "2024-01-05T09:43:06.687724+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-network-confs

```bash
yeedu resource search-network-confs -h
```

```bash
usage:  search-network-confs [-h] --network_conf_name
                             NETWORK_CONF_NAME
                             [--cloud_provider [{GCP,AWS,AZURE}]]
                             [--page_number PAGE_NUMBER]
                             [--limit LIMIT]
                             [--json-output [{pretty,default}]]
                             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --network_conf_name NETWORK_CONF_NAME
                        Provide network_conf_name to get information
                        about a specific Network Configuration.
  --cloud_provider [{GCP,AWS,AZURE}]
                        Provide specific cloud_provider_id to get
                        information about related Network
                        Configurations.
  --page_number PAGE_NUMBER
                        To search Network Configurations for a
                        specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of Network
                        Configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:
                        pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format.
                        (default: false)
```

- search-network-confs example with required argument `--network_conf_name` passed.

```bash
yeedu resource search-network-confs --network_conf_name="yeedu_"
```

- Console output

```bash
{
  "data": [
    {
      "network_conf_id": 1,
      "network_conf_name": "yeedu_network",
      "description": null,
      "network_project_id": "modak-yeedu",
      "network_name": "modak-yeedu-spark-vpc",
      "network_tags": [
        "yeedu",
        "iap-allow"
      ],
      "subnet": "custom-subnet-modak-yeedu",
      "availability_zone": {
        "availability_zone_id": 75,
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp",
          "description": "Provider for creating infrastructure on Google Cloud Platform"
        },
        "name": "us-central1-a",
        "region": "us-central1",
        "description": "Council Bluffs, Iowa, North America"
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-05T09:43:06.687724+00:00",
      "from_date": "2024-01-05T09:43:06.687724+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-network-conf

```bash
yeedu resource get-network-conf -h
```

```bash
usage:  get-network-conf [-h] [--network_conf_id NETWORK_CONF_ID]
                         [--network_conf_name NETWORK_CONF_NAME]
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --network_conf_id NETWORK_CONF_ID
                        Provide network_conf_id to get information
                        about a specific network Configuration.
  --network_conf_name NETWORK_CONF_NAME
                        Provide network_conf_name to get information
                        about a specific network Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:
                        pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format.
                        (default: false)
```

- get-network-conf example with any one of the required argument '--network_conf_name' passed.

```bash
yeedu resource get-network-conf --network_conf_name="yeedu_network"
```

- Console output

```bash
  {
      "network_conf_id": 1,
      "network_conf_name": "yeedu_network",
      "description": null,
      "network_project_id": "modak-yeedu",
      "network_name": "modak-yeedu-spark-vpc",
      "network_tags": [
        "yeedu",
        "iap-allow"
      ],
      "subnet": "custom-subnet-modak-yeedu",
      "availability_zone": {
        "availability_zone_id": 75,
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp",
          "description": "Provider for creating infrastructure on Google Cloud Platform"
        },
        "name": "us-central1-a",
        "region": "us-central1",
        "description": "Council Bluffs, Iowa, North America"
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-05T09:43:06.687724+00:00",
      "from_date": "2024-01-05T09:43:06.687724+00:00",
      "to_date": "infinity"
  }
```

### edit-network-conf

```bash
yeedu resource edit-network-conf -h
```

```bash
usage:  edit-network-conf [-h] [--network_conf_id NETWORK_CONF_ID]
                          [--network_conf_name NETWORK_CONF_NAME]
                          [--name NAME] [--description DESCRIPTION]
                          [--network_name [NETWORK_NAME]]
                          [--network_project_id [NETWORK_PROJECT_ID]]
                          [--availability_zone_id AVAILABILITY_ZONE_ID]
                          [--subnet [SUBNET]]
                          [--network_tags ['value1,value2']]
                          [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --network_conf_id NETWORK_CONF_ID
                        Provide a specific Network Configuration
                        network_conf_id to edit-network-conf.
  --network_conf_name NETWORK_CONF_NAME
                        Provide a specific Network Configuration
                        network_conf_name to edit-network-conf.
  --name NAME           Provide name to edit-network-conf.
  --description DESCRIPTION
                        Provide description to edit-network-conf.
  --network_name [NETWORK_NAME]
                        Provide network_name to edit-network-conf.
  --network_project_id [NETWORK_PROJECT_ID]
                        Provide network_project_id to edit-network-
                        conf.
  --availability_zone_id AVAILABILITY_ZONE_ID
                        Provide availability_zone_id to edit-network-
                        conf.
  --subnet [SUBNET]     Provide subnet to edit-network-conf.
  --network_tags ['value1,value2']
                        Provide network_tags to edit-network-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:
                        pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format.
                        (default: false)
```

- edit-network-conf example with any one of the required argument '--network_conf_id' and other optional argument is passed which is to be updated.

```bash
yeedu resource edit-network-conf --network_conf_id=1 --network_name="modak-yeedu-spark-vpc"
```

- Console output

```bash
{
  "network_conf_id": "1",
  "network_conf_name": "yeedu_network",
  "description": null,
  "network_project_id": "modak-yeedu",
  "network_name": "modak-yeedu-spark-vpc",
  "network_tags": [
    "yeedu",
    "iap-allow"
  ],
  "subnet": "custom-subnet-modak-yeedu",
  "availability_zone_id": "75",
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-05T09:58:13.769Z",
  "from_date": "2024-01-05T09:43:06.687Z",
  "to_date": null
}
```

### delete-network-conf

```bash
yeedu resource delete-network-conf -h
```

```bash
usage:  delete-network-conf [-h] [--network_conf_id NETWORK_CONF_ID]
                            [--network_conf_name NETWORK_CONF_NAME]
                            [--json-output [{pretty,default}]]
                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --network_conf_id NETWORK_CONF_ID
                        Provide network_conf_id to delete a specific
                        network Configuration.
  --network_conf_name NETWORK_CONF_NAME
                        Provide network_conf_name to delete a specific
                        network Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:
                        pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format.
                        (default: false)
```

- delete-network-conf example with any one of the required argument '--network_conf_id' which is to be deleted.

```bash
yeedu resource delete-network-conf --network_conf_id=1
```

- Console output

```bash
{
  "message": "Deleted Machine Network Configuration Id: 1."
}
```

## Boot Disk Image Config

| Command Name                                                 | Utility                                                                |
|--------------------------------------------------------------|------------------------------------------------------------------------|
|[create-boot-disk-image-conf](#create-boot-disk-image-conf)   | To create a Boot Disk Image Configuration.                             |
|[get-boot-disk-image-conf](#get-boot-disk-image-conf)         | To get the information about a specific Boot Disk Image Configuration. |
|[list-boot-disk-image-confs](#list-boot-disk-image-confs)     | To list all the available Boot Disk Image Configurations.              |
|[search-boot-disk-image-confs](#search-boot-disk-image-confs) | To search all the available Boot Disk Image Configurations.              |
|[edit-boot-disk-image-conf](#edit-boot-disk-image-conf)       | To edit the information about a specific Boot Disk Image Configuration. |
|[delete-boot-disk-image-conf](#delete-boot-disk-image-conf)   | To delete the information about a specific Boot Disk Image Configuration. |

### create-boot-disk-image-conf

```bash
yeedu resource create-boot-disk-image-conf -h
```

```bash
usage:  create-boot-disk-image-conf [-h] --name NAME
                                    [--description DESCRIPTION]
                                    --cloud_provider_id
                                    CLOUD_PROVIDER_ID
                                    --linux_distro_id LINUX_DISTRO_ID
                                    --boot_disk_image BOOT_DISK_IMAGE
                                    [--json-output [{pretty,default}]]
                                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create-boot-disk-image-conf.
  --description DESCRIPTION
                        Provide description to create-boot-disk-image-
                        conf.
  --cloud_provider_id CLOUD_PROVIDER_ID
                        Provide cloud_provider_id to create-boot-disk-
                        image-conf.
  --linux_distro_id LINUX_DISTRO_ID
                        Provide linux_distro_id to create-boot-disk-
                        image-conf.
  --boot_disk_image BOOT_DISK_IMAGE
                        Provide boot_disk_image to create-boot-disk-
                        image-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:
                        pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format.
                        (default: false)
```

- create-boot-disk-image-conf example with all the required arguments passed.

```bash
yeedu resource create-boot-disk-image-conf --name="yeedu_boot_disk_image" --cloud_provider_id=0 --boot_disk_image="ubuntu-os-cloud/ubuntu-2004-lts" --linux_distro_id=1
```

- Console output

```bash
{
  "boot_disk_image_id": "2",
  "boot_disk_image_name": "yeedu_boot_disk_image",
  "description": null,
  "cloud_provider_id": 0,
  "linux_distro_id": 1,
  "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-05T10:09:27.590Z",
  "from_date": "2024-01-05T10:09:27.590Z",
  "to_date": null
}
```

### get-boot-disk-image-conf

```bash
yeedu resource get-boot-disk-image-conf -h
```

```bash
usage:  get-boot-disk-image-conf [-h]
                                 [--boot_disk_image_id BOOT_DISK_IMAGE_ID]
                                 [--boot_disk_image_name BOOT_DISK_IMAGE_NAME]
                                 [--json-output [{pretty,default}]]
                                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --boot_disk_image_id BOOT_DISK_IMAGE_ID
                        Provide Boot Disk Image Id to get information about a specific boot disk image configuration.
  --boot_disk_image_name BOOT_DISK_IMAGE_NAME
                        Provide Boot Disk Image Name to get information about a specific boot disk image configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format.(default: false)
```

- get-boot-disk-image-conf example with any one of the required arguments passed.

```bash
yeedu resource get-boot-disk-image-conf --boot_disk_image_id=1
```

- Console output

```bash
{
  "boot_disk_image_id": 1,
  "boot_disk_image_name": "yeedu_boot_disk_image",
  "description": null,
  "cloud_provider": {
    "cloud_provider_id": 0,
    "name": "gcp",
    "description": "Provider for creating infrastructure on Google Cloud Platform"
  },
  "linux_distro": {
    "linux_distro_id": 1,
    "distro_name": "UBUNTU",
    "distro_version": "20.04 LTS"
  },
  "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2024-01-05T10:09:27.590432+00:00",
  "from_date": "2024-01-05T10:09:27.590432+00:00",
  "to_date": "infinity"
}

```

### list-boot-disk-image-confs

```bash
yeedu resource list-boot-disk-image-confs -h
```

```bash
usage:  list-boot-disk-image-confs [-h]
                                   [--cloud_provider [{GCP,AWS,AZURE}]]
                                   [--page_number PAGE_NUMBER]
                                   [--limit LIMIT]
                                   [--json-output [{pretty,default}]]
                                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider [{GCP,AWS,AZURE}]
                        Provide cloud_provider to list all the related boot disk image configs for a specific Cloud Provider.
  --page_number PAGE_NUMBER
                        To list boot disk image configurations for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of boot disk image configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format.(default: false)
```

- list-boot-disk-image-confs example with an optional argument passed.

```bash
yeedu resource list-boot-disk-image-confs --cloud_provider="GCP"
```

- Console output

```bash
{
  "data": [
    {
      "boot_disk_image_id": 1,
      "boot_disk_image_name": "yeedu_boot_disk_image",
      "description": null,
      "cloud_provider": {
        "cloud_provider_id": 0,
        "name": "gcp",
        "description": "Provider for creating infrastructure on Google Cloud Platform"
      },
      "linux_distro": {
        "linux_distro_id": 0,
        "distro_name": "UBUNTU",
        "distro_version": "20.04 LTS"
      },
      "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-05T10:09:27.590432+00:00",
      "from_date": "2024-01-05T10:09:27.590432+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-boot-disk-image-confs

```bash
yeedu resource search-boot-disk-image-confs -h
```

```bash
usage:  search-boot-disk-image-confs [-h] --boot_disk_image_name
                                     BOOT_DISK_IMAGE_NAME
                                     [--cloud_provider [{GCP,AWS,AZURE}]]
                                     [--page_number PAGE_NUMBER]
                                     [--limit LIMIT]
                                     [--json-output [{pretty,default}]]
                                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --boot_disk_image_name BOOT_DISK_IMAGE_NAME
                        Provide Boot Disk Image Name to search information about all the related boot disk image configs.
  --cloud_provider [{GCP,AWS,AZURE}]
                        Provide cloud_provider to search all the related boot disk image configs for a specific Cloud Provider.
  --page_number PAGE_NUMBER
                        To list boot disk image configurations for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of boot disk image configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-boot-disk-image-confs example with the required argument '--boot_disk_image_name' passed.

```bash
yeedu resource search-boot-disk-image-confs --boot_disk_image_name="yeedu_"
```

- Console output

```bash
{
  "data": [
    {
      "boot_disk_image_id": 1,
      "boot_disk_image_name": "yeedu_boot_disk_image",
      "description": null,
      "cloud_provider": {
        "cloud_provider_id": 0,
        "name": "gcp",
        "description": "Provider for creating infrastructure on Google Cloud Platform"
      },
      "linux_distro": {
        "linux_distro_id": 0,
        "distro_name": "UBUNTU",
        "distro_version": "20.04 LTS"
      },
      "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-05T10:09:27.590432+00:00",
      "from_date": "2024-01-05T10:09:27.590432+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### edit-boot-disk-image-conf

```bash
yeedu resource edit-boot-disk-image-conf -h
```

```bash
usage:  edit-boot-disk-image-conf [-h] [--boot_disk_image_id BOOT_DISK_IMAGE_ID] [--boot_disk_image_name BOOT_DISK_IMAGE_NAME] [--name NAME]
                                  [--description DESCRIPTION] [--linux_distro_id LINUX_DISTRO_ID] [--boot_disk_image BOOT_DISK_IMAGE]
                                  [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --boot_disk_image_id BOOT_DISK_IMAGE_ID
                        Provide boot_disk_image_id to edit a specific boot disk image configuration.
  --boot_disk_image_name BOOT_DISK_IMAGE_NAME
                        Provide boot_disk_image_name to edit a specific boot disk image configuration.
  --name NAME           Provide name to edit a specific boot disk image configuration.
  --description DESCRIPTION
                        Provide description to edit a specific boot disk image configuration.
  --linux_distro_id LINUX_DISTRO_ID
                        Provide linux_distro_id to edit a specific boot disk image configuration.
  --boot_disk_image BOOT_DISK_IMAGE
                        Provide boot_disk_image to edit a specific boot disk image configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to edit output in YAML format. (default: false)
```

- edit-boot-disk-image-conf example with any one of the required argument '--boot_disk_image_id' and other optional argument is passed which is to be updated.

```bash
yeedu resource edit-boot-disk-image-conf --boot_disk_image_id=1 --description="dev boot disk"
```

- Console output

```bash
{
  "boot_disk_image_id": "1",
  "boot_disk_image_name": "yeedu_boot_disk_image",
  "description": "dev boot disk",
  "cloud_provider_id": 0,
  "linux_distro_id": 0,
  "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-05T10:22:54.395Z",
  "from_date": "2024-01-05T10:09:27.590Z",
  "to_date": null
}
```

### delete-boot-disk-image-conf

```bash
yeedu resource delete-boot-disk-image-conf -h
```

```bash
usage:  delete-boot-disk-image-conf [-h] [--boot_disk_image_id BOOT_DISK_IMAGE_ID] [--boot_disk_image_name BOOT_DISK_IMAGE_NAME]
                                    [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --boot_disk_image_id BOOT_DISK_IMAGE_ID
                        Provide boot_disk_image_id to delete a specific boot disk image configuration.
  --boot_disk_image_name BOOT_DISK_IMAGE_NAME
                        Provide boot_disk_image_name to delete a specific boot disk image configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to delete output in YAML format. (default: false)
```

- delete-boot-disk-image-conf example with any one of the required argument '--boot_disk_image_id' is passed which is to be deleted.

```bash
yeedu resource delete-boot-disk-image-conf --boot_disk_image_id=1
```

- Console output

```bash
{
  "message": "Deleted boot disk image configuration id: 1."
}
```

## Credentials Configuration

| Command Name                                       | Utility                                                           |
|----------------------------------------------------|-------------------------------------------------------------------|
|[create-credential-conf](#create-credential-conf)   | To create a Credential Configuration.                             |
|[list-credential-confs](#list-credential-confs)     | To list all the available Credential Configurations.              |
|[search-credential-confs](#search-credential-confs) | To search all the Credential Configurations based on name.        |
|[get-credential-conf](#get-credential-conf)         | To get the information about a specific Credential Configuration. |
|[edit-credential-conf](#edit-credential-conf)       | To edit a specific Credential Configuration.                      |
|[delete-credential-conf](#delete-credential-conf)   | To delete a specific Credential Configuration.                    |

### create-credential-conf

```bash
yeedu resource create-credential-conf -h
```

```bash
usage:  create-credential-conf [-h] --name NAME --credential_type_id CREDENTIAL_TYPE_ID
                               --base64_encoded_credentials BASE64_ENCODED_CREDENTIALS
                               [--json-output [{pretty,default}]]
                               [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create-credential-conf.
  --description DESCRIPTION
                        Provide description to create-credential-conf.
  --credential_type_id CREDENTIAL_TYPE_ID
                        Provide credential_type_id to create-credential-conf.
  --base64_encoded_credentials BASE64_ENCODED_CREDENTIALS
                        Provide base64_encoded_credentials to create-credential-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-credential-conf example with all the required arguments passed.

```bash
yeedu resource create-credential-conf  --name='modakyeedu-svc' --credential_type_id=0 --base64_encoded_credentials='ew0KICAieWVlZHVfY3JlZGVudGlhbHMiOiAiRHVtbXkgQ3JlZGVudGlhbHMgQ29uZmlndXJhdGlvbiINCn0'
```

- Console output

```bash
{
  "credentials_conf_id": "1",
  "name": "modakyeedu-svc",
  "description": null,
  "credential_type_id": "0",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-09-28T17:28:11.325Z",
  "from_date": "2023-09-28T17:28:11.325Z",
  "to_date": null
}
```

### list-credential-confs

```bash
yeedu resource list-credential-confs -h
```

```bash
usage:  list-credential-confs [-h] [--cloud_provider [{GCP,AWS,AZURE}]]
                              [--page_number PAGE_NUMBER] [--limit LIMIT]
                              [--json-output [{pretty,default}]]
                              [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider [{GCP,AWS,AZURE}]
                        Cloud Provider that will be used for filtering Credential
                        Configurations.
  --page_number PAGE_NUMBER
                        To list Credential Configurations for a specific page_number.
                        (default: 1)
  --limit LIMIT         Provide limit to list number of Credential Configurations.
                        (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-credential-confs example with optional arguments passed.

```bash
yeedu resource list-credential-confs --cloud_provider="GCP"
```

- Console output

```bash
{
  "data": [
    {
      "credentials_conf_id": 1,
      "credentials_conf_name": "modakyeedu-svc",
      "description": null,
      "credential_type": {
        "name": "gcp",
        "cloud_provider": {
          "name": "gcp",
          "description": "Provider for creating infrastructure on Google Cloud Platform"
        }
      },
      "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-09-28T17:28:11.325838+00:00",
      "from_date": "2023-09-28T17:28:11.325838+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-credential-confs

```bash
yeedu resource search-credential-confs -h
```

```bash
usage:  search-credential-confs [-h] --credentials_conf_name CREDENTIALS_CONF_NAME
                                [--cloud_provider [{GCP,AWS,AZURE}]]
                                [--page_number PAGE_NUMBER] [--limit LIMIT]
                                [--json-output [{pretty,default}]]
                                [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --credentials_conf_name CREDENTIALS_CONF_NAME
                        Provide credentials_conf_name to search credential
                        configuration.
  --cloud_provider [{GCP,AWS,AZURE}]
                        Cloud Provider that will be used for filtering Credential
                        Configurations.
  --page_number PAGE_NUMBER
                        To search Credential Configurations for a specific page_number.
                        (default: 1)
  --limit LIMIT         Provide limit to search number of Credential Configurations.
                        (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-credential-confs example with required argument '--credentials_conf_name' passed.

```bash
yeedu resource search-credential-confs --credentials_conf_name="modak"
```

- Console output

```bash
{
  "data": [
    {
      "credentials_conf_id": 1,
      "credentials_conf_name": "modakyeedu-svc",
      "description": null,
      "credential_type": {
        "name": "gcp",
        "cloud_provider": {
          "name": "gcp",
          "description": "Provider for creating infrastructure on Google Cloud Platform"
        }
      },
      "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-09-28T17:28:11.325838+00:00",
      "from_date": "2023-09-28T17:28:11.325838+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-credential-conf

```bash
yeedu resource get-credential-conf -h
```

```bash
usage:  get-credential-conf [-h] [--credentials_conf_id CREDENTIALS_CONF_ID]
                            [--credentials_conf_name CREDENTIALS_CONF_NAME]
                            [--json-output [{pretty,default}]]
                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --credentials_conf_id CREDENTIALS_CONF_ID
                        Provide credentials_conf_id to get information about a specific
                        credential configuration.
  --credentials_conf_name CREDENTIALS_CONF_NAME
                        Provide credentials_conf_name to get information about a
                        specific credential configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-credential-conf example with any one of the required '--credentials_conf_name' arguments passed.

```bash
yeedu resource get-credential-conf --credentials_conf_name=""
```

- Console output

```bash
{
  "credentials_conf_id": 1,
  "credentials_conf_name": "modakyeedu-svc",
  "description": null,
  "credential_type": {
    "name": "gcp",
    "cloud_provider": {
      "name": "gcp",
      "description": "Provider for creating infrastructure on Google Cloud Platform"
    }
  },
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2023-09-28T17:28:11.325838+00:00",
  "from_date": "2023-09-28T17:28:11.325838+00:00",
  "to_date": "infinity"
}
```

### edit-credential-conf

```bash
yeedu resource edit-credential-conf -h
```

```bash
usage:  edit-credential-conf [-h] [--credentials_conf_id CREDENTIALS_CONF_ID]
                             [--credentials_conf_name CREDENTIALS_CONF_NAME]
                             [--name NAME]
                             [--base64_encoded_credentials BASE64_ENCODED_CREDENTIALS]
                             [--json-output [{pretty,default}]]
                             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --credentials_conf_id CREDENTIALS_CONF_ID
                        Provide credentials_conf_id to edit a specific Credential Configuration.
  --credentials_conf_name CREDENTIALS_CONF_NAME
                        Provide credentials_conf_name to edit a specific Credential Configuration.
  --name NAME           Provide name to edit-credential-conf.
  --description DESCRIPTION
                        Provide description to edit-credential-conf.
  --base64_encoded_credentials BASE64_ENCODED_CREDENTIALS
                        Provide base64_encoded_credentials to edit-credential-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit-credential-conf example with any one of the required '--credentials_conf_id' argument and other optional argument is passed which is to be updated.

```bash
yeedu resource edit-credential-conf --credentials_conf_id=1 --name='modak-yeedu-svc'
```

- Console output

```bash
{
  "credentials_conf_id": "1",
  "name": "modak-yeedu-svc",
  "credential_type_id": "0",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-09-28T17:33:36.788Z",
  "from_date": "2023-09-28T17:28:11.325Z",
  "to_date": null
}
```

### delete-credential-conf

```bash
yeedu resource delete-credential-conf -h
```

```bash
usage:  delete-credential-conf [-h] [--credentials_conf_id CREDENTIALS_CONF_ID]
                               [--credentials_conf_name CREDENTIALS_CONF_NAME]
                               [--json-output [{pretty,default}]]
                               [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --credentials_conf_id CREDENTIALS_CONF_ID
                        Provide credentials_conf_id to delete a specific Credential
                        Configuration.
  --credentials_conf_name CREDENTIALS_CONF_NAME
                        Provide credentials_conf_name to delete a specific Credential
                        Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-credential-conf example with any one of the required '--credentials_conf_name' argument passed.

```bash
yeedu resource delete-credential-conf --credentials_conf_name="modak-yeedu-svc"
```

- Console output

```bash
{
  "message": "Deleted Credentials Configuration Name: 'modak-yeedu-svc'."
}
```

## Cloud Env

| Command Name                                                     | Utility                                                          |
|------------------------------------------------------------------|------------------------------------------------------------------|
|[create-cloud-env](#create-cloud-env)   | To create a Object Storage Manager.                              |
|[list-cloud-envs](#list-cloud-envs)     | To list all the available Object Storage Manager Configurations. |
|[search-cloud-envs](#search-cloud-envs) | To search Object Storage Manager Configurations.                 |
|[get-cloud-env](#get-cloud-env)         | To get information about a specific Object Storage Manager.      |
|[edit-cloud-env](#edit-cloud-env)       | To edit a specific Object Storage Manager Configuration.         |
|[delete-cloud-env](#delete-cloud-env)   | To delete a specific Object Storage Manager.                     |

### create-cloud-env

```bash
yeedu resource create-cloud-env -h
```

```bash
usage:  create-cloud-env [-h] --name NAME [--description DESCRIPTION]
                         --cloud_provider_id CLOUD_PROVIDER_ID
                         --availability_zone_id AVAILABILITY_ZONE_ID
                         --network_conf_id NETWORK_CONF_ID
                         --cloud_project CLOUD_PROJECT
                         --credential_config_id CREDENTIAL_CONFIG_ID
                         --boot_disk_image_id BOOT_DISK_IMAGE_ID
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create a cloud environment.
  --description DESCRIPTION
                        Provide description to create a cloud environment.
  --cloud_provider_id CLOUD_PROVIDER_ID
                        Provide cloud_provider_id to create a cloud environment.
  --availability_zone_id AVAILABILITY_ZONE_ID
                        Provide availability_zone_id to create a cloud environment.
  --network_conf_id NETWORK_CONF_ID
                        Provide network_conf_id to create a cloud environment.
  --cloud_project CLOUD_PROJECT
                        Provide cloud_project to create a cloud environment.
  --credential_config_id CREDENTIAL_CONFIG_ID
                        Provide credential_config_id to create a cloud environment.
  --boot_disk_image_id BOOT_DISK_IMAGE_ID
                        Provide boot_disk_image_id to create a cloud environment.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-cloud-env example with all the required arguments passed.

```bash
yeedu resource create-cloud-env --name="gcp_cloud_env" --cloud_provider_id=0 --availability_zone_id=75 --network_conf_id=1 --cloud_project="modak-nabu" --credential_config_id=1 --boot_disk_image_id=1
```

- Console output

```bash
{
  "cloud_env_id": "1",
  "name": "gcp_cloud_env",
  "description": null,
  "cloud_provider_id": "0",
  "availability_zone_id": "75",
  "network_conf_id": "1",
  "cloud_project": "modak-yeedu",
  "credential_config_id": "1",
  "boot_disk_image_id": "1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T09:07:25.748Z",
  "from_date": "2024-01-08T09:07:25.748Z",
  "to_date": null
}
```

### list-cloud-envs

```bash
yeedu resource list-cloud-envs -h
```

```bash
usage:  list-cloud-envs [-h] [--cloud_provider [{GCP,AWS,AZURE}]]
                        [--page_number PAGE_NUMBER] [--limit LIMIT]
                        [--json-output [{pretty,default}]]
                        [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider [{GCP,AWS,AZURE}]
                        Provide cloud_provider to list all the related cloud environments of a specific cloud provider.
  --page_number PAGE_NUMBER
                        To list cloud environments for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of cloud environments. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-cloud-envs example with an optional argument passed.

```bash
yeedu resource list-cloud-envs --cloud_provider="GCP"
```

- Console output

```bash
{
  "data": [
    {
      "cloud_env_id": 1,
      "cloud_env_name": "gcp_cloud_env",
      "description": "yeedu cloud environment",
      "cloud_provider": {
        "cloud_provider_id": 0,
        "name": "gcp",
        "description": "Provider for creating infrastructure on Google Cloud Platform"
      },
      "availability_zone": {
        "availability_zone_id": 75,
        "name": "us-central1-a",
        "region": "us-central1",
        "description": "Council Bluffs, Iowa, North America"
      },
      "network_config": {
        "network_conf_id": 1,
        "name": "yeedu_gcp_network",
        "description": null,
        "network_project_id": "modak-yeedu",
        "network_name": "modak-yeedu-vpc",
        "network_tags": [
          "yeedu",
          "iap-allow"
        ],
        "subnet": "custom-subnet-modak-yeedu",
        "availability_zone": {
          "availability_zone_id": 75,
          "name": "us-central1-a",
          "region": "us-central1",
          "description": "Council Bluffs, Iowa, North America"
        }
      },
      "cloud_project": "modak-yeedu",
      "credential_config": {
        "credential_conf_id": 1,
        "name": "modakyeedu-svc",
        "description": null,
        "credential_type": {
          "credential_type_id": 0,
          "name": "gcp"
        }
      },
      "boot_disk_image": {
        "boot_disk_image_id": 1,
        "name": "gcp_boot_disk",
        "description": "dev boot disk",
        "linux_distro": {
          "linux_distro_id": 0,
          "distro_name": "UBUNTU",
          "distro_version": "20.04 LTS"
        },
        "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-12-28T14:06:38.078294+00:00",
      "from_date": "2023-12-28T14:06:38.078294+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-cloud-envs

```bash
yeedu resource search-cloud-envs -h
```

```bash
usage:  search-cloud-envs [-h] --cloud_env_name CLOUD_ENV_NAME
                          [--cloud_provider [{GCP,AWS,AZURE}]]
                          [--page_number PAGE_NUMBER] [--limit LIMIT]
                          [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_env_name CLOUD_ENV_NAME
                        Provide cloud_env_name to search matching cloud environments.
  --cloud_provider [{GCP,AWS,AZURE}]
                        Provide cloud_provider to search all the related cloud environments of a specific cloud provider.
  --page_number PAGE_NUMBER
                        To list cloud environments for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of cloud environments. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-cloud-envs example with required argument '--cloud_env_name' passed.

```bash
yeedu resource search-cloud-envs --cloud_env_name="gcp_"
```

- Console output

```bash
{
  "data": [
    {
      "cloud_env_id": 1,
      "cloud_env_name": "gcp_cloud_env",
      "description": "yeedu cloud environment",
      "cloud_provider": {
        "cloud_provider_id": 0,
        "name": "gcp",
        "description": "Provider for creating infrastructure on Google Cloud Platform"
      },
      "availability_zone": {
        "availability_zone_id": 75,
        "name": "us-central1-a",
        "region": "us-central1",
        "description": "Council Bluffs, Iowa, North America"
      },
      "network_config": {
        "network_conf_id": 1,
        "name": "yeedu_gcp_network",
        "description": null,
        "network_project_id": "modak-yeedu",
        "network_name": "modak-yeedu-vpc",
        "network_tags": [
          "yeedu",
          "iap-allow"
        ],
        "subnet": "custom-subnet-modak-yeedu",
        "availability_zone": {
          "availability_zone_id": 75,
          "name": "us-central1-a",
          "region": "us-central1",
          "description": "Council Bluffs, Iowa, North America"
        }
      },
      "cloud_project": "modak-yeedu",
      "credential_config": {
        "credential_conf_id": 1,
        "name": "modakyeedu-svc",
        "description": null,
        "credential_type": {
          "credential_type_id": 0,
          "name": "gcp"
        }
      },
      "boot_disk_image": {
        "boot_disk_image_id": 1,
        "name": "gcp_boot_disk",
        "description": "dev boot disk",
        "linux_distro": {
          "linux_distro_id": 0,
          "distro_name": "UBUNTU",
          "distro_version": "20.04 LTS"
        },
        "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-12-28T14:06:38.078294+00:00",
      "from_date": "2023-12-28T14:06:38.078294+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-cloud-env

```bash
yeedu resource get-cloud-env -h
```

```bash
usage:  get-cloud-env [-h] [--cloud_env_id CLOUD_ENV_ID]
                      [--cloud_env_name CLOUD_ENV_NAME]
                      [--json-output [{pretty,default}]]
                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_env_id CLOUD_ENV_ID
                        Provide cloud_env_id to get detials about a specific cloud environment.
  --cloud_env_name CLOUD_ENV_NAME
                        Provide cloud_env_name to get detials about a specific cloud environment.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-cloud-env example with any one of the required argument passed.

```bash
yeedu resource get-cloud-env --cloud_env_id=1
```

- Console output

```bash
{
  "cloud_env_id": 1,
  "cloud_env_name": "gcp_cloud_env",
  "description": "yeedu cloud environment",
  "cloud_provider": {
    "cloud_provider_id": 0,
    "name": "gcp",
    "description": "Provider for creating infrastructure on Google Cloud Platform"
  },
  "availability_zone": {
    "availability_zone_id": 75,
    "name": "us-central1-a",
    "region": "us-central1",
    "description": "Council Bluffs, Iowa, North America"
  },
  "network_config": {
    "network_conf_id": 1,
    "name": "yeedu_gcp_network",
    "description": null,
    "network_project_id": "modak-yeedu",
    "network_name": "modak-yeedu-vpc",
    "network_tags": [
      "yeedu",
      "iap-allow"
    ],
    "subnet": "custom-subnet-modak-yeedu",
    "availability_zone": {
      "availability_zone_id": 75,
      "name": "us-central1-a",
      "region": "us-central1",
      "description": "Council Bluffs, Iowa, North America"
    }
  },
  "cloud_project": "modak-yeedu",
  "credential_config": {
    "credential_conf_id": 1,
    "name": "modakyeedu-svc",
    "description": null,
    "credential_type": {
      "credential_type_id": 0,
      "name": "gcp"
    }
  },
  "boot_disk_image": {
    "boot_disk_image_id": 1,
    "name": "gcp_boot_disk",
    "description": "dev boot disk",
    "linux_distro": {
      "linux_distro_id": 0,
      "distro_name": "UBUNTU",
      "distro_version": "20.04 LTS"
    },
    "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
  },
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2023-12-28T14:06:38.078294+00:00",
  "from_date": "2023-12-28T14:06:38.078294+00:00",
  "to_date": "infinity"
}
```

### edit-cloud-env

```bash
yeedu resource edit-cloud-env -h
```

```bash
usage:  edit-cloud-env [-h] [--cloud_env_id CLOUD_ENV_ID]
                       [--cloud_env_name CLOUD_ENV_NAME] [--name NAME]
                       [--description DESCRIPTION]
                       [--availability_zone_id AVAILABILITY_ZONE_ID]
                       [--network_conf_id NETWORK_CONF_ID]
                       [--cloud_project CLOUD_PROJECT]
                       [--credential_config_id CREDENTIAL_CONFIG_ID]
                       [--boot_disk_image_id BOOT_DISK_IMAGE_ID]
                       [--json-output [{pretty,default}]]
                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_env_id CLOUD_ENV_ID
                        Provide cloud_env_id to edit a specific cloud environment.
  --cloud_env_name CLOUD_ENV_NAME
                        Provide cloud_env_name to edit a specific cloud environment.
  --name NAME           Provide name to edit a specific cloud environment.
  --description DESCRIPTION
                        Provide description to edit a specific cloud environment.
  --availability_zone_id AVAILABILITY_ZONE_ID
                        Provide availability_zone_id to edit a specific cloud environment.
  --network_conf_id NETWORK_CONF_ID
                        Provide network_conf_id to edit a specific cloud environment.
  --cloud_project CLOUD_PROJECT
                        Provide cloud_project to edit a specific cloud environment.
  --credential_config_id CREDENTIAL_CONFIG_ID
                        Provide credential_config_id to edit a specific cloud environment.
  --boot_disk_image_id BOOT_DISK_IMAGE_ID
                        Provide boot_disk_image_id to edit a specific cloud environment.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to edit output in YAML format. (default: false)
```

- edit-cloud-env example with all the required arguments passed which needs to be updated.

```bash
yeedu resource edit-cloud-env --cloud_env_id=1 --name="gcp_cloud_env_dev"
```

- Console output

```bash
{
  "cloud_env_id": "1",
  "name": "gcp_cloud_env_dev",
  "description": null,
  "cloud_provider_id": "0",
  "availability_zone_id": "75",
  "network_conf_id": "1",
  "cloud_project": "modak-yeedu",
  "credential_config_id": "1",
  "boot_disk_image_id": "1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T09:07:25.748Z",
  "from_date": "2024-01-08T09:07:25.748Z",
  "to_date": null
}
```

### delete-cloud-env

```bash
yeedu resource delete-cloud-env -h
```

```bash
usage:  delete-cloud-env [-h] [--cloud_env_id CLOUD_ENV_ID]
                         [--cloud_env_name CLOUD_ENV_NAME]
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_env_id CLOUD_ENV_ID
                        Provide cloud_env_id to delete a specific cloud environment.
  --cloud_env_name CLOUD_ENV_NAME
                        Provide cloud_env_name to delete a specific cloud environment.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to delete output in YAML format. (default: false)
```

- delete-cloud-env example with any one of the required argument passed.

```bash
yeedu resource delete-cloud-env --cloud_env_id=1
```

- Console output

```bash
{
  "message": "Deleted cloud environment id: 1"
}
```

## Object Storage Manager

| Command Name                                                     | Utility                                                          |
|------------------------------------------------------------------|------------------------------------------------------------------|
|[create-object-storage-manager](#create-object-storage-manager)   | To create a Object Storage Manager.                              |
|[list-object-storage-managers](#list-object-storage-managers)     | To list all the available Object Storage Manager Configurations. |
|[search-object-storage-managers](#search-object-storage-managers) | To search Object Storage Manager Configurations.                 |
|[get-object-storage-manager](#get-object-storage-manager)         | To get information about a specific Object Storage Manager.      |
|[edit-object-storage-manager](#edit-object-storage-manager)       | To edit a specific Object Storage Manager Configuration.         |
|[delete-object-storage-manager](#delete-object-storage-manager)   | To delete a specific Object Storage Manager.                     |

### create-object-storage-manager

```bash
yeedu resource create-object-storage-manager -h
```

```bash
usage:  create-object-storage-manager [-h] --name NAME
                                      [--description DESCRIPTION]
                                      --credentials_conf_id
                                      CREDENTIALS_CONF_ID
                                      --object_storage_bucket_name
                                      OBJECT_STORAGE_BUCKET_NAME
                                      [--json-output [{pretty,default}]]
                                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create-object-storage-manager.
  --description DESCRIPTION
                        Provide description to create-object-storage-manager.
  --credentials_conf_id CREDENTIALS_CONF_ID
                        Provide credentials_conf_id to create-object-storage-manager.
  --object_storage_bucket_name OBJECT_STORAGE_BUCKET_NAME
                        Provide object_storage_bucket_name to create-object-storage-manager.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-object-storage-manager example with all the required arguments passed.

```bash
yeedu resource create-object-storage-manager --name="yeedu_osm" --credentials_conf_id=1 --object_storage_bucket_name="modak-yeedu-nabu"
```

- Console output

```bash
{
  "object_storage_manager_id": "1",
  "name": "yeedu_object_storage_manager",
  "description": null,
  "credentials_conf_id": "1",
  "object_storage_bucket_name": "modak-yeedu-nabu",
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T09:32:24.643Z",
  "from_date": "2024-01-08T09:32:24.643Z",
  "to_date": null
}
```

### list-object-storage-managers

```bash
yeedu resource list-object-storage-managers -h
```

```bash
usage:  list-object-storage-managers [-h] [--cloud_provider [{GCP,AWS,AZURE}]]
                                     [--page_number PAGE_NUMBER] [--limit LIMIT]
                                     [--json-output [{pretty,default}]]
                                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider [{GCP,AWS,AZURE}]
                        Cloud Provider that will be used for filtering list.
  --page_number PAGE_NUMBER
                        To list Object Storage Managers for a specific page_number.
                        (default: 1)
  --limit LIMIT         Provide limit to list number of Object Storage Managers.
                        (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-object-storage-managers example with an optional argument passed.

```bash
yeedu resource list-object-storage-managers --cloud_provider="GCP"
```

- Console output

```bash
{
  "data": [
    {
      "object_storage_manager_id": 1,
      "object_storage_manager_name": "yeedu_object_storage_manager",
      "description": null,
      "object_storage_bucket_name": "modak-yeedu-nabu",
      "credentials_config": {
        "credentials_conf_id": 1,
        "description": null,
        "name": "modakyeedu-svc",
        "credential_type": {
          "credential_type_id": 0,
          "name": "gcp",
          "cloud_provider": {
            "name": "gcp",
            "description": "Provider for creating infrastructure on Google Cloud Platform"
          }
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-04T09:11:38.51+00:00",
      "from_date": "2023-12-28T14:05:05.328617+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-object-storage-managers

```bash
yeedu resource search-object-storage-managers -h
```

```bash
usage:  search-object-storage-managers [-h]
                                       --object_storage_manager_name
                                       OBJECT_STORAGE_MANAGER_NAME
                                       [--cloud_provider [{GCP,AWS,AZURE}]]
                                       [--page_number PAGE_NUMBER]
                                       [--limit LIMIT]
                                       [--json-output [{pretty,default}]]
                                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide Object Storage Manager Name to search information about a specific Object Storage Manager.
  --cloud_provider [{GCP,AWS,AZURE}]
                        Cloud Provider that will be used for filtering list.
  --page_number PAGE_NUMBER
                        To search Object Storage Managers for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of Object Storage Managers. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-object-storage-managers example with required argument '--object_storage_manager_name' passed.

```bash
yeedu resource search-object-storage-managers --object_storage_manager_name="gcp_"
```

- Console output

```bash
{
  "data": [
    {
      "object_storage_manager_id": 1,
      "object_storage_manager_name": "yeedu_object_storage_manager",
      "description": null,
      "object_storage_bucket_name": "modak-yeedu-nabu",
      "credentials_config": {
        "credentials_conf_id": 1,
        "description": null,
        "name": "modakyeedu-svc",
        "credential_type": {
          "credential_type_id": 0,
          "name": "gcp",
          "cloud_provider": {
            "name": "gcp",
            "description": "Provider for creating infrastructure on Google Cloud Platform"
          }
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-04T09:11:38.51+00:00",
      "from_date": "2023-12-28T14:05:05.328617+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-object-storage-manager

```bash
yeedu resource get-object-storage-manager -h
```

```bash
usage:  get-object-storage-manager [-h]
                                   [--object_storage_manager_id OBJECT_STORAGE_MANAGER_ID]
                                   [--object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME]
                                   [--json-output [{pretty,default}]]
                                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide Object Storage Manager Id to get information about a specific Object Storage Manager.
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide Object Storage Manager Name to get information about a specific Object Storage Manager.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-object-storage-manager example with any one of the required argument passed.

```bash
yeedu resource get-object-storage-manager --object_storage_manager_id=1
```

- Console output

```bash
{
  "object_storage_manager_id": 1,
  "object_storage_manager_name": "yeedu_object_storage_manager",
  "description": null,
  "object_storage_bucket_name": "modak-yeedu-nabu",
  "credentials_config": {
    "credentials_conf_id": 1,
    "description": null,
    "name": "modakyeedu-svc",
    "credential_type": {
      "credential_type_id": 0,
      "name": "gcp",
      "cloud_provider": {
        "name": "gcp",
        "description": "Provider for creating infrastructure on Google Cloud Platform"
      }
    }
  },
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2024-01-04T09:11:38.51+00:00",
  "from_date": "2023-12-28T14:05:05.328617+00:00",
  "to_date": "infinity"
}
```

### edit-object-storage-manager

```bash
yeedu resource edit-object-storage-manager -h
```

```bash
usage:  edit-object-storage-manager [-h] [--object_storage_manager_id OBJECT_STORAGE_MANAGER_ID]
                                    [--object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME] [--name NAME] [--description DESCRIPTION]
                                    [--credentials_conf_id CREDENTIALS_CONF_ID] [--object_storage_bucket_name OBJECT_STORAGE_BUCKET_NAME]
                                    [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide object_storage_manager_id to edit information about a specific Object Storage Manager.
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide object_storage_manager_name to edit information about a specific Object Storage Manager.
  --name NAME           Provide name to edit-object-storage-manager.
  --description DESCRIPTION
                        Provide description to edit-object-storage-manager.
  --credentials_conf_id CREDENTIALS_CONF_ID
                        Provide credentials_conf_id to edit-object-storage-manager.
  --object_storage_bucket_name OBJECT_STORAGE_BUCKET_NAME
                        Provide object_storage_bucket_name to edit-object-storage-manager.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit-object-storage-manager example with all the required arguments passed which needs to be updated.

```bash
yeedu resource edit-object-storage-manager --object_storage_manager_id=1 --name="yeedu_object_storage_manager"
```

- Console output

```bash
{
  "object_storage_manager_id": "1",
  "name": "yeedu_object_storage_manager",
  "description": null,
  "credentials_conf_id": "1",
  "object_storage_bucket_name": "modak-yeedu-nabu",
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T09:32:24.643Z",
  "from_date": "2024-01-08T09:32:24.643Z",
  "to_date": null
}
```

### delete-object-storage-manager

```bash
yeedu resource delete-object-storage-manager -h
```

```bash
usage:  delete-object-storage-manager [-h] [--object_storage_manager_id OBJECT_STORAGE_MANAGER_ID]
                                      [--object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME] [--json-output [{pretty,default}]]
                                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide object_storage_manager_id to delete a specific Object Storage Manager.
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide object_storage_manager_name to delete a specific Object Storage Manager.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-object-storage-manager example with any one of the required argument passed.

```bash
yeedu resource delete-object-storage-manager --object_storage_manager_name="yeedu_object_storage_manager"
```

- Console output

```bash
{
  "message": "Deleted Object Storage Manager Configuration Name: 'yeedu_object_storage_manager'."
}
```

## Object Storage Manager Files

| Command Name                                                               | Utility                                                          |
|----------------------------------------------------------------------------|------------------------------------------------------------------|
|[create-object-storage-manager-file](#create-object-storage-manager-file)   | To create a Object Storage Manager Files.                        |
|[list-object-storage-manager-files](#list-object-storage-manager-files)     | To list all the available Object Storage Manager Files.          |
|[search-object-storage-manager-files](#search-object-storage-manager-files) | To search all the available Object Storage Manager Files.        |
|[get-object-storage-manager-file](#get-object-storage-manager-file)         | To get information about a specific Object Storage Manager File. |
|[delete-object-storage-manager-file](#delete-object-storage-manager-file)   | To delete a specific Object Storage Manager File.                |

### create-object-storage-manager-file

```bash
yeedu resource create-object-storage-manager-file -h
```

```bash
usage:  create-object-storage-manager-file [-h] [--object_storage_manager_id OBJECT_STORAGE_MANAGER_ID]
                                           [--object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME] --local_file_path LOCAL_FILE_PATH
                                           [--cluster_id CLUSTER_ID] [--cluster_name CLUSTER_NAME] [--overwrite [{true,false}]]
                                           [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide Object Storage Manager Id to create-object-storage-manager-file.
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide Object Storage Manager Name to to create-object-storage-manager-file.
  --local_file_path LOCAL_FILE_PATH
                        Provide local_file_path to create-object-storage-manager-file.
  --cluster_id CLUSTER_ID
                        Provide Cluster Instance Id [OPTIONAL] to check permissions before create-object-storage-manager-file.
  --cluster_name CLUSTER_NAME
                        Provide Cluster Instance Name [OPTIONAL] to check permissions before create-object-storage-manager-file.
  --overwrite [{true,false}]
                        Provide overwrite to create-object-storage-manager-file. (default: false)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-object-storage-manager-file example with all the required arguments passed.

```bash
yeedu resource create-object-storage-manager-file --object_storage_manager_id=1 --local_file_path='/home/user/Downloads/spark-examples_2.12-3.2.2.jar'
```

- Console output

```bash
{
  "object_storage_manager_file_id": "1",
  "object_storage_manager_id": "1",
  "file_name": "spark-examples_2.11-2.4.8.jar",
  "full_file_path": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
  "file_size_bytes": "2017856",
  "file_type": "jar",
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T09:58:48.760Z",
  "from_date": "2024-01-08T09:58:48.760Z",
  "to_date": null
}
```

### list-object-storage-manager-files

```bash
yeedu resource list-object-storage-manager-files -h
```

```bash
usage:  list-object-storage-manager-files [-h] [--object_storage_manager_id OBJECT_STORAGE_MANAGER_ID]
                                          [--object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME] [--page_number PAGE_NUMBER]
                                          [--limit LIMIT] [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide Object Storage Manager Id to list all the available Object Storage Manager Files.
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide Object Storage Manager Name to list all the available Object Storage Manager Files.
  --page_number PAGE_NUMBER
                        To list Object Storage Manager Files for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Object Storage Manager Files. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-object-storage-manager-files example with any one of the required argument passed.

```bash
yeedu resource list-object-storage-manager-files --object_storage_manager_name="yeedu_object_storage_manager"
```

- Console output

```bash
{
  "data": [
    {
      "object_storage_manager_file_id": 1,
      "object_storage_manager": {
        "object_storage_manager_id": 1,
        "object_storage_manager_name": "yeedu_object_storage_manager",
        "description": null,
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modak-yeedu-svc",
          "description": null,
          "credential_type": {
            "name": "gcp",
            "description": "Provider for creating infrastructure on Google Cloud Platform"
          }
        },
        "object_storage_bucket_name": "modak-yeedu-nabu"
      },
      "file_name": "spark-examples_2.12-3.2.2.jar",
      "full_file_path": "file:///yeedu/object-storage-manager/spark-examples_2.12-3.2.2.jar",
      "file_size_bytes": "1560870",
      "file_type": "jar",
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-08T09:58:48.760362+00:00",
      "from_date": "2024-01-08T09:58:48.760362+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-object-storage-manager-files

```bash
yeedu resource search-object-storage-manager-files -h
```

```bash
usage:  search-object-storage-manager-files [-h] --file_name FILE_NAME
                                            [--object_storage_manager_id OBJECT_STORAGE_MANAGER_ID]
                                            [--object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME]
                                            [--page_number PAGE_NUMBER]
                                            [--limit LIMIT]
                                            [--json-output [{pretty,default}]]
                                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --file_name FILE_NAME
                        Provide File Name to search all the available Object Storage Manager Files.
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide Object Storage Manager Id to search all the available Object Storage Manager Files.
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide Object Storage Manager Name to search all the available Object Storage Manager Files.
  --page_number PAGE_NUMBER
                        To search Object Storage Manager Files for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of Object Storage Manager Files. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-object-storage-manager-files example with any one of the required argument passed.

```bash
yeedu resource search-object-storage-manager-files --object_storage_manager_name="yeedu_object_storage_manager" --file_name="spark-examples_"
```

- Console output

```bash
{
  "data": [
    {
      "object_storage_manager_file_id": 1,
      "object_storage_manager": {
        "object_storage_manager_id": 1,
        "object_storage_manager_name": "yeedu_object_storage_manager",
        "description": null,
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modak-yeedu-svc",
          "description": null,
          "credential_type": {
            "name": "gcp",
            "description": "Provider for creating infrastructure on Google Cloud Platform"
          }
        },
        "object_storage_bucket_name": "modak-yeedu-nabu"
      },
      "file_name": "spark-examples_2.12-3.2.2.jar",
      "full_file_path": "file:///yeedu/object-storage-manager/spark-examples_2.12-3.2.2.jar",
      "file_size_bytes": "1560870",
      "file_type": "jar",
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-08T09:58:48.760362+00:00",
      "from_date": "2024-01-08T09:58:48.760362+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-object-storage-manager-file

```bash
yeedu resource get-object-storage-manager-file -h
```

```bash
usage:  get-object-storage-manager-file [-h] [--object_storage_manager_id OBJECT_STORAGE_MANAGER_ID]
                                        [--object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME] [--file_id FILE_ID] [--file_name FILE_NAME]
                                        [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide Object Storage Manager Id to get information about a specific Object Storage Manager Files.
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide Object Storage Manager Name to get information about a specific Object Storage Manager Files.
  --file_id FILE_ID     Provide File Id to get information about a specific Object Storage Manager Files.
  --file_name FILE_NAME
                        Provide File Name to get information about a specific Object Storage Manager Files.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-object-storage-manager-file example with any one of the required arguments passed.

```bash
yeedu resource get-object-storage-manager-file --object_storage_manager_id=1 --file_id=1
```

- Console output

```bash
{
  "object_storage_manager_file_id": 1,
  "object_storage_manager": {
    "object_storage_manager_id": 1,
    "object_storage_manager_name": "yeedu_object_storage_manager",
    "description": null,
    "credentials_config": {
      "credential_config_id": 1,
      "name": "modak-yeedu-svc",
      "description": null,
      "credential_type": {
        "name": "gcp",
        "description": "Provider for creating infrastructure on Google Cloud Platform"
      }
    },
    "object_storage_bucket_name": "modak-yeedu-nabu"
  },
  "file_name": "spark-examples_2.12-3.2.2.jar",
  "full_file_path": "file:///yeedu/object-storage-manager/spark-examples_2.12-3.2.2.jar",
  "file_size_bytes": "1560870",
  "file_type": "jar",
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2024-01-08T09:58:48.760362+00:00",
  "from_date": "2024-01-08T09:58:48.760362+00:00",
  "to_date": "infinity"
}
```

### delete-object-storage-manager-file

```bash
yeedu resource delete-object-storage-manager-file -h
```

```bash
usage:  delete-object-storage-manager-file [-h] [--object_storage_manager_id OBJECT_STORAGE_MANAGER_ID]
                                           [--object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME] [--file_id FILE_ID]
                                           [--file_name FILE_NAME] [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide Object Storage Manager Id to delete a specific Object Storage Manager File.
  --object_storage_manager_name OBJECT_STORAGE_MANAGER_NAME
                        Provide Object Storage Manager Name to delete a specific Object Storage Manager File.
  --file_id FILE_ID     Provide File Id to delete a specific Object Storage Manager Files.
  --file_name FILE_NAME
                        Provide File Name to delete a specific Object Storage Manager Files.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-object-storage-manager-file example with any one of the required arguments passed.

```bash
yeedu resource delete-object-storage-manager-file --object_storage_manager_id=1 --file_id=1
```

- Console output

```bash
{
  "message": "The File: 'spark-examples_2.12-3.2.2.jar' has been deleted."
}
```

## Hive Metastore Configuration

| Command Name                                               | Utility                                                               |
|------------------------------------------------------------|-----------------------------------------------------------------------|
|[create-hive-metastore-conf](#create-hive-metastore-conf)   | To create a Hive Metastore Configuration.                             |
|[list-hive-metastore-confs](#list-hive-metastore-confs)     | To list all the available Hive Metastore Configurations.              |
|[search-hive-metastore-confs](#search-hive-metastore-confs) | To list all the available Hive Metastore Configurations.              |
|[get-hive-metastore-conf](#get-hive-metastore-conf)         | To get the information about a specific Hive Metastore Configuration. |
|[edit-hive-metastore-conf](#edit-hive-metastore-conf)       | To edit a specific Hive Metastore Configuration.                      |
|[delete-hive-metastore-conf](#delete-hive-metastore-conf)   | To delete a specific Hive Metastore Configuration.                    |

### create-hive-metastore-conf

```bash
yeedu resource create-hive-metastore-conf -h
```

```bash
usage:  create-hive-metastore-conf [-h] --name NAME
                                   [--hive_site_xml_file_path HIVE_SITE_XML_FILE_PATH]
                                   [--core_site_xml_file_path CORE_SITE_XML_FILE_PATH]
                                   [--hdfs_site_xml_file_path HDFS_SITE_XML_FILE_PATH]
                                   [--krb5_conf_file_path KRB5_CONF_FILE_PATH]
                                   [--json-output [{pretty,default}]]
                                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create-hive-metastore-conf.
  --hive_site_xml_file_path HIVE_SITE_XML_FILE_PATH
                        Provide hive_site_xml_file_path to create-hive-metastore-conf.
  --core_site_xml_file_path CORE_SITE_XML_FILE_PATH
                        Provide core_site_xml_file_path to create-hive-metastore-conf.
  --hdfs_site_xml_file_path HDFS_SITE_XML_FILE_PATH
                        Provide hdfs_site_xml_file_path to create-hive-metastore-conf.
  --krb5_conf_file_path KRB5_CONF_FILE_PATH
                        Provide krb5_conf_file_path to create-hive-metastore-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-hive-metastore-conf example with all the required arguments passed.

```bash
yeedu resource create-hive-metastore-conf --name="yeedu_hive_conf" --hive_site_xml_file_path="/home/user/Documents/hive-site.xml" --core_site_xml_file_path="/home/user/Documents/core-site.xml" --hdfs_site_xml_file_path="/home/user/Documents/hdfs-site.xml"
```

- Console output

```bash
{
  "hive_metastore_conf_id": "1",
  "name": "yeedu_hive_conf",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-09-29T07:37:52.309Z",
  "from_date": "2023-09-29T07:37:52.309Z",
  "to_date": null
}
```

### list-hive-metastore-confs

```bash
yeedu resource list-hive-metastore-confs -h
```

```bash
usage:  list-hive-metastore-confs [-h] [--page_number PAGE_NUMBER] [--limit LIMIT]
                                  [--json-output [{pretty,default}]]
                                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --page_number PAGE_NUMBER
                        To list Hive Metastore Configurations for a specific
                        page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Hive Metastore Configurations.
                        (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-hive-metastore-confs example without any optional argument passed for output format.

```bash
yeedu resource list-hive-metastore-confs
```

- Console output

```bash
{
  "data": [
    {
      "hive_metastore_conf_id": 1,
      "hive_metastore_conf_name": "yeedu_hive_conf",
      "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-09-29T07:37:52.309654+00:00",
      "from_date": "2023-09-29T07:37:52.309654+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-hive-metastore-confs

```bash
yeedu resource search-hive-metastore-confs -h
```

```bash
usage:  search-hive-metastore-confs [-h] --hive_metastore_conf_name
                                    HIVE_METASTORE_CONF_NAME [--page_number PAGE_NUMBER]
                                    [--limit LIMIT] [--json-output [{pretty,default}]]
                                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --hive_metastore_conf_name HIVE_METASTORE_CONF_NAME
                        Provide hive_metastore_conf_name to search information about
                        Hive Metastore Configurations.
  --page_number PAGE_NUMBER
                        To search Hive Metastore Configurations for a specific
                        page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of Hive Metastore Configurations.
                        (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-hive-metastore-confs example with required argument '--hive_metastore_conf_name' passed.

```bash
yeedu resource search-hive-metastore-confs --hive_metastore_conf_name="yeedu_"
```

- Console output

```bash
{
  "data": [
    {
      "hive_metastore_conf_id": 1,
      "hive_metastore_conf_name": "yeedu_hive_conf",
      "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-09-29T07:37:52.309654+00:00",
      "from_date": "2023-09-29T07:37:52.309654+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-hive-metastore-conf

```bash
yeedu resource get-hive-metastore-conf -h
```

```bash
usage:  get-hive-metastore-conf [-h] [--hive_metastore_conf_id HIVE_METASTORE_CONF_ID]
                                [--hive_metastore_conf_name HIVE_METASTORE_CONF_NAME]
                                [--json-output [{pretty,default}]]
                                [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --hive_metastore_conf_id HIVE_METASTORE_CONF_ID
                        Provide hive_metastore_conf_id to get information about a
                        specific Hive Metastore Configuration.
  --hive_metastore_conf_name HIVE_METASTORE_CONF_NAME
                        Provide hive_metastore_conf_name to get information about a
                        specific Hive Metastore Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-hive-metastore-conf example with any one of the required '--hive_metastore_conf_id' argument passed.

```bash
yeedu resource get-hive-metastore-conf --hive_metastore_conf_id=1
```

- Console output

```bash
{
  "hive_metastore_conf_id": 1,
  "hive_metastore_conf_name": "yeedu_hive_conf",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2023-09-29T07:37:52.309654+00:00",
  "from_date": "2023-09-29T07:37:52.309654+00:00",
  "to_date": "infinity"
}
```

### edit-hive-metastore-conf

```bash
yeedu resource edit-hive-metastore-conf -h
```

```bash
usage:  edit-hive-metastore-conf [-h] [--hive_metastore_conf_id HIVE_METASTORE_CONF_ID]
                                 [--hive_metastore_conf_name HIVE_METASTORE_CONF_NAME]
                                 [--name NAME]
                                 [--hive_site_xml_file_path HIVE_SITE_XML_FILE_PATH]
                                 [--core_site_xml_file_path CORE_SITE_XML_FILE_PATH]
                                 [--hdfs_site_xml_file_path HDFS_SITE_XML_FILE_PATH]
                                 [--krb5_conf_file_path KRB5_CONF_FILE_PATH]
                                 [--json-output [{pretty,default}]]
                                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --hive_metastore_conf_id HIVE_METASTORE_CONF_ID
                        Provide a specific hive_metastore_conf_id to edit-hive-
                        metastore-conf.
  --hive_metastore_conf_name HIVE_METASTORE_CONF_NAME
                        Provide a specific hive_metastore_conf_name to edit-hive-
                        metastore-conf.
  --name NAME           Provide name to edit-hive-metastore-conf.
  --hive_site_xml_file_path HIVE_SITE_XML_FILE_PATH
                        Provide hive_site_xml_file_path to edit-hive-metastore-conf.
  --core_site_xml_file_path CORE_SITE_XML_FILE_PATH
                        Provide core_site_xml_file_path to edit-hive-metastore-conf.
  --hdfs_site_xml_file_path HDFS_SITE_XML_FILE_PATH
                        Provide hdfs_site_xml_file_path to edit-hive-metastore-conf.
  --krb5_conf_file_path KRB5_CONF_FILE_PATH
                        Provide krb5_conf_file_path to edit-hive-metastore-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit-hive-metastore-conf example with any one of the required '--hive_metastore_conf_id' argument and other optional argument is passed which is to be updated.

```bash
yeedu resource edit-hive-metastore-conf --hive_metastore_conf_id=1 --krb5_conf_file_path="/home/user/Documents/krb5.conf"
```

- Console output

```bash
{
  "hive_metastore_conf_id": "1",
  "hive_metastore_conf_name": "yeedu_hive_conf",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-09-29T07:46:42.929Z",
  "from_date": "2023-09-29T07:37:52.309Z",
  "to_date": null
}
```

### delete-hive-metastore-conf

```bash
yeedu resource delete-hive-metastore-conf -h
```

```bash
usage:  delete-hive-metastore-conf [-h]
                                   [--hive_metastore_conf_id HIVE_METASTORE_CONF_ID]
                                   [--hive_metastore_conf_name HIVE_METASTORE_CONF_NAME]
                                   [--json-output [{pretty,default}]]
                                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --hive_metastore_conf_id HIVE_METASTORE_CONF_ID
                        Provide hive_metastore_conf_id to delete a specific Hive
                        Metastore Configuration.
  --hive_metastore_conf_name HIVE_METASTORE_CONF_NAME
                        Provide hive_metastore_conf_name to delete a specific Hive
                        Metastore Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-hive-metastore-conf example with any one of the required argument '--hive_metastore_conf_id' passed.

```bash
yeedu resource delete-hive-metastore-conf --hive_metastore_conf_id=1
```

- Console output

```bash
{
  "message": "Deleted Hive Metastore Configuration Id: 1"
}
```

# Cluster

## Cluster Configuration

| Command Name                 | Utility                                                        |
|------------------------------|----------------------------------------------------------------|
|[create-conf](#create-conf)   | To create the Cluster Configuration.                           |
|[list-confs](#list-confs)     | To list all the available Cluster Configurations.              |
|[search-confs](#search-confs) | To search all the available Cluster Configurations.            |
|[get-conf](#get-conf)         | To get the information about a specific Cluster Configuration. |
|[edit-conf](#edit-conf)       | To edit a specific Cluster Configuration.                      |
|[delete-conf](#delete-conf)   | To delete a specific Cluster Configuration.                      |

### create-conf

```bash
yeedu cluster create-conf -h
```

```bash
usage:  create-conf [-h] --name NAME [--description DESCRIPTION]
                    --machine_type_category_id
                    MACHINE_TYPE_CATEGORY_ID --machine_type_id
                    MACHINE_TYPE_ID --volume_conf_id VOLUME_CONF_ID
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create-conf.
  --description DESCRIPTION
                        Provide description to create-conf.
  --machine_type_category_id MACHINE_TYPE_CATEGORY_ID
                        Provide machine_category_type_id to create_cluster_conf.
  --machine_type_id MACHINE_TYPE_ID
                        Provide machine_type_id to create_cluster_conf.
  --volume_conf_id VOLUME_CONF_ID
                        Provide volume_conf_id to create_cluster_conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-conf example with all the required arguments passed.

```bash
yeedu cluster create-conf --name="yeedu_cluster_config" --description="Cluster Configurations test" --machine_type_id=64 --machine_type_category_id=2 --volume_conf_id=1
```

- Console output

```bash
{
  "cluster_conf_id": "1",
  "name": "yeedu_cluster_config",
  "description": "Cluster Configurations test",
  "machine_type_category_id": "2",
  "machine_type_id": "64",
  "volume_conf_id": "1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-09-29T07:51:12.575Z",
  "from_date": "2023-09-29T07:51:12.575Z",
  "to_date": null
}
```

### list-confs

```bash
yeedu cluster list-confs -h
```

```bash
usage:  list-confs [-h] [--cloud_provider [{GCP,AWS,AZURE}]]
                   [--compute_type [{compute_optimized,memory_optimized,general_purpose,storage_optimized,gpu_accelerated}]]
                   [--page_number PAGE_NUMBER] [--limit LIMIT] [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cloud_provider [{GCP,AWS,AZURE}]
                        Provide specific cloud_provider_id to get information about related Cluster Configuration.
  --compute_type [{compute_optimized,memory_optimized,general_purpose,storage_optimized,gpu_accelerated}]
                        Provide specific compute_type to get information about related Cluster Configuration.
  --page_number PAGE_NUMBER
                        To list Cluster Configuration for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Cluster Configuration. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-confs example with optional arguments passed.

```bash
yeedu cluster list-confs --cloud_provider="GCP" --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "cluster_conf_id": 1,
      "cluster_conf_name": "yeedu_cluster_config",
      "description": "Cluster Configurations test",
      "machine_type_category": "general_purpose",
      "machine_type": {
        "machine_type_id": 64,
        "name": "n1-standard-4",
        "vcpus": 4,
        "memory": "15 GiB",
        "has_cuda": false,
        "gpu_model": null,
        "gpus": null,
        "gpu_memory": null,
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        }
      },
      "machine_volume_conf": {
        "volume_conf_id": 1,
        "name": "volume_gcp_1",
        "encrypted": true,
        "size": 375,
        "disk_type": {
          "disk_type_id": 4,
          "name": "local-ssd",
          "has_fixed_size": true,
          "min_size": 375,
          "max_size": 375,
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          }
        },
        "machine_volume_num": 1,
        "machine_volume_strip_num": 1
      },
      "disk_num": 1,
      "disk_size": 375,
      "machine_price_ycu": 2.17,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-08T10:20:19.399039+00:00",
      "from_date": "2024-01-08T10:20:19.399039+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 1
  }
}
```

### search-confs

```bash
yeedu cluster search-confs -h
```

```bash
usage:  search-confs [-h] --cluster_conf_name CLUSTER_CONF_NAME
                     [--compute_type {compute_optimized,memory_optimized,general_purpose,storage_optimized,gpu_accelerated}]
                     [--cloud_provider [{GCP,AWS,AZURE}]] [--page_number PAGE_NUMBER] [--limit LIMIT] [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_conf_name CLUSTER_CONF_NAME
                        Provide Cluster Config Name to search Cluster Configurations.
  --compute_type {compute_optimized,memory_optimized,general_purpose,storage_optimized,gpu_accelerated}
                        Provide specific compute type to search information about related Cluster Configuration.
  --cloud_provider [{GCP,AWS,AZURE}]
                        Provide specific cloud_provider_id to search information about related Cluster Configuration.
  --page_number PAGE_NUMBER
                        To search Cluster Configuration for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of Cluster Configuration. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-confs example with required argument '--cluster_conf_name' passed.

```bash
yeedu cluster search-confs --cluster_conf_name="yeedu_"
```

- Console output

```bash
{
  "data": [
    {
      "cluster_conf_id": 1,
      "cluster_conf_name": "yeedu_cluster_config",
      "description": "Cluster Configurations test",
      "machine_type_category": "general_purpose",
      "machine_type": {
        "machine_type_id": 64,
        "name": "n1-standard-4",
        "vcpus": 4,
        "memory": "15 GiB",
        "has_cuda": false,
        "gpu_model": null,
        "gpus": null,
        "gpu_memory": null,
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        }
      },
      "machine_volume_conf": {
        "volume_conf_id": 1,
        "name": "volume_gcp_1",
        "encrypted": true,
        "size": 375,
        "disk_type": {
          "disk_type_id": 4,
          "name": "local-ssd",
          "has_fixed_size": true,
          "min_size": 375,
          "max_size": 375,
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          }
        },
        "machine_volume_num": 1,
        "machine_volume_strip_num": 1
      },
      "disk_num": 1,
      "disk_size": 375,
      "machine_price_ycu": 2.17,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-08T10:20:19.399039+00:00",
      "from_date": "2024-01-08T10:20:19.399039+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 1
  }
}
```

### get-conf

```bash
yeedu cluster get-conf -h
```

```bash
usage:  get-conf [-h] [--cluster_conf_id CLUSTER_CONF_ID]
                 [--cluster_conf_name CLUSTER_CONF_NAME]
                 [--json-output [{pretty,default}]]
                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_conf_id CLUSTER_CONF_ID
                        Provide Cluster Config Id to get information about a specific Cluster Configuration.
  --cluster_conf_name CLUSTER_CONF_NAME
                        Provide Cluster Config Name to get information about a specific Cluster Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-conf example with any one of the required argument '--cluster_conf_id' passed.

```bash
yeedu cluster get-conf --cluster_conf_id=1
```

- Console output

```bash
{
  "cluster_conf_id": 1,
  "cluster_conf_name": "yeedu_cluster_config",
  "description": "Cluster Configurations test",
  "machine_type_category": "general_purpose",
  "machine_type": {
    "machine_type_id": 64,
    "name": "n1-standard-4",
    "vcpus": 4,
    "memory": "15 GiB",
    "has_cuda": false,
    "gpu_model": null,
    "gpus": null,
    "gpu_memory": null,
    "cloud_provider": {
      "cloud_provider_id": 0,
      "name": "gcp"
    }
  },
  "machine_volume_conf": {
    "volume_conf_id": 1,
    "name": "volume_gcp_1",
    "encrypted": true,
    "size": 375,
    "disk_type": {
      "disk_type_id": 4,
      "name": "local-ssd",
      "has_fixed_size": true,
      "min_size": 375,
      "max_size": 375,
      "cloud_provider": {
        "cloud_provider_id": 0,
        "name": "gcp"
      }
    },
    "machine_volume_num": 1,
    "machine_volume_strip_num": 1
  },
  "disk_num": 1,
  "disk_size": 375,
  "machine_price_ycu": 2.17,
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2024-01-08T10:20:19.399039+00:00",
  "from_date": "2024-01-08T10:20:19.399039+00:00",
  "to_date": "infinity"
}
```

### edit-conf

```bash
yeedu cluster edit-conf -h
```

```bash
usage:  edit-conf [-h] [--cluster_conf_id CLUSTER_CONF_ID]
                  [--cluster_conf_name CLUSTER_CONF_NAME]
                  [--name [NAME]] [--description [DESCRIPTION]]
                  [--machine_type_category_id MACHINE_TYPE_CATEGORY_ID]
                  [--machine_type_id MACHINE_TYPE_ID]
                  [--volume_conf_id VOLUME_CONF_ID]
                  [--json-output [{pretty,default}]]
                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_conf_id CLUSTER_CONF_ID
                        Provide a specific Cluster Config Id to edit-conf.
  --cluster_conf_name CLUSTER_CONF_NAME
                        Provide a specific Cluster Config Name to edit-conf.
  --name [NAME]         Provide name to edit-conf.
  --description [DESCRIPTION]
                        Provide description to edit-conf.
  --machine_type_category_id MACHINE_TYPE_CATEGORY_ID
                        Provide machine_type_category_id to edit-conf.
  --machine_type_id MACHINE_TYPE_ID
                        Provide machine_type_id to edit-conf.
  --volume_conf_id VOLUME_CONF_ID
                        Provide volume_conf_id to edit-conf.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit-conf example with any one of the required argument '--cluster_conf_id' and other optional argument is passed which is to be updated.

```bash
yeedu cluster edit-conf --cluster_conf_id=1 --description="Yeedu General Purpose Configuration"
```

- Console output

```bash
{
  "cluster_conf_id": "1",
  "name": "yeedu_cluster_config",
  "description": "Yeedu General Purpose Configuration",
  "machine_type_category_id": "2",
  "machine_type_id": "64",
  "volume_conf_id": "1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T10:27:07.773Z",
  "from_date": "2024-01-08T10:20:19.399Z",
  "to_date": null
}
```

### delete-conf

```bash
yeedu cluster delete-conf -h
```

```bash
usage:  delete-conf [-h] [--cluster_conf_id CLUSTER_CONF_ID]
                    [--cluster_conf_name CLUSTER_CONF_NAME]
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_conf_id CLUSTER_CONF_ID
                        Provide Cluster Config Id to delete a specific Cluster Configuration.
  --cluster_conf_name CLUSTER_CONF_NAME
                        Provide Cluster Config Name to delete a specific Cluster Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-conf example with any one of the required argument passed.

```bash
yeedu cluster delete-conf --cluster_conf_name="yeedu_cluster_config"
```

- Console output

```bash
{
  "message": "Deleted Cluster Config Name: 'yeedu_cluster_config'"
}

```

## Cluster Instance

| Command Name               | Utility                                                           |
|----------------------------|-------------------------------------------------------------------|
|[create](#create)           | To create the Cluster Instance.                                   |
|[list](#list)               | To list all the available Cluster Instances.                      |
|[search](#search)           | To search cluster instances by cluster name.                      |
|[get](#get)                 | To get the information about a specific Cluster Instance.         |
|[edit](#edit)               | To edit a specific Cluster Instance.                              |
|[start](#start)             | To start a specific Cluster Instance.                             |
|[stop](#stop)               | To stop a specific Cluster Instance.                              |
|[destroy](#destroy)         | To destroy a specific Cluster Instance.                           |
|[get-stats](#get-stats)     | To get the Spark Job Statistics of an Cluster Instance.           |
|[list-status](#list-status) | To list status events of Cluster Instances.                       |
|[logs](#logs)               | To download Cluster Instance logs for a specific Cluster Instance |

### create

```bash
yeedu cluster create -h
```

```bash
usage:  create [-h] --name [NAME] [--description DESCRIPTION] --idle_timeout_ms
               [IDLE_TIMEOUT_MS] [--auto_shutdown [{true,false}]]
               [--labels LABELS [LABELS ...]] [--is_spot_instance [{true,false}]]
               [--enable_public_ip [{true,false}]]
               [--block_project_ssh_keys [{true,false}]]
               [--bootstrap_shell_script_file_path BOOTSTRAP_SHELL_SCRIPT_FILE_PATH]
               --cloud_env_id CLOUD_ENV_ID --object_storage_manager_id
               OBJECT_STORAGE_MANAGER_ID [--conf CONF [CONF ...]] [--packages [PACKAGES]]
               [--repositories [REPOSITORIES]] [--jars [JARS]] [--archives [ARCHIVES]]
               [--env_var ENV_VAR [ENV_VAR ...]]
               [--conf_secret CONF_SECRET [CONF_SECRET ...]]
               [--env_var_secret ENV_VAR_SECRET [ENV_VAR_SECRET ...]]
               [--hive_metastore_conf_id [HIVE_METASTORE_CONF_ID]]
               --spark_infra_version_id SPARK_INFRA_VERSION_ID
               [--max_parallel_spark_job_execution_per_instance [MAX_PARALLEL_SPARK_JOB_EXECUTION_PER_INSTANCE]]
               [--standalone_workers_number [STANDALONE_WORKERS_NUMBER]] --cluster_type
               [YEEDU, STANDALONE, CLUSTER] --min_instances MIN_INSTANCES --max_instances
               MAX_INSTANCES --cluster_conf_id CLUSTER_CONF_ID
               [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name [NAME]         Provide name to create a cluster instance.
  --description DESCRIPTION
                        Provide description to create a cluster instance.
  --idle_timeout_ms [IDLE_TIMEOUT_MS]
                        Provide idle_timeout_ms to create a cluster instance.
  --auto_shutdown [{true,false}]
                        Provide auto_shutdown to create a cluster instance. (default: true)
  --labels LABELS [LABELS ...]
                        Provide labels to create a cluster instance.
  --is_spot_instance [{true,false}]
                        Provide is_spot_instance to create a cluster instance. (default: false)
  --enable_public_ip [{true,false}]
                        Provide enable_public_ip to create a cluster instance. (default: false)
  --block_project_ssh_keys [{true,false}]
                        Provide block_project_ssh_keys to create a cluster instance. (default: true)
  --bootstrap_shell_script_file_path BOOTSTRAP_SHELL_SCRIPT_FILE_PATH
                        Provide bootstrap_shell_script_file_path to create a cluster instance.
  --cloud_env_id CLOUD_ENV_ID
                        Provide cloud_env_id to create a cluster instance.
  --object_storage_manager_id OBJECT_STORAGE_MANAGER_ID
                        Provide object_storage_manager_id to create a cluster instance.
  --conf CONF [CONF ...]
                        Provide conf to create a cluster instance.
  --packages [PACKAGES]
                        Provide packages to create a cluster instance.
  --repositories [REPOSITORIES]
                        Provide repositories to create a cluster instance.
  --jars [JARS]         Provide jars to create a cluster instance.
  --archives [ARCHIVES]
                        Provide archives to create a cluster instance.
  --env_var ENV_VAR [ENV_VAR ...]
                        Provide env_var to create a cluster instance.
  --conf_secret CONF_SECRET [CONF_SECRET ...]
                        Provide conf_secret to create a cluster instance.
  --env_var_secret ENV_VAR_SECRET [ENV_VAR_SECRET ...]
                        Provide env_var_secret to create a cluster instance.
  --hive_metastore_conf_id [HIVE_METASTORE_CONF_ID]
                        Provide hive_metastore_conf_id to create a cluster instance.
  --spark_infra_version_id SPARK_INFRA_VERSION_ID
                        Provide spark_infra_version_id to create a cluster instance.
  --max_parallel_spark_job_execution_per_instance [MAX_PARALLEL_SPARK_JOB_EXECUTION_PER_INSTANCE]
                        Provide max_parallel_spark_job_execution_per_instance to create a cluster instance. (default: 5)
  --standalone_workers_number [STANDALONE_WORKERS_NUMBER]
                        Provide standalone_workers_number to create a cluster instance.
  --cluster_type [YEEDU, STANDALONE, CLUSTER]
                        Provide cluster_type to create a cluster instance.
  --min_instances MIN_INSTANCES
                        Provide min_instances to create a cluster instance.
  --max_instances MAX_INSTANCES
                        Provide max_instances to create a cluster instance.
  --cluster_conf_id CLUSTER_CONF_ID
                        Provide cluster_conf_id to create a cluster instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create example with all the required and optional arguments passed.

```bash
yeedu cluster create --name="yeedu_cluster_instance" --description="Yeedu Instance" --idle_timeout_ms=600000 --auto_shutdown=true --labels="env=test" --is_spot_instance=false --enable_public_ip=true --block_project_ssh_keys=true --object_storage_manager_id=1 --cloud_env_id=1 --spark_infra_version_id=2 --max_parallel_spark_job_execution_per_instance=5 --cluster_type="YEEDU" --min_instances=1 --max_instances=1 --cluster_conf_id=1
```

- Console output

```bash
{
  "cluster_id": "1",
  "name": "yeedu_cluster_instance",
  "description": "Yeedu Instance",
  "cloud_env_id": 1,
  "idle_timeout_ms": "600000",
  "auto_shutdown": true,
  "labels": {
    "env": "test",
    "resource": "yeedu",
    "vm": "yeedu_node",
    "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
  },
  "is_spot_instance": false,
  "enable_public_ip": true,
  "block_project_ssh_keys": true,
  "bootstrap_shell_script": null,
  "object_storage_manager_id": "1",
  "cluster_conf_id": "1",
  "spark_config_id": null,
  "hive_metastore_conf_id": null,
  "spark_infra_version_id": "2",
  "engine_cluster_spark_config": {
    "max_parallel_spark_job_execution_per_instance": 5
  },
  "cluster_type": "YEEDU",
  "min_instances": 1,
  "max_instances": 1,
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T10:44:07.650Z",
  "from_date": "2024-01-08T10:44:07.650Z",
  "to_date": null
}
```

### list

```bash
yeedu cluster list -h
```

```bash
usage:  list [-h] [--cluster_status [CLUSTER_STATUS]]
             [--cluster_conf_id CLUSTER_CONF_ID]
             [--cluster_conf_name CLUSTER_CONF_NAME]
             [--page_number PAGE_NUMBER] [--limit LIMIT]
             [--json-output [{pretty,default}]]
             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_status [CLUSTER_STATUS]
                        Provide cluster instance status from ["INITIATING", "RUNNING", "STOPPING", "STOPPED", "DESTROYING", "DESTROYED",
                        "ERROR", "RESIZING_UP", "RESIZING_DOWN"] to list, For example --cluster_status="RUNNING,DESTROYED".
  --cluster_conf_id CLUSTER_CONF_ID
                        Provide Cluster Conf Id to list all the Cluster Instances.
  --cluster_conf_name CLUSTER_CONF_NAME
                        Provide Engine Cluster Config Name to list all the Cluster Instances.
  --page_number PAGE_NUMBER
                        To list cluster instance for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of cluster instance. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list example passing the optional arguments.

```bash
yeedu cluster list --cluster_status="RUNNING" --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "cluster_id": 1,
      "name": "yeedu_cluster_instance",
      "description": "Yeedu Instance",
      "labels": {
        "env": "test",
        "resource": "yeedu",
        "vm": "yeedu_node",
        "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
      },
      "idle_timeout_ms": 600000,
      "auto_shutdown": true,
      "cluster_status": "RUNNING",
      "cluster_type": "YEEDU",
      "compute_engine_id": 3,
      "instance_size": 1,
      "is_spot_instance": false,
      "enable_public_ip": true,
      "block_project_ssh_keys": true,
      "min_instances": 1,
      "max_instances": 1,
      "total_ycu": null,
      "bootstrap_shell_script": null,
      "spark_config_id": null,
      "cluster_conf": {
        "cluster_conf_id": 1,
        "cluster_conf_name": "n1-standard-4",
        "description": null,
        "machine_type_category": "general_purpose",
        "machine_type": {
          "machine_type_id": 64,
          "name": "n1-standard-4",
          "vcpus": 4,
          "memory": "15 GiB",
          "has_cuda": false,
          "gpu_model": null,
          "gpus": null,
          "gpu_memory": null
        },
        "machine_volume_conf": {
          "volume_conf_id": 1,
          "name": "volume_gcp_1",
          "description": null,
          "encrypted": true,
          "size": 375,
          "disk_machine_type": {
            "disk_machine_type_id": 4,
            "cloud_provider_id": 0,
            "name": "local-ssd",
            "has_fixed_size": true,
            "min_size": 375,
            "max_size": 375
          },
          "machine_volume_num": 1,
          "machine_volume_strip_num": 1
        }
      },
      "cloud_env": {
        "cloud_env_id": 1,
        "name": "gcp_cloud_env",
        "description": "yeedu cloud environment",
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        },
        "availabilty_zone": {
          "availabilty_zone_id": 75,
          "name": "us-central1-a",
          "cloud_provider_id": 0,
          "region": "us-central1",
          "description": "Council Bluffs, Iowa, North America"
        },
        "machine_network": {
          "machine_network_conf_id": 1,
          "name": "yeedu_gcp_network",
          "description": null,
          "network_project_id": "modak-yeedu",
          "network_name": "modak-yeedu-spark-vpc",
          "network_tags": [
            "yeedu",
            "iap-allow"
          ],
          "subnet": "custom-subnet-modak-nabu",
          "machine_network_availability_zone": {
            "availability_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          }
        },
        "cloud_project": "modak-yeedu",
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modaknabu-svc",
          "description": null,
          "credential_type": {
            "credential_type_id": 0,
            "name": "gcp",
            "cloud_provider_id": 0
          }
        },
        "boot_disk_image": {
          "boot_disk_image_id": 1,
          "name": "gcp_boot_disk",
          "description": "dev boot disk",
          "cloud_provider_id": 0,
          "linux_distro": {
            "linux_distro_id": 0,
            "distro_name": "UBUNTU",
            "distro_version": "20.04 LTS"
          },
          "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
        }
      },
      "hive_metastore_conf": {
        "hive_metastore_conf_id": null,
        "hive_metastore_conf_name": null
      },
      "spark_infra_version": {
        "spark_infra_version_id": 2,
        "spark_version": "3.2.2",
        "hive_version": "3.2.3",
        "hadoop_version": "3.2.4",
        "scala_version": "2.12.15",
        "python_version": "3.9.5",
        "notebook_support": true
      },
      "engine_cluster_spark_config": {
        "max_parallel_spark_job_execution_per_instance": 5,
        "standalone_workers_number": null
      },
      "object_storage_manager": {
        "object_storage_manager_id": 1,
        "name": "yeedu_osm",
        "description": "test",
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modakyeedu-svc",
          "description": null,
          "credential_type_name": "gcp"
        },
        "object_storage_bucket_name": "modak-yeedu-nabu"
      },
      "workflow_job_instance_details": {
        "workflow_job_instance_status": {
          "workflow_job_instance_id": 5,
          "workflow_job_id": 5,
          "status": "EXECUTING",
          "from_date": "2024-01-08T10:44:07.650245+00:00",
          "to_date": "infinity"
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-08T10:44:07.650245+00:00",
      "from_date": "2024-01-08T10:44:07.650245+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search

```bash
yeedu cluster search -h
```

```bash
usage:  search [-h] --cluster_name CLUSTER_NAME
               [--page_number PAGE_NUMBER] [--limit LIMIT]
               [--json-output [{pretty,default}]]
               [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_name CLUSTER_NAME
                        Provide cluster name to search cluster instances.
  --page_number PAGE_NUMBER
                        To search cluster instances for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of cluster instances. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search example passing the optional arguments.

```bash
yeedu cluster search --cluster_name="yeedu_" --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "cluster_id": 1,
      "name": "yeedu_cluster_instance",
      "description": "Yeedu Instance",
      "labels": {
        "env": "test",
        "resource": "yeedu",
        "vm": "yeedu_node",
        "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
      },
      "idle_timeout_ms": 600000,
      "auto_shutdown": true,
      "cluster_status": "RUNNING",
      "cluster_type": "YEEDU",
      "compute_engine_id": 3,
      "instance_size": 1,
      "is_spot_instance": false,
      "enable_public_ip": true,
      "block_project_ssh_keys": true,
      "min_instances": 1,
      "max_instances": 1,
      "total_ycu": null,
      "bootstrap_shell_script": null,
      "spark_config_id": null,
      "cluster_conf": {
        "cluster_conf_id": 1,
        "cluster_conf_name": "n1-standard-4",
        "description": null,
        "machine_type_category": "general_purpose",
        "machine_type": {
          "machine_type_id": 64,
          "name": "n1-standard-4",
          "vcpus": 4,
          "memory": "15 GiB",
          "has_cuda": false,
          "gpu_model": null,
          "gpus": null,
          "gpu_memory": null
        },
        "machine_volume_conf": {
          "volume_conf_id": 1,
          "name": "volume_gcp_1",
          "description": null,
          "encrypted": true,
          "size": 375,
          "disk_machine_type": {
            "disk_machine_type_id": 4,
            "cloud_provider_id": 0,
            "name": "local-ssd",
            "has_fixed_size": true,
            "min_size": 375,
            "max_size": 375
          },
          "machine_volume_num": 1,
          "machine_volume_strip_num": 1
        }
      },
      "cloud_env": {
        "cloud_env_id": 1,
        "name": "gcp_cloud_env",
        "description": "yeedu cloud environment",
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        },
        "availabilty_zone": {
          "availabilty_zone_id": 75,
          "name": "us-central1-a",
          "cloud_provider_id": 0,
          "region": "us-central1",
          "description": "Council Bluffs, Iowa, North America"
        },
        "machine_network": {
          "machine_network_conf_id": 1,
          "name": "yeedu_gcp_network",
          "description": null,
          "network_project_id": "modak-yeedu",
          "network_name": "modak-yeedu-spark-vpc",
          "network_tags": [
            "yeedu",
            "iap-allow"
          ],
          "subnet": "custom-subnet-modak-nabu",
          "machine_network_availability_zone": {
            "availability_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          }
        },
        "cloud_project": "modak-yeedu",
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modaknabu-svc",
          "description": null,
          "credential_type": {
            "credential_type_id": 0,
            "name": "gcp",
            "cloud_provider_id": 0
          }
        },
        "boot_disk_image": {
          "boot_disk_image_id": 1,
          "name": "gcp_boot_disk",
          "description": "dev boot disk",
          "cloud_provider_id": 0,
          "linux_distro": {
            "linux_distro_id": 0,
            "distro_name": "UBUNTU",
            "distro_version": "20.04 LTS"
          },
          "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
        }
      },
      "hive_metastore_conf": {
        "hive_metastore_conf_id": null,
        "hive_metastore_conf_name": null
      },
      "spark_infra_version": {
        "spark_infra_version_id": 2,
        "spark_version": "3.2.2",
        "hive_version": "3.2.3",
        "hadoop_version": "3.2.4",
        "scala_version": "2.12.15",
        "python_version": "3.9.5",
        "notebook_support": true
      },
      "engine_cluster_spark_config": {
        "max_parallel_spark_job_execution_per_instance": 5,
        "standalone_workers_number": null
      },
      "object_storage_manager": {
        "object_storage_manager_id": 1,
        "name": "yeedu_osm",
        "description": "test",
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modakyeedu-svc",
          "description": null,
          "credential_type_name": "gcp"
        },
        "object_storage_bucket_name": "modak-yeedu-nabu"
      },
      "workflow_job_instance_details": {
        "workflow_job_instance_status": {
          "workflow_job_instance_id": 5,
          "workflow_job_id": 5,
          "status": "EXECUTING",
          "from_date": "2024-01-08T10:44:07.650245+00:00",
          "to_date": "infinity"
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-08T10:44:07.650245+00:00",
      "from_date": "2024-01-08T10:44:07.650245+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get

```bash
yeedu cluster get -h
```

```bash
usage:  get [-h] [--cluster_id CLUSTER_ID]
            [--cluster_name CLUSTER_NAME]
            [--json-output [{pretty,default}]]
            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide cluster instance id to get information about a specific cluster instance.
  --cluster_name CLUSTER_NAME
                        Provide cluster instance name to get information about a specific cluster instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get example with any one of the required argument '--cluster_name' passed.

```bash
yeedu cluster get --cluster_name="yeedu_cluster_instance"
```

- Console output

```bash
{
  "cluster_id": 1,
  "name": "yeedu_cluster_instance",
  "description": "Yeedu Instance",
  "labels": {
    "env": "test",
    "resource": "yeedu",
    "vm": "yeedu_node",
    "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
  },
  "idle_timeout_ms": 600000,
  "auto_shutdown": true,
  "cluster_status": "RUNNING",
  "cluster_type": "YEEDU",
  "compute_engine_id": 3,
  "instance_size": 1,
  "is_spot_instance": false,
  "enable_public_ip": true,
  "block_project_ssh_keys": true,
  "min_instances": 1,
  "max_instances": 1,
  "total_ycu": null,
  "bootstrap_shell_script": null,
  "spark_config_id": null,
  "cluster_conf": {
    "cluster_conf_id": 1,
    "cluster_conf_name": "n1-standard-4",
    "description": null,
    "machine_type_category": "general_purpose",
    "machine_type": {
      "machine_type_id": 64,
      "name": "n1-standard-4",
      "vcpus": 4,
      "memory": "15 GiB",
      "has_cuda": false,
      "gpu_model": null,
      "gpus": null,
      "gpu_memory": null
    },
    "machine_volume_conf": {
      "volume_conf_id": 1,
      "name": "volume_gcp_1",
      "description": null,
      "encrypted": true,
      "size": 375,
      "disk_machine_type": {
        "disk_machine_type_id": 4,
        "cloud_provider_id": 0,
        "name": "local-ssd",
        "has_fixed_size": true,
        "min_size": 375,
        "max_size": 375
      },
      "machine_volume_num": 1,
      "machine_volume_strip_num": 1
    }
  },
  "cloud_env": {
    "cloud_env_id": 1,
    "name": "gcp_cloud_env",
    "description": "yeedu cloud environment",
    "cloud_provider": {
      "cloud_provider_id": 0,
      "name": "gcp"
    },
    "availabilty_zone": {
      "availabilty_zone_id": 75,
      "name": "us-central1-a",
      "cloud_provider_id": 0,
      "region": "us-central1",
      "description": "Council Bluffs, Iowa, North America"
    },
    "machine_network": {
      "machine_network_conf_id": 1,
      "name": "yeedu_gcp_network",
      "description": null,
      "network_project_id": "modak-yeedu",
      "network_name": "modak-yeedu-spark-vpc",
      "network_tags": [
        "yeedu",
        "iap-allow"
      ],
      "subnet": "custom-subnet-modak-nabu",
      "machine_network_availability_zone": {
        "availability_zone_id": 75,
        "name": "us-central1-a",
        "cloud_provider_id": 0,
        "region": "us-central1",
        "description": "Council Bluffs, Iowa, North America"
      }
    },
    "cloud_project": "modak-yeedu",
    "credentials_config": {
      "credential_config_id": 1,
      "name": "modaknabu-svc",
      "description": null,
      "credential_type": {
        "credential_type_id": 0,
        "name": "gcp",
        "cloud_provider_id": 0
      }
    },
    "boot_disk_image": {
      "boot_disk_image_id": 1,
      "name": "gcp_boot_disk",
      "description": "dev boot disk",
      "cloud_provider_id": 0,
      "linux_distro": {
        "linux_distro_id": 0,
        "distro_name": "UBUNTU",
        "distro_version": "20.04 LTS"
      },
      "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
    }
  },
  "hive_metastore_conf": {
    "hive_metastore_conf_id": null,
    "hive_metastore_conf_name": null
  },
  "spark_infra_version": {
    "spark_infra_version_id": 2,
    "spark_version": "3.2.2",
    "hive_version": "3.2.3",
    "hadoop_version": "3.2.4",
    "scala_version": "2.12.15",
    "python_version": "3.9.5",
    "notebook_support": true
  },
  "engine_cluster_spark_config": {
    "max_parallel_spark_job_execution_per_instance": 5,
    "standalone_workers_number": null
  },
  "object_storage_manager": {
    "object_storage_manager_id": 1,
    "name": "yeedu_osm",
    "description": "test",
    "credentials_config": {
      "credential_config_id": 1,
      "name": "modakyeedu-svc",
      "description": null,
      "credential_type_name": "gcp"
    },
    "object_storage_bucket_name": "modak-yeedu-nabu"
  },
  "workflow_job_instance_details": {
    "workflow_job_instance_status": {
      "workflow_job_instance_id": 5,
      "workflow_job_id": 5,
      "status": "EXECUTING",
      "from_date": "2024-01-08T10:44:07.650245+00:00",
      "to_date": "infinity"
    }
  },
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2024-01-08T10:44:07.650245+00:00",
  "from_date": "2024-01-08T10:44:07.650245+00:00",
  "to_date": "infinity"
}
```

### edit

```bash
yeedu cluster edit -h
```

```bash
usage:  edit [-h] [--cluster_id CLUSTER_ID] [--cluster_name CLUSTER_NAME] [--name NAME]
             [--description DESCRIPTION] [--idle_timeout_ms [IDLE_TIMEOUT_MS]]
             [--auto_shutdown [{true,false}]] [--labels LABELS [LABELS ...]]
             [--enable_public_ip [{true,false}]] [--block_project_ssh_keys [{true,false}]]
             [--bootstrap_shell_script_file_path [BOOTSTRAP_SHELL_SCRIPT_FILE_PATH]]
             [--cloud_env_id [CLOUD_ENV_ID]]
             [--object_storage_manager_id [OBJECT_STORAGE_MANAGER_ID]]
             [--hive_metastore_conf_id [HIVE_METASTORE_CONF_ID]]
             [--spark_infra_version_id SPARK_INFRA_VERSION_ID] [--cluster_conf_id [CLUSTER_CONF_ID]]
             [--conf CONF [CONF ...]] [--packages [PACKAGES]] [--repositories [REPOSITORIES]]
             [--jars [JARS]] [--archives [ARCHIVES]] [--env_var ENV_VAR [ENV_VAR ...]]
             [--conf_secret CONF_SECRET [CONF_SECRET ...]]
             [--env_var_secret ENV_VAR_SECRET [ENV_VAR_SECRET ...]]
             [--max_parallel_spark_job_execution_per_instance [MAX_PARALLEL_SPARK_JOB_EXECUTION_PER_INSTANCE]]
             [--standalone_workers_number [STANDALONE_WORKERS_NUMBER]]
             [--min_instances [MIN_INSTANCES]] [--max_instances [MAX_INSTANCES]]
             [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide a specific cluster instance id to edit.
  --cluster_name CLUSTER_NAME
                        Provide a specific cluster instance name to edit.
  --name NAME           Provide name to edit a cluster instance.
  --description DESCRIPTION
                        Provide description to edit a cluster instance.
  --idle_timeout_ms [IDLE_TIMEOUT_MS]
                        Provide idle_timeout_ms to edit a cluster instance.
  --auto_shutdown [{true,false}]
                        Provide auto_shutdown to edit a cluster instance.
  --labels LABELS [LABELS ...]
                        Provide labels to edit a cluster instance.
  --enable_public_ip [{true,false}]
                        Provide enable_public_ip to edit a cluster instance.
  --block_project_ssh_keys [{true,false}]
                        Provide block_project_ssh_keys to edit a cluster instance.
  --bootstrap_shell_script_file_path [BOOTSTRAP_SHELL_SCRIPT_FILE_PATH]
                        Provide bootstrap_shell_script_file_path to edit a cluster instance.
  --cloud_env_id [CLOUD_ENV_ID]
                        Provide cloud_env_id to edit a cluster instance.
  --object_storage_manager_id [OBJECT_STORAGE_MANAGER_ID]
                        Provide object_storage_manager_id to edit a cluster instance.
  --hive_metastore_conf_id [HIVE_METASTORE_CONF_ID]
                        Provide hive_metastore_conf_id to edit a cluster instance.
  --spark_infra_version_id SPARK_INFRA_VERSION_ID
                        Provide spark_infra_version_id to edit a cluster instance.
  --cluster_conf_id [CLUSTER_CONF_ID]
                        Provide cluster_conf_id to edit a cluster instance.
  --conf CONF [CONF ...]
                        Provide conf to edit a cluster instance.
  --packages [PACKAGES]
                        Provide packages to edit a cluster instance.
  --repositories [REPOSITORIES]
                        Provide repositories to edit a cluster instance.
  --jars [JARS]         Provide jars to edit a cluster instance.
  --archives [ARCHIVES]
                        Provide archives to edit a cluster instance.
  --env_var ENV_VAR [ENV_VAR ...]
                        Provide env_var to edit a cluster instance.
  --conf_secret CONF_SECRET [CONF_SECRET ...]
                        Provide conf_secret to edit a cluster instance.
  --env_var_secret ENV_VAR_SECRET [ENV_VAR_SECRET ...]
                        Provide env_var_secret to edit a cluster instance.
  --max_parallel_spark_job_execution_per_instance [MAX_PARALLEL_SPARK_JOB_EXECUTION_PER_INSTANCE]
                        Provide max_parallel_spark_job_execution_per_instance to edit a cluster instance.
  --standalone_workers_number [STANDALONE_WORKERS_NUMBER]
                        Provide standalone_workers_number to edit a cluster instance.
  --min_instances [MIN_INSTANCES]
                        Provide min_instances to edit a cluster instance.
  --max_instances [MAX_INSTANCES]
                        Provide max_instances to edit a cluster instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit example with one of the required '--cluster_id' argument and other optional argument is passed which is to be updated.

```bash
yeedu cluster edit --cluster_id=1 --idle_timeout_ms=600000
```

- Console output

```bash
{
  "cluster_id": "1",
  "name": "yeedu_cluster_instance",
  "description": "Yeedu Instance",
  "cloud_env_id": 1,
  "idle_timeout_ms": "600000",
  "auto_shutdown": true,
  "labels": {
    "env": "test",
    "resource": "yeedu",
    "vm": "yeedu_node",
    "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
  },
  "is_spot_instance": false,
  "enable_public_ip": true,
  "block_project_ssh_keys": true,
  "bootstrap_shell_script": null,
  "object_storage_manager_id": "1",
  "cluster_conf_id": "1",
  "spark_config_id": null,
  "hive_metastore_conf_id": null,
  "spark_infra_version_id": "2",
  "engine_cluster_spark_config": {
    "max_parallel_spark_job_execution_per_instance": 5
  },
  "cluster_type": "YEEDU",
  "min_instances": 1,
  "max_instances": 1,
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T10:44:07.650Z",
  "from_date": "2024-01-08T10:44:07.650Z",
  "to_date": null
}
```

### start

```bash
yeedu cluster start -h
```

```bash
usage:  start [-h] [--cluster_id CLUSTER_ID]
              [--cluster_name CLUSTER_NAME]
              [--json-output [{pretty,default}]]
              [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide cluster instance id to start a cluster instance.
  --cluster_name CLUSTER_NAME
                        Provide cluster instance name to start a cluster instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- start example with one of the required argument '--cluster_id' passed.

```bash
yeedu cluster start --cluster_id=1
```

- Console output

```bash
{
  "CosiStart": {
    "workflow_job_id": 1,
    "workflow_job_instance_id": 1,
    "engine_cluster_instance_id": 1
  }
}
```

### stop

```bash
yeedu cluster stop -h
```

```bash
usage:  stop [-h] [--cluster_id CLUSTER_ID]
             [--cluster_name CLUSTER_NAME]
             [--json-output [{pretty,default}]]
             [--yaml-output [{true,false}]]
options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide cluster instance id to stop a cluster instance.
  --cluster_name CLUSTER_NAME
                        Provide cluster instance name to stop a cluster instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- stop example with one of the required argument '--cluster_id' passed.

```bash
yeedu cluster stop --cluster_id=1
```

- Console output

```bash
{
  "CosiStop": {
    "workflow_job_id": 1,
    "workflow_job_instance_id": 1,
    "engine_cluster_instance_id": 1
  }
}
```

### destroy

```bash
yeedu cluster destroy -h
```

```bash
usage:  destroy [-h] [--cluster_id CLUSTER_ID]
                [--cluster_name CLUSTER_NAME]
                [--json-output [{pretty,default}]]
                [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide cluster instance id to destroy a cluster instance.
  --cluster_name CLUSTER_NAME
                        Provide cluster instance name to destroy a cluster instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- destroy example with one of the required argument '--cluster_id' passed.

```bash
yeedu cluster destroy --cluster_id=1
```

- Console output

```bash
{
  "CosiDestroy": {
    "workflow_job_id": 1,
    "workflow_job_instance_id": 1,
    "engine_cluster_instance_id": 1
  }
}
```

### get-stats

```bash
yeedu cluster get-stats -h
```

```bash
usage:  get-stats [-h] [--cluster_id CLUSTER_ID]
                  [--cluster_name CLUSTER_NAME]
                  [--json-output [{pretty,default}]]
                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide cluster instance id to get the spark job statistics of a cluster instance.
  --cluster_name CLUSTER_NAME
                        Provide cluster instance name to get the spark job statistics of a cluster instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-stats example with one of the optional arguments '--cluster_name' passed.

```bash
yeedu cluster get-stats --cluster_name="yeedu_cluster_instance"
```

- Console output

```bash
{
  "SUBMITTED": 1,
  "RUNNING": 2,
  "DONE": 4,
  "ERROR": 0,
  "TERMINATED": 0,
  "STOPPING": 1,
  "STOPPED": 1,
  "TOTAL_JOB_COUNT": 9
}
```

### list-status

```bash
yeedu cluster list-status -h
```

```bash
usage:  list-status [-h] [--cluster_id CLUSTER_ID]
                    [--cluster_name CLUSTER_NAME]
                    [--page_number PAGE_NUMBER] [--limit LIMIT]
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide cluster id to list all the cluster instance status.
  --cluster_name CLUSTER_NAME
                        Provide cluster name to list all the cluster instance status.
  --page_number PAGE_NUMBER
                        To list the cluster instance status for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of cluster instance status. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-status example with one of the required argument '--cluster_id' and other optional argument passed.

```bash
yeedu cluster list-status --cluster_id=1 --limit=4
```

- Console output

```bash
{
  "data": [
    {
      "cluster_status": "STOPPED",
      "current_node_size": 0,
      "created_by": null,
      "start_time": "2023-09-29T07:33:38.586618+00:00",
      "end_time": "infinity"
    },
    {
      "cluster_status": "STOPPING",
      "current_node_size": 0,
      "created_by": null,
      "start_time": "2023-09-29T07:32:12.534424+00:00",
      "end_time": "2023-09-29T07:33:38.586618+00:00"
    },
    {
      "cluster_status": "RUNNING",
      "current_node_size": 1,
      "created_by": null,
      "start_time": "2023-09-29T07:20:47.743064+00:00",
      "end_time": "2023-09-29T07:32:12.534424+00:00"
    },
    {
      "cluster_status": "INITIATING",
      "current_node_size": 1,
      "created_by": null,
      "start_time": "2023-09-29T07:19:58.413655+00:00",
      "end_time": "2023-09-29T07:20:47.743064+00:00"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 32,
    "total_pages": 8,
    "limit": 4,
    "next_page": 2
  }
}
```

### logs

```bash
yeedu cluster logs -h
```

```bash
usage:  logs [-h] [--cluster_id CLUSTER_ID]
             [--cluster_name CLUSTER_NAME]
             [--log_type {stdout,stderr}]
             [--json-output [{pretty,default}]]
             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide Cluster Instance Id to download log records.
  --cluster_name CLUSTER_NAME
                        Provide Cluster Instance Name to download log records.
  --log_type {stdout,stderr}
                        Provide log_type to download Cluster Instance log records. (default: stdout)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- logs example with one of the required '--cluster_id' argument passed.

```bash
yeedu cluster logs --cluster_id=1
```

- Console output

```bash
Initializing modules...
- local-node in module
- master-standalone-cluster in module
- standalone-node in module
- worker-standalone-cluster in module
Initializing the backend...

Successfully configured the backend "pg"! Terraform will automatically
use this backend unless the backend configuration changes.
Initializing provider plugins...
- Finding latest version of hashicorp/random...
- Finding latest version of hashicorp/template...
- Finding latest version of hashicorp/google...
- Installing hashicorp/template v2.2.0...
- Installed hashicorp/template v2.2.0 (signed by HashiCorp)
- Installing hashicorp/google v4.50.0...
- Installed hashicorp/google v4.50.0 (signed by HashiCorp)
- Installing hashicorp/random v3.4.3...
- Installed hashicorp/random v3.4.3 (signed by HashiCorp)
Terraform has created a lock file .terraform.lock.hcl to record the provider
selections it made above. Include this file in your version control repository
so that Terraform can guarantee to make the same selections by default when
you run "terraform init" in the future.
Terraform has been successfully initialized!

...

Apply complete! Resources: 3 added, 0 changed, 0 destroyed.

Outputs:
local-node-uuids = [
  {
    "instance_uuid" = tomap({
      "292a79d6-7967-3284-6e19-31aecf9977f4" = 0
    })
    "reserved_ip" = [
      "10.101.1.41",
    ]
  },
]
master-standalone-cluster-uuids = []
standalone-node-uuids = []
worker-standalone-cluster-uuids = []
```

## Cluster Access Control

| Command Name                                       | Utility                                                          |
|----------------------------------------------------|------------------------------------------------------------------|
|[associate-workspace](#associate-workspace)         | Associate cluster with a workspaces                              |
|[dissociate-workspace](#dissociate-workspace)       | Dissociate cluster with a workspace                              |
|[list-workspaces](#list-workspaces)                 | List all the Workspaces having access to a cluster.              |
|[list-workspace-clusters](#list-workspace-clusters) | List all the Clusters that have access to a workspace.           |
|[search-workspace-clusters](#search-workspace-clusters) | Search all the Clusters that have access to a workspace.           |

### associate-workspace

```bash
yeedu cluster associate-workspace -h
```

```bash
usage:  associate-workspace [-h] --workspace_id WORKSPACE_ID
                            --cluster_id CLUSTER_ID
                            [--json-output [{pretty,default}]]
                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to associate it with a cluster.
  --cluster_id CLUSTER_ID
                        Provide Cluster Id to to associate it with a workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- associate-workspace example with all the required argument passed.

```bash
yeedu cluster associate-workspace --workspace_id=1 --cluster_id=1
```

- Console output

```bash
{
  "workspace_id": "1",
  "cluster_id": "1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-09-29T12:24:29.358Z",
  "from_date": "2023-09-29T12:24:29.358Z",
  "to_date": null
}
```

### dissociate-workspace

```bash
yeedu cluster dissociate-workspace -h
```

```bash
usage:  dissociate-workspace [-h] --workspace_id WORKSPACE_ID
                             --cluster_id CLUSTER_ID
                             [--json-output [{pretty,default}]]
                             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to dissociate it with a cluster.
  --cluster_id CLUSTER_ID
                        Provide Cluster Id to dissociate it with a workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- dissociate-workspace example with all the required argument passed.

```bash
yeedu cluster create-group-access --cluster_id=1 --group_id=1 --permission_id=1
```

- Console output

```bash
{
  "auth_engine_cluster_instance_group_id": "1",
  "cluster_instance_perm_id": 1,
  "group_id": "1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-09-29T11:10:48.468Z",
  "from_date": "2023-09-29T11:10:48.468Z",
  "to_date": null
}
```

### list-workspaces

```bash
yeedu cluster list-workspaces -h
```

```bash
usage:  list-workspaces [-h] --cluster_id CLUSTER_ID
                        [--page_number PAGE_NUMBER] [--limit LIMIT]
                        [--json-output [{pretty,default}]]
                        [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide Cluster Id to list all the associated workspaces.
  --page_number PAGE_NUMBER
                        To list Clusters for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Clusters. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-workspaces example with all the required argument passed.

```bash
yeedu cluster list-workspaces --cluster_id=1
```

- Console output

```bash
{
  "data": [
    {
      "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
        }
      "cluster_info": {
        "cluster_id": 1,
        "name": "yeedu_cluster_instance",
        "description": "Yeedu Instance",
        "labels": {
          "env": "test",
          "resource": "yeedu",
          "vm": "yeedu_node",
          "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
        },
        "idle_timeout_ms": 600000,
        "auto_shutdown": true,
        "cluster_status": "RUNNING",
        "cluster_type": "YEEDU",
        "compute_engine_id": 3,
        "instance_size": 1,
        "is_spot_instance": false,
        "enable_public_ip": true,
        "block_project_ssh_keys": true,
        "min_instances": 1,
        "max_instances": 1,
        "total_ycu": null,
        "bootstrap_shell_script": null,
        "spark_config_id": null,
        "cluster_conf": {
          "cluster_conf_id": 1,
          "cluster_conf_name": "n1-standard-4",
          "description": null,
          "machine_type_category": "general_purpose",
          "machine_type": {
            "machine_type_id": 64,
            "name": "n1-standard-4",
            "vcpus": 4,
            "memory": "15 GiB",
            "has_cuda": false,
            "gpu_model": null,
            "gpus": null,
            "gpu_memory": null
          },
          "machine_volume_conf": {
            "volume_conf_id": 1,
            "name": "volume_gcp_1",
            "description": null,
            "encrypted": true,
            "size": 375,
            "disk_machine_type": {
              "disk_machine_type_id": 4,
              "cloud_provider_id": 0,
              "name": "local-ssd",
              "has_fixed_size": true,
              "min_size": 375,
              "max_size": 375
            },
            "machine_volume_num": 1,
            "machine_volume_strip_num": 1
          }
        },
        "cloud_env": {
          "cloud_env_id": 1,
          "name": "gcp_cloud_env",
          "description": "yeedu cloud environment",
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          },
          "availabilty_zone": {
            "availabilty_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          },
          "machine_network": {
            "machine_network_conf_id": 1,
            "name": "yeedu_gcp_network",
            "description": null,
            "network_project_id": "modak-yeedu",
            "network_name": "modak-yeedu-spark-vpc",
            "network_tags": [
              "yeedu",
              "iap-allow"
            ],
            "subnet": "custom-subnet-modak-nabu",
            "machine_network_availability_zone": {
              "availability_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            }
          },
          "cloud_project": "modak-yeedu",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modaknabu-svc",
            "description": null,
            "credential_type": {
              "credential_type_id": 0,
              "name": "gcp",
              "cloud_provider_id": 0
            }
          },
          "boot_disk_image": {
            "boot_disk_image_id": 1,
            "name": "gcp_boot_disk",
            "description": "dev boot disk",
            "cloud_provider_id": 0,
            "linux_distro": {
              "linux_distro_id": 0,
              "distro_name": "UBUNTU",
              "distro_version": "20.04 LTS"
            },
            "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
          }
        },
        "hive_metastore_conf": {
          "hive_metastore_conf_id": null,
          "hive_metastore_conf_name": null
        },
        "spark_infra_version": {
          "spark_infra_version_id": 2,
          "spark_version": "3.2.2",
          "hive_version": "3.2.3",
          "hadoop_version": "3.2.4",
          "scala_version": "2.12.15",
          "python_version": "3.9.5",
          "notebook_support": true
        },
        "engine_cluster_spark_config": {
          "max_parallel_spark_job_execution_per_instance": 5,
          "standalone_workers_number": null
        },
        "object_storage_manager": {
          "object_storage_manager_id": 1,
          "name": "yeedu_osm",
          "description": "test",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type_name": "gcp"
          },
          "object_storage_bucket_name": "modak-yeedu-nabu"
        },
        "workflow_job_instance_details": {
          "workflow_job_instance_status": {
            "workflow_job_instance_id": 5,
            "workflow_job_id": 5,
            "status": "EXECUTING",
            "from_date": "2024-01-08T10:44:07.650245+00:00",
            "to_date": "infinity"
          }
        },
        "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
        "created_by": {
          "user_id": 1,
          "username": "YSU0000"
        },
        "modified_by": {
          "user_id": 1,
          "username": "YSU0000"
        },
        "last_update_date": "2024-01-08T10:44:07.650245+00:00",
        "from_date": "2024-01-08T10:44:07.650245+00:00",
        "to_date": "infinity"
      }
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### list-workspace-clusters

```bash
yeedu cluster list-workspace-clusters -h
```

```bash
usage:  list-workspace-clusters [-h] --workspace_id WORKSPACE_ID
                                [--cluster_status [CLUSTER_STATUS]]
                                [--job_type [{job,notebook}]]
                                [--page_number PAGE_NUMBER] [--limit LIMIT]
                                [--json-output [{pretty,default}]]
                                [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to list all the associated clusters.
  --cluster_status [CLUSTER_STATUS]
                        Provide Cluster Instance Status from ["INITIATING", "RUNNING", "STOPPING", "STOPPED", "DESTROYING", "DESTROYED", "ERROR", "RESIZING_UP", "RESIZING_DOWN"] to list, For example --cluster_status="RUNNING,DESTROYED".
  --job_type [{JOB,NOTEBOOK}]
                        To list Clusters for a specific job_type.
  --page_number PAGE_NUMBER
                        To list Clusters for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Clusters. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-workspace-clusters example with all the required argument passed.

```bash
yeedu cluster list-workspace-clusters --workspace_id=1
```

- Console output

```bash
{
  "data": [
    {
      "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
      },
      "cluster_info": {
        "cluster_id": 1,
        "name": "yeedu_cluster_instance",
        "description": "Yeedu Instance",
        "labels": {
          "env": "test",
          "resource": "yeedu",
          "vm": "yeedu_node",
          "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
        },
        "idle_timeout_ms": 600000,
        "auto_shutdown": true,
        "cluster_status": "RUNNING",
        "cluster_type": "YEEDU",
        "compute_engine_id": 3,
        "instance_size": 1,
        "is_spot_instance": false,
        "enable_public_ip": true,
        "block_project_ssh_keys": true,
        "min_instances": 1,
        "max_instances": 1,
        "total_ycu": null,
        "bootstrap_shell_script": null,
        "spark_config_id": null,
        "cluster_conf": {
          "cluster_conf_id": 1,
          "cluster_conf_name": "n1-standard-4",
          "description": null,
          "machine_type_category": "general_purpose",
          "machine_type": {
            "machine_type_id": 64,
            "name": "n1-standard-4",
            "vcpus": 4,
            "memory": "15 GiB",
            "has_cuda": false,
            "gpu_model": null,
            "gpus": null,
            "gpu_memory": null
          },
          "machine_volume_conf": {
            "volume_conf_id": 1,
            "name": "volume_gcp_1",
            "description": null,
            "encrypted": true,
            "size": 375,
            "disk_machine_type": {
              "disk_machine_type_id": 4,
              "cloud_provider_id": 0,
              "name": "local-ssd",
              "has_fixed_size": true,
              "min_size": 375,
              "max_size": 375
            },
            "machine_volume_num": 1,
            "machine_volume_strip_num": 1
          }
        },
        "cloud_env": {
          "cloud_env_id": 1,
          "name": "gcp_cloud_env",
          "description": "yeedu cloud environment",
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          },
          "availabilty_zone": {
            "availabilty_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          },
          "machine_network": {
            "machine_network_conf_id": 1,
            "name": "yeedu_gcp_network",
            "description": null,
            "network_project_id": "modak-yeedu",
            "network_name": "modak-yeedu-spark-vpc",
            "network_tags": [
              "yeedu",
              "iap-allow"
            ],
            "subnet": "custom-subnet-modak-nabu",
            "machine_network_availability_zone": {
              "availability_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            }
          },
          "cloud_project": "modak-yeedu",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modaknabu-svc",
            "description": null,
            "credential_type": {
              "credential_type_id": 0,
              "name": "gcp",
              "cloud_provider_id": 0
            }
          },
          "boot_disk_image": {
            "boot_disk_image_id": 1,
            "name": "gcp_boot_disk",
            "description": "dev boot disk",
            "cloud_provider_id": 0,
            "linux_distro": {
              "linux_distro_id": 0,
              "distro_name": "UBUNTU",
              "distro_version": "20.04 LTS"
            },
            "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
          }
        },
        "hive_metastore_conf": {
          "hive_metastore_conf_id": null,
          "hive_metastore_conf_name": null
        },
        "spark_infra_version": {
          "spark_infra_version_id": 2,
          "spark_version": "3.2.2",
          "hive_version": "3.2.3",
          "hadoop_version": "3.2.4",
          "scala_version": "2.12.15",
          "python_version": "3.9.5",
          "notebook_support": true
        },
        "engine_cluster_spark_config": {
          "max_parallel_spark_job_execution_per_instance": 5,
          "standalone_workers_number": null
        },
        "object_storage_manager": {
          "object_storage_manager_id": 1,
          "name": "yeedu_osm",
          "description": "test",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type_name": "gcp"
          },
          "object_storage_bucket_name": "modak-yeedu-nabu"
        },
        "workflow_job_instance_details": {
          "workflow_job_instance_status": {
            "workflow_job_instance_id": 5,
            "workflow_job_id": 5,
            "status": "EXECUTING",
            "from_date": "2024-01-08T10:44:07.650245+00:00",
            "to_date": "infinity"
          }
        },
        "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
        "created_by": {
          "user_id": 1,
          "username": "YSU0000"
        },
        "modified_by": {
          "user_id": 1,
          "username": "YSU0000"
        },
        "last_update_date": "2024-01-08T10:44:07.650245+00:00",
        "from_date": "2024-01-08T10:44:07.650245+00:00",
        "to_date": "infinity"
      }
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-workspace-clusters

```bash
yeedu cluster search-workspace-clusters -h
```

```bash
usage:  search-workspace-clusters [-h] --workspace_id WORKSPACE_ID
                                  [--cluster_name [CLUSTER_NAME]]
                                  [--cluster_status [CLUSTER_STATUS]]
                                  [--job_type [{JOB,NOTEBOOK}]]
                                  [--page_number PAGE_NUMBER]
                                  [--limit LIMIT]
                                  [--json-output [{pretty,default}]]
                                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to search all the associated clusters.
  --cluster_name [CLUSTER_NAME]
                        Provide cluster name to search all the associated workspace clusters.
  --cluster_status [CLUSTER_STATUS]
                        Provide cluster instance status from ["INITIATING", "RUNNING", "STOPPING", "STOPPED", "DESTROYING", "DESTROYED", "ERROR", "RESIZING_UP", "RESIZING_DOWN"] to search, for example --cluster_status="RUNNING,DESTROYED".
  --job_type [{JOB,NOTEBOOK}]
                        To search clusters of a specific job_type.
  --page_number PAGE_NUMBER
                        To search clusters for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of clusters. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-confs example with required argument '--cluster_conf_name' passed.

```bash
yeedu cluster search-workspace-clusters --workspace_id=1 --cluster_name="yeedu_"
```

- Console output

```bash
{
  "data": [
    {
      "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
      },
      "cluster_info": {
        "cluster_id": 1,
        "name": "yeedu_cluster_instance",
        "description": "Yeedu Instance",
        "labels": {
          "env": "test",
          "resource": "yeedu",
          "vm": "yeedu_node",
          "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
        },
        "idle_timeout_ms": 600000,
        "auto_shutdown": true,
        "cluster_status": "RUNNING",
        "cluster_type": "YEEDU",
        "compute_engine_id": 3,
        "instance_size": 1,
        "is_spot_instance": false,
        "enable_public_ip": true,
        "block_project_ssh_keys": true,
        "min_instances": 1,
        "max_instances": 1,
        "total_ycu": null,
        "bootstrap_shell_script": null,
        "spark_config_id": null,
        "cluster_conf": {
          "cluster_conf_id": 1,
          "cluster_conf_name": "n1-standard-4",
          "description": null,
          "machine_type_category": "general_purpose",
          "machine_type": {
            "machine_type_id": 64,
            "name": "n1-standard-4",
            "vcpus": 4,
            "memory": "15 GiB",
            "has_cuda": false,
            "gpu_model": null,
            "gpus": null,
            "gpu_memory": null
          },
          "machine_volume_conf": {
            "volume_conf_id": 1,
            "name": "volume_gcp_1",
            "description": null,
            "encrypted": true,
            "size": 375,
            "disk_machine_type": {
              "disk_machine_type_id": 4,
              "cloud_provider_id": 0,
              "name": "local-ssd",
              "has_fixed_size": true,
              "min_size": 375,
              "max_size": 375
            },
            "machine_volume_num": 1,
            "machine_volume_strip_num": 1
          }
        },
        "cloud_env": {
          "cloud_env_id": 1,
          "name": "gcp_cloud_env",
          "description": "yeedu cloud environment",
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          },
          "availabilty_zone": {
            "availabilty_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          },
          "machine_network": {
            "machine_network_conf_id": 1,
            "name": "yeedu_gcp_network",
            "description": null,
            "network_project_id": "modak-yeedu",
            "network_name": "modak-yeedu-spark-vpc",
            "network_tags": [
              "yeedu",
              "iap-allow"
            ],
            "subnet": "custom-subnet-modak-nabu",
            "machine_network_availability_zone": {
              "availability_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            }
          },
          "cloud_project": "modak-yeedu",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modaknabu-svc",
            "description": null,
            "credential_type": {
              "credential_type_id": 0,
              "name": "gcp",
              "cloud_provider_id": 0
            }
          },
          "boot_disk_image": {
            "boot_disk_image_id": 1,
            "name": "gcp_boot_disk",
            "description": "dev boot disk",
            "cloud_provider_id": 0,
            "linux_distro": {
              "linux_distro_id": 0,
              "distro_name": "UBUNTU",
              "distro_version": "20.04 LTS"
            },
            "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
          }
        },
        "hive_metastore_conf": {
          "hive_metastore_conf_id": null,
          "hive_metastore_conf_name": null
        },
        "spark_infra_version": {
          "spark_infra_version_id": 2,
          "spark_version": "3.2.2",
          "hive_version": "3.2.3",
          "hadoop_version": "3.2.4",
          "scala_version": "2.12.15",
          "python_version": "3.9.5",
          "notebook_support": true
        },
        "engine_cluster_spark_config": {
          "max_parallel_spark_job_execution_per_instance": 5,
          "standalone_workers_number": null
        },
        "object_storage_manager": {
          "object_storage_manager_id": 1,
          "name": "yeedu_osm",
          "description": "test",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type_name": "gcp"
          },
          "object_storage_bucket_name": "modak-yeedu-nabu"
        },
        "workflow_job_instance_details": {
          "workflow_job_instance_status": {
            "workflow_job_instance_id": 5,
            "workflow_job_id": 5,
            "status": "EXECUTING",
            "from_date": "2024-01-08T10:44:07.650245+00:00",
            "to_date": "infinity"
          }
        },
        "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
        "created_by": {
          "user_id": 1,
          "username": "YSU0000"
        },
        "modified_by": {
          "user_id": 1,
          "username": "YSU0000"
        },
        "last_update_date": "2024-01-08T10:44:07.650245+00:00",
        "from_date": "2024-01-08T10:44:07.650245+00:00",
        "to_date": "infinity"
      }
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

# Workspace

| Command Name       | Utility                                        |
|--------------------|------------------------------------------------|
|[create](#create-1) | To create a Workspace.                         |
|[list](#list-1)     | To list all the Workspaces.                    |
|[search](#search-1) | To search workspaces by workspace name.        |
|[get](#get-1)       | To get information about a specific Workspace. |
|[edit](#edit-1)     | To edit a specific Workspace.                  |
|[enable](#enable)   | To enable a specific Workspace.                |
|[disable](#disable) | To disable a specific Workspace.               |

### create

```bash
yeedu workspace create -h
```

```bash
usage:  create [-h] [--name NAME] [--description DESCRIPTION]
               [--json-output [{pretty,default}]]
               [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create workspace.
  --description DESCRIPTION
                        Provide description to create workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create example with all the required arguments passed.

```bash
yeedu workspace create --name="spark_jobs_test" --description="Test Spark Jobs"
```

- Console output

```bash
{
  "workspace_id": "1",
  "name": "spark_jobs_test",
  "description": "Test Spark Jobs",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T12:01:56.508Z",
  "from_date": "2024-01-08T12:01:56.508Z",
  "to_date": null
}
```

### list

```bash
yeedu workspace list -h
```

```bash
usage:  list [-h] [--enable [{true,false}]] [--page_number PAGE_NUMBER] [--limit LIMIT]
             [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --enable [{true,false}]
                        Provide enable as true or false to list Workspaces.
  --page_number PAGE_NUMBER
                        To list Workspaces for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Workspaces. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list example with optional arguments passed.

```bash
yeedu workspace list --limit=1 --page_number=2
```

- Console output

```bash
{
  "data": [
    {
      "workspace_id": 1,
      "name": "spark_jobs_test",
      "description": "Test Spark Jobs",
      "job_conf_count": 0,
      "notebook_conf_count": 0,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "active": true,
      "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
      "last_update_date": "2024-01-08T12:01:56.508Z",
      "from_date": "2024-01-08T12:01:56.508Z",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 2,
    "total_objects": 2,
    "total_pages": 2,
    "limit": 1,
    "previous_page": 1
  }
}
```

### search

```bash
yeedu workspace search -h
```

```bash
usage:  search [-h] --workspace_name WORKSPACE_NAME
               [--enable [{true,false}]] [--page_number PAGE_NUMBER]
               [--limit LIMIT] [--json-output [{pretty,default}]]
               [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_name WORKSPACE_NAME
                        Provide workspace name to search workspaces.
  --enable [{true,false}]
                        Provide enable as true or false to search workspaces.
  --page_number PAGE_NUMBER
                        To search workspaces for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of workspaces. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search example with the required argument passed.

```bash
yeedu workspace search --workspace_name="spark_"
```

- Console output

```bash
{
  "data": [
    {
      "workspace_id": 1,
      "name": "spark_jobs_test",
      "description": "Test Spark Jobs",
      "job_conf_count": 9,
      "notebook_conf_count": 1,
      "created_by": {
        "user_id": 1,
        "username": "mandeep.singh@modak.com"
      },
      "modified_by": {
        "user_id": 1,
        "username": "mandeep.singh@modak.com"
      },
      "active": true,
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "last_update_date": "2024-01-08T12:01:56.50868+00:00",
      "from_date": "2024-01-08T12:01:56.50868+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get

```bash
yeedu workspace get -h
```

```bash
usage:  get [-h] [--workspace_id WORKSPACE_ID]
            [--workspace_name WORKSPACE_NAME]
            [--json-output [{pretty,default}]]
            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to get information about a specific Workspace.
  --workspace_name WORKSPACE_NAME
                        Provide workspace_name to get information about a specific Workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get example with any one of the required argument passed.

```bash
yeedu workspace get --workspace_id=1
```

- Console output

```bash
{
  "workspace_id": 1,
  "name": "spark_jobs_test",
  "description": "Test Spark Jobs",
  "job_conf_count": 9,
  "notebook_conf_count": 1,
  "created_by": {
    "user_id": 1,
    "username": "mandeep.singh@modak.com"
  },
  "modified_by": {
    "user_id": 1,
    "username": "mandeep.singh@modak.com"
  },
  "active": true,
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "last_update_date": "2024-01-08T12:01:56.50868+00:00",
  "from_date": "2024-01-08T12:01:56.50868+00:00",
  "to_date": "infinity"
}
```

### edit

```bash
yeedu workspace edit -h
```

```bash
usage:  edit [-h] [--workspace_id WORKSPACE_ID]
             [--workspace_name WORKSPACE_NAME] [--name NAME]
             [--description DESCRIPTION]
             [--json-output [{pretty,default}]]
             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to edit a specific Workspace.
  --workspace_name WORKSPACE_NAME
                        Provide workspace_name to edit a specific Workspace.
  --name NAME           Provide name to edit a specific Workspace.
  --description DESCRIPTION
                        Provide description to edit a specific Workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit example with any one of the required argument '--workspace_id' and other optional argument is passed which is to be updated.

```bash
yeedu workspace edit --workspace_id=1 --description="Test Spark Curation Jobs"
```

- Console output

```bash
{
  "workspace_id": "1",
  "name": "spark_jobs_test",
  "description": "Test Spark Curation Jobs",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T12:01:56.508Z",
  "from_date": "2024-01-08T12:01:56.508Z",
  "to_date": null
}
```

### enable

```bash
yeedu workspace enable -h
```

```bash
usage:  enable [-h] [--workspace_id WORKSPACE_ID]
               [--workspace_name WORKSPACE_NAME]
               [--json-output [{pretty,default}]]
               [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to enable a specific Workspace.
  --workspace_name WORKSPACE_NAME
                        Provide workspace_name to enable a specific Workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- enable example with any one of the required argument passed.

```bash
yeedu workspace enable --workspace_id=1
```

- Console output

```bash
{
  "workspace_id": "1",
  "name": "spark_jobs_test",
  "description": "Test Spark Jobs",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T12:01:56.508Z",
  "from_date": "2024-01-08T12:01:56.508Z",
  "to_date": null
}
```

### disable

```bash
yeedu workspace disable -h
```

```bash
usage:  disable [-h] [--workspace_id WORKSPACE_ID]
                [--workspace_name WORKSPACE_NAME]
                [--json-output [{pretty,default}]]
                [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to disable a specific Workspace.
  --workspace_name WORKSPACE_NAME
                        Provide workspace_name to disable a specific Workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- disable example with any one of the required argument passed.

```bash
yeedu workspace disable --workspace_id=1
```

- Console output

```bash
{
  "workspace_id": "1",
  "name": "spark_jobs_test",
  "description": "Test Spark Jobs",
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T12:01:56.508Z",
  "from_date": "2024-01-08T12:01:56.508Z",
  "to_date": "2024-01-08T12:01:56.508Z"
}
```

## Workspace Access Control

| Command Name                                 | Utility                                                          |
|----------------------------------------------|------------------------------------------------------------------|
|[create-user-access](#create-user-access)   | Assign access to a user on a specific workspace                  |
|[create-group-access](#create-group-access) | Assign access to a group on a specific workspace                 |
|[delete-user-access](#delete-user-access)   | Delete access of a user on a specific workspace                  |
|[delete-group-access](#delete-group-access) | Delete access of a group on a specific workspace                 |
|[list-users](#list-users)                   | To list all the users having access to a workspace.              |
|[search-users](#search-users)               | To search the users having access to a workspace.                |
|[match-user](#match-user)                   | To match the exact username having access to a workspace.        |
|[list-groups](#list-groups)                 | To list all the groups having access to a workspace.             |
|[search-groups](#list-groups)               | To search the groups having access to a workspace.               |
|[match-group](#match-group)                 | To match the exact groupname having access to a workspace.       |
|[get-user-access](#get-user-access)         | To get the permission of the user having access to a workspace.  |
|[get-group-access](#get-group-access)       | To get the permission of the group having access to a workspace. |
|[list-users-access](#list-users-access)     | To list all the permissions of the users having access to a workspace.  |
|[list-groups-access](#list-groups-access)   | To list all the permissions of the groups having access to a workspace. |

### create-user-access

```bash
yeedu workspace create-user-access -h
```

```bash
usage:  create-user-access [-h] --workspace_id WORKSPACE_ID --user_id
                           USER_ID --permission_id PERMISSION_ID
                           [--json-output [{pretty,default}]]
                           [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to assign user access on a workspace.
  --user_id USER_ID     Provide User Id to assign user access on a workspace.
  --permission_id PERMISSION_ID
                        Provide Permission Id to assign user access on a workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default:pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-user-access example with all the required arguments passed.

```bash
yeedu workspace create-user-access --workspace_id=1 --user_id=1 --permission_id=2
```

- Console output

```bash
{
  "auth_workspace_user_id": "1",
  "workspace_id": "1",
  "auth_workspace_perm_id": 2,
  "user_id": "1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T13:08:16.731Z",
  "from_date": "2024-01-08T13:08:16.731Z",
  "to_date": null
}
```

### create-group-access

```bash
yeedu workspace create-group-access -h
```

```bash
usage:  create-group-access [-h] --workspace_id WORKSPACE_ID
                            --group_id GROUP_ID --permission_id
                            PERMISSION_ID
                            [--json-output [{pretty,default}]]
                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to assign group access on a workspace.
  --group_id GROUP_ID   Provide group Id to assign group access on a workspace.
  --permission_id PERMISSION_ID
                        Provide Permission Id to assign group access on a workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-group-access example with optional arguments passed.

```bash
yeedu workspace create-group-access --workspace_id=1 --group_id=1 --permission_id=2
```

- Console output

```bash
{
  "auth_workspace_group_id": "1",
  "workspace_id": "1",
  "auth_workspace_perm_id": 2,
  "group_id": "1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T13:10:50.581Z",
  "from_date": "2024-01-08T13:10:50.581Z",
  "to_date": null
}
```

### delete-user-access

```bash
yeedu workspace delete-user-access -h
```

```bash
usage:  delete-user-access [-h] --workspace_id WORKSPACE_ID --user_id USER_ID
                           --permission_id PERMISSION_ID
                           [--json-output [{pretty,default}]]
                           [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to delete user access on a workspace.
  --user_id USER_ID     Provide User Id to delete user access on a workspace.
  --permission_id PERMISSION_ID
                        Provide Permission Id to delete user access on a workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-user-access example with the required argument passed.

```bash
yeedu workspace delete-user-access --workspace_id=1 --user_id=1 --permission_id=2
```

- Console output

```bash
{
  "message": "Deleted Permission successfully."
}
```

### delete-group-access

```bash
yeedu workspace delete-group-access -h
```

```bash
usage:  delete-group-access [-h] --workspace_id WORKSPACE_ID --group_id GROUP_ID
                            --permission_id PERMISSION_ID
                            [--json-output [{pretty,default}]]
                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to delete group access on a workspace.
  --group_id GROUP_ID   Provide group Id to delete group access on a workspace.
  --permission_id PERMISSION_ID
                        Provide Permission Id to delete group access on a workspace.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-group-access example with all the required arguments passed.

```bash
yeedu workspace delete-group-access --workspace_id=1 --group_id=1 --permission_id=2
```

- Console output

```bash
{
  "message": "Deleted Permission successfully."
}
```

### list-users

```bash
yeedu workspace list-users -h
```

```bash
usage:  list-users [-h] --workspace_id WORKSPACE_ID
                   [--group_id GROUP_ID] [--page_number PAGE_NUMBER]
                   [--limit LIMIT] [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to list all the users.
  --group_id GROUP_ID   Provide group_id to list all the users.
  --page_number PAGE_NUMBER
                        To list users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-users example with the required argument '--workspace_id' passed.

```bash
yeedu workspace list-users --workspace_id=1
```

- Console output

```bash
{
  "data": [
    {
      "user_id": 1,
      "username": "YSU0000",
      "email": "ysu0000@modak.com"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-users

```bash
yeedu workspace search-users -h
```

```bash
usage:  search-users [-h] --workspace_id WORKSPACE_ID --username USERNAME [--group_id GROUP_ID]
                     [--page_number PAGE_NUMBER] [--limit LIMIT] [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to search all the users.
  --username USERNAME   Provide username to search all the users.
  --group_id GROUP_ID   Provide group id to search all the users.
  --page_number PAGE_NUMBER
                        To search users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search example with the required argument passed.

```bash
yeedu workspace search-users --workspace_id=1 --username="YSU"
```

- Console output

```bash
{
  "data": [
    {
      "user_id": 1,
      "username": "YSU0000",
      "email": "ysu0000@modak.com"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### match-user

```bash
yeedu workspace match-user -h
```

```bash
usage:  match-user [-h] --workspace_id WORKSPACE_ID --username USERNAME
                   [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to match all the users.
  --username USERNAME   Provide username to match all the users.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- match example with the required argument passed.

```bash
yeedu workspace match-user --workspace_id=1 --username="YSU0000"
```

- Console output

```bash
{
  "user_id": 1,
  "username": "YSU0000",
  "email": "ysu0000@modak.com",
  "from_date": "2023-12-28T14:01:50.367429+00:00",
  "to_date": "infinity"
}
```

### list-groups

```bash
yeedu workspace list-groups -h
```

```bash
usage:  list-groups [-h] --workspace_id WORKSPACE_ID
                    [--user_id USER_ID] [--page_number PAGE_NUMBER]
                    [--limit LIMIT] [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to list all the groups.
  --user_id USER_ID     Provide a user_id to retrieve a list of all the groups associated with that user.
  --page_number PAGE_NUMBER
                        To list groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-groups example with the required argument '--workspace_id' passed.

```bash
yeedu workspace list-groups --workspace_id=1
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 1,
      "group_name": "modak.com",
      "group_type": "Unified",
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 2,
      "group_name": "Yeedu",
      "group_type": "DynamicMembership",
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 13,
    "total_pages": 7,
    "limit": 2,
    "next_page": 2
  }
}
```

### search-groups

```bash
yeedu workspace search-groups -h
```

```bash
usage:  search-groups [-h] --workspace_id WORKSPACE_ID --groupname
                      GROUPNAME [--user_id USER_ID]
                      [--page_number PAGE_NUMBER] [--limit LIMIT]
                      [--json-output [{pretty,default}]]
                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to search all the groups.
  --groupname GROUPNAME
                        Provide groupname to search all the groups.
  --user_id USER_ID     Provide user id to search all the groups.
  --page_number PAGE_NUMBER
                        To search groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search example with the required argument passed.

```bash
yeedu workspace search-groups --workspace_id=1 --groupname="Yeedu"
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 7,
      "group_name": "Yeedu",
      "group_type": null,
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 11,
      "group_name": "Yeedu Dev_Team",
      "group_type": null,
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 25,
      "group_name": "Yeedu_Backend",
      "group_type": null,
      "from_date": "2024-01-02T09:19:25.770823+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 3,
    "total_pages": 1,
    "limit": 100
  }
}
```

### match-group

```bash
yeedu workspace match-group -h
```

```bash
usage:  match-group [-h] --workspace_id WORKSPACE_ID --groupname GROUPNAME
                    [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to match all the groups.
  --groupname GROUPNAME
                        Provide groupname to match all the groups.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- match example with the required argument passed.

```bash
yeedu workspace match-group --workspace_id=1 --groupname="Yeedu"
```

- Console output

```bash
[
  {
    "group_id": 8,
    "group_name": "Yeedu",
    "group_type": "Unified",
    "from_date": "2023-12-28T14:01:50.367429+00:00",
    "to_date": "infinity"
  },
  {
    "group_id": 7,
    "group_name": "Yeedu",
    "group_type": null,
    "from_date": "2023-12-28T14:01:50.367429+00:00",
    "to_date": "infinity"
  }
]
```

### get-user-access

```bash
yeedu workspace get-user-access -h
```

```bash
usage:  get-user-access [-h] --workspace_id WORKSPACE_ID --user_id USER_ID
                        [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to get the permission of a user.
  --user_id USER_ID     Provide User Id to get the permission of a user.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-user-access example with all the required arguments passed.

```bash
yeedu workspace get-user-access --workspace_id=1 --user_id=1
```

- Console output

```bash
{
  "user_id": "1",
  "username": "YSU0000",
  "workspace": {
    "workspace_id": "1",
    "name": "spark_jobs_test",
    "description": "Test Spark Curation Jobs"
  },
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "user_permission": {
    "auth_workspace_user_id": 3,
    "permission": {
      "auth_workspace_perm_id": 2,
      "name": "EDIT",
      "description": "To list, run and edit a spark job configuration in a workspace"
    },
    "created_by": {
      "user_id": 1,
      "username": "YSU0000"
    },
    "modified_by": {
      "user_id": 1,
      "username": "YSU0000"
    },
    "last_update_date": "2024-01-08T13:08:16.731517+00:00",
    "from_date": "2024-01-08T13:08:16.731517+00:00",
    "to_date": "infinity"
  },
  "group_permission": [
    {
      "auth_workspace_group_id": 1,
      "permission": {
        "auth_workspace_perm_id": 2,
        "name": "EDIT",
        "description": "To list, run and edit a spark job configuration in a workspace"
      },
      "group_id": 1,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-08T13:08:16.731517+00:00",
      "from_date": "2024-01-08T13:08:16.731517+00:00",
      "to_date": "infinity"
    }
  ]
}
```

### get-group-access

```bash
yeedu workspace get-group-access -h
```

```bash
usage:  get-group-access [-h] --workspace_id WORKSPACE_ID --group_id GROUP_ID
                         [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to get the permission of a group.
  --group_id GROUP_ID   Provide Group Id to get the permission of a group.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-group-access example with all the required arguments passed.

```bash
yeedu workspace get-group-access --workspace_id=1 --group_id=1
```

- Console output

```bash
{
  "group_id": "1",
  "group_name": "yeedu-manager",
  "workspace": {
    "workspace_id": "1",
    "name": "spark_jobs_test",
    "description": "Test Spark Curation Jobs"
  },
  "tenant_id": "e67f00ad-68aa-46d0-b32e-f3f8dac5427d",
  "group_permission": {
    "auth_workspace_group_id": "1",
    "permission": {
      "auth_workspace_perm_id": 2,
      "name": "EDIT",
      "description": "To list, run and edit a spark job configuration in a workspace"
    },
    "created_by": {
      "user_id": "1",
      "username": "YSU0000"
    },
    "modified_by": {
      "user_id": "1",
      "username": "YSU0000"
    },
    "last_update_date": "2024-01-08T14:00:26.953Z",
    "from_date": "2024-01-08T14:00:26.953Z",
    "to_date": null
  }
}
```

### list-users-access

```bash
yeedu workspace list-users-access -h
```

```bash
usage:  list-users-access [-h] --workspace_id WORKSPACE_ID --permission_id PERMISSION_ID
                          [--page_number PAGE_NUMBER] [--limit LIMIT]
                          [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to list all the users.
  --permission_id PERMISSION_ID
                        Provide Permission Id to list all the users.
  --page_number PAGE_NUMBER
                        To list users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-users-access example with the required argument '--workspace_id' and '--permission_id' passed.

- Console output

```bash
{
  "data": {
    "workspace_id": 1,
    "workspace_name": "spark_jobs_test",
    "description": "Test Spark Jobs",
    "permission": {
      "permission_id": 2,
      "name": "EDIT",
      "description": "To list, run and edit a spark job configuration in a workspace",
      "users": [
        {
          "user_id": 1,
          "username": "YSU0000",
          "email": "ysu0000@modak.com"
        }
      ]
    }
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### list-groups-access

```bash
yeedu workspace list-groups-access -h
```

```bash
usage:  list-groups-access [-h] --workspace_id WORKSPACE_ID
                           --permission_id PERMISSION_ID
                           [--page_number PAGE_NUMBER] [--limit LIMIT]
                           [--json-output [{pretty,default}]]
                           [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to list all the groups.
  --permission_id PERMISSION_ID
                        Provide Permission Id to list all the groups.
  --page_number PAGE_NUMBER
                        To list groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-groups-access example with the required argument '--workspace_id' and '--permission_id' passed.

```bash
yeedu workspace list-groups-access --workspace_id=1 --permission_id=2
```

- Console output

```bash
{
  "data": {
    "workspace_id": 1,
    "workspace_name": "spark_jobs_test",
    "description": "Test Spark Jobs",
    "permission": {
      "permission_id": 2,
      "name": "EDIT",
      "description": "To list, run and edit a spark job configuration in a workspace",
      "groups": [
        {
          "group_id": 8,
          "group_name": "Yeedu",
          "group_type": "Unified"
        }
      ]
    }
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

# Job

## Spark Job Configuration

| Command Name                   | Utility                                                          |
|--------------------------------|------------------------------------------------------------------|
|[create-conf](#create-conf-1)   | To create the Spark Job Configuration.                           |
|[list-confs](#list-confs-1)     | To list all the available Job Configurations.                    |
|[search-confs](#search-confs-1) | To search job configurations by job conf name in a workspace.    |
|[get-conf](#get-conf-1)         | To get the information about a specific Spark Job Configuration. |
|[edit-conf](#edit-conf-1)       | To edit the Spark Job Configuration.                             |
|[enable-conf](#enable-conf)     | To enable a specific Spark Job Configuration.                    |
|[disable-conf](#disable-conf)   | To disable a specific Spark Job Configuration.                   |

### create-conf

```bash
yeedu job create-conf -h
```

```bash
usage:  create-conf [-h] [--cluster_id CLUSTER_ID] [--cluster_name CLUSTER_NAME]
                    --workspace_id WORKSPACE_ID --name NAME [--files [FILES]]
                    [--properties-file [PROPERTIES_FILE]] [--conf CONF [CONF ...]]
                    [--packages [PACKAGES]] [--repositories [REPOSITORIES]]
                    [--jars [JARS]] [--archives [ARCHIVES]]
                    [--driver-memory [DRIVER_MEMORY]]
                    [--driver-java-options [DRIVER_JAVA_OPTIONS]]
                    [--driver-library-path [DRIVER_LIBRARY_PATH]]
                    [--driver-class-path [DRIVER_CLASS_PATH]]
                    [--executor-memory [EXECUTOR_MEMORY]] [--driver-cores [DRIVER_CORES]]
                    [--total-executor-cores [TOTAL_EXECUTOR_CORES]]
                    [--executor-cores [EXECUTOR_CORES]] [--num-executors [NUM_EXECUTORS]]
                    [--principal [PRINCIPAL]] [--keytab [KEYTAB]] [--queue [QUEUE]]
                    [--job-class-name [JOB_CLASS_NAME]] [--job-command [JOB_COMMAND]]
                    [--job-arguments [JOB_ARGUMENTS]]
                    [--job-raw-scala-code JOB_RAW_SCALA_CODE] --job-type {Raw
                    Scala,Jar,Python3,SQL} [--max_concurrency MAX_CONCURRENCY]
                    [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --cluster_id CLUSTER_ID
                        Provide cluster_id to create a Spark Job Configuration.
  --cluster_name CLUSTER_NAME
                        Provide cluster_name to create a Spark Job Configuration.
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to create a Spark Job Configuration.
  --name NAME           Provide name to create a Spark Job Configuration.
  --files [FILES]       Provide files to create a Spark Job Configuration.
  --properties-file [PROPERTIES_FILE]
                        Provide properties-file to create a Spark Job Configuration.
  --conf CONF [CONF ...]
                        Provide conf to create a Spark Job Configuration.
  --packages [PACKAGES]
                        Provide packages to create a Spark Job Configuration.
  --repositories [REPOSITORIES]
                        Provide repositories to create a Spark Job Configuration.
  --jars [JARS]         Provide jars to create a Spark Job Configuration.
  --archives [ARCHIVES]
                        Provide archives to create a Spark Job Configuration.
  --driver-memory [DRIVER_MEMORY]
                        Provide driver-memory to create a Spark Job Configuration.
  --driver-java-options [DRIVER_JAVA_OPTIONS]
                        Provide driver-java-options to create a Spark Job Configuration.
  --driver-library-path [DRIVER_LIBRARY_PATH]
                        Provide driver-library-path to create a Spark Job Configuration.
  --driver-class-path [DRIVER_CLASS_PATH]
                        Provide driver-class-path to create a Spark Job Configuration.
  --executor-memory [EXECUTOR_MEMORY]
                        Provide executor-memory to create a Spark Job Configuration.
  --driver-cores [DRIVER_CORES]
                        Provide driver-cores to create a Spark Job Configuration.
  --total-executor-cores [TOTAL_EXECUTOR_CORES]
                        Provide total-executor-cores to create a Spark Job Configuration.
  --executor-cores [EXECUTOR_CORES]
                        Provide executor-cores to create a Spark Job Configuration.
  --num-executors [NUM_EXECUTORS]
                        Provide num-executors to create a Spark Job Configuration.
  --principal [PRINCIPAL]
                        Provide principal to create a Spark Job Configuration.
  --keytab [KEYTAB]     Provide keytab to create a Spark Job Configuration.
  --queue [QUEUE]       Provide queue to create a Spark Job Configuration.
  --job-class-name [JOB_CLASS_NAME]
                        Provide job-class-name to create a Spark Job Configuration.
  --job-command [JOB_COMMAND]
                        Provide job-command to create a Spark Job Configuration.
  --job-arguments [JOB_ARGUMENTS]
                        Provide job-arguments to create a Spark Job Configuration.
  --job-raw-scala-code JOB_RAW_SCALA_CODE
                        Provide job-raw-scala-code file path to create a Spark Job
                        Configuration.
  --job-type {Raw Scala,Jar,Python3,SQL}
                        Provide job-raw-scala-code file path to create a Spark Job
                        Configuration.
  --max_concurrency MAX_CONCURRENCY
                        Provide max_concurrency number to limit the number of jobs
                        submitted.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-conf example with all the required and optional arguments passed.

```bash
yeedu job create-conf --cluster_id=1 --workspace_id=1 --name="spark_examples" --job-class-name="org.apache.spark.examples.SparkPi" --job-command="file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar" --job-arguments=500 --job-type=Jar
```

- Console output

```bash
{
  "job_conf_id": "1",
  "name": "spark_examples",
  "cluster_id": "1",
  "workspace_id": "1",
  "spark_job_type_lang_id": 1,
  "max_concurrency": "0",
  "job_class_name": "org.apache.spark.examples.SparkPi",
  "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
  "job_arguments": "500",
  "job_rawScalaCode": null,
  "files": null,
  "properties_file": null,
  "conf": null,
  "packages": null,
  "repositories": null,
  "jars": null,
  "archives": null,
  "driver_memory": null,
  "driver_java_options": null,
  "driver_library_path": null,
  "driver_class_path": null,
  "executor_memory": null,
  "driver_cores": null,
  "total_executor_cores": null,
  "executor_cores": null,
  "num_executors": null,
  "principal": null,
  "keytab": null,
  "queue": null,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T14:56:51.539Z",
  "from_date": "2024-01-08T14:56:51.539Z",
  "to_date": null
}
```

### list-confs

```bash
yeedu job list-confs -h
```

```bash
usage:  list-confs [-h] --workspace_id WORKSPACE_ID
                   [--enable [{true,false}]]
                   [--page_number PAGE_NUMBER] [--limit LIMIT]
                   [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        To list Job Configurations of a specific workspace.
  --enable [{true,false}]
                        Provide enable as true or false to list Job Configurations of a specific workspace.
  --page_number PAGE_NUMBER
                        To list Job Configurations for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Job Configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-confs example with required and optional arguments passed.

```bash
yeedu job list-confs --workspace_id=1 --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "job_conf_id": 1,
      "name": "spark_examples",
      "cluster_info": {
        "cluster_id": 1,
        "name": "yeedu_instance",
        "description": "Test yeedu instance",
        "labels": {
          "test": "yeedu",
          "resource": "yeedu",
          "vm": "yeedu_node",
          "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
        },
        "idle_timeout_ms": 600000,
        "auto_shutdown": true,
        "cluster_status": "RUNNING",
        "cluster_type": "YEEDU",
        "compute_engine_id": 1,
        "instance_size": 1,
        "is_spot_instance": false,
        "enable_public_ip": false,
        "block_project_ssh_keys": false,
        "min_instances": 1,
        "max_instances": 3,
        "total_ycu": null,
        "bootstrap_shell_script": null,
        "spark_config_id": null,
        "cluster_conf": {
          "cluster_conf_id": 1,
          "cluster_conf_name": "n1-standard-4",
          "description": null,
          "machine_type_category": "general_purpose",
          "machine_type": {
            "machine_type_id": 64,
            "name": "n1-standard-4",
            "vcpus": 4,
            "memory": "15 GiB",
            "has_cuda": false,
            "gpu_model": null,
            "gpus": null,
            "gpu_memory": null
          },
          "machine_volume_conf": {
            "volume_conf_id": 1,
            "name": "volume_gcp",
            "description": null,
            "encrypted": true,
            "size": 375,
            "disk_machine_type": {
              "disk_machine_type_id": 4,
              "cloud_provider_id": 0,
              "name": "local-ssd",
              "has_fixed_size": true,
              "min_size": 375,
              "max_size": 375
            },
            "machine_volume_num": 1,
            "machine_volume_strip_num": 1
          }
        },
        "cloud_env": {
          "cloud_env_id": 1,
          "name": "gcp_cloud_env",
          "description": "yeedu cloud environment",
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          },
          "availabilty_zone": {
            "availabilty_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          },
          "machine_network": {
            "machine_network_conf_id": 1,
            "name": "yeedu_gcp_network",
            "description": null,
            "network_project_id": "modak-yeedu",
            "network_name": "modak-yeedu-spark-vpc",
            "network_tags": [
              "yeedu",
              "iap-allow"
            ],
            "subnet": "custom-subnet-modak-yeedu",
            "machine_network_availability_zone": {
              "availability_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            }
          },
          "cloud_project": "modak-yeedu",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type": {
              "credential_type_id": 0,
              "name": "gcp",
              "cloud_provider_id": 0
            }
          },
          "boot_disk_image": {
            "boot_disk_image_id": 1,
            "name": "gcp_boot_disk",
            "description": "dev boot disk",
            "cloud_provider_id": 0,
            "linux_distro": {
              "linux_distro_id": 0,
              "distro_name": "UBUNTU",
              "distro_version": "20.04 LTS"
            },
            "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
          }
        },
        "hive_metastore_conf": {
          "hive_metastore_conf_id": null,
          "hive_metastore_conf_name": null
        },
        "spark_infra_version": {
          "spark_infra_version_id": 0,
          "spark_version": "3.2.2",
          "hive_version": "3.2.3",
          "hadoop_version": "3.2.4",
          "scala_version": "2.12.15",
          "python_version": "3.9.5",
          "notebook_support": true
        },
        "engine_cluster_spark_config": {
          "max_parallel_spark_job_execution_per_instance": 5,
          "standalone_workers_number": null
        },
        "object_storage_manager": {
          "object_storage_manager_id": 1,
          "name": "yeedu_osm",
          "description": null,
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type_name": "gcp"
          },
          "object_storage_bucket_name": "modak-yeedu-nabu"
        }
      },
      "workspace": {
        "workspace_id": 1,
        "name": "spark_jobs_test",
        "description": "Test Spark Jobs"
      },
      "job_count": 0,
      "spark_job_type": {
        "job_type": "JOB",
        "language": "Jar"
      },
      "max_concurrency": 0,
      "last_job_run": {
        "job_id": null,
        "job_status": null
      },
      "job_class_name": "org.apache.spark.examples.SparkPi",
      "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
      "job_arguments": "500",
      "job_rawScalaCode": null,
      "files": null,
      "properties_file": null,
      "conf": null,
      "packages": null,
      "repositories": null,
      "jars": null,
      "archives": null,
      "driver_memory": null,
      "driver_java_options": null,
      "driver_library_path": null,
      "driver_class_path": null,
      "executor_memory": null,
      "driver_cores": null,
      "total_executor_cores": null,
      "executor_cores": null,
      "num_executors": null,
      "principal": null,
      "keytab": null,
      "queue": null,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "active": true,
      "last_update_date": "2024-01-08T14:56:51.53996+00:00",
      "from_date": "2024-01-08T14:56:51.53996+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-confs

```bash
yeedu job search-confs -h
```

```bash
usage:  search-confs [-h] --workspace_id WORKSPACE_ID --job_conf_name
                     JOB_CONF_NAME [--enable [{true,false}]]
                     [--page_number PAGE_NUMBER] [--limit LIMIT]
                     [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to search job configurations in it.
  --job_conf_name JOB_CONF_NAME
                        Provide job_conf_name to search job configurations.
  --enable [{true,false}]
                        Provide enable as true or false to search job configurations.
  --page_number PAGE_NUMBER
                        To search job configurations for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of job configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-confs example with required and optional arguments passed.

```bash
yeedu job search-confs --workspace_id=1 --job_conf_name="spark_" --enable=true --limit=2
```

- Console output

```bash
{
  "data": [
    {
      "job_conf_id": 1,
      "name": "spark_examples",
      "cluster_info": {
        "cluster_id": 1,
        "name": "yeedu_instance",
        "description": "Test yeedu instance",
        "labels": {
          "test": "yeedu",
          "resource": "yeedu",
          "vm": "yeedu_node",
          "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
        },
        "idle_timeout_ms": 600000,
        "auto_shutdown": true,
        "cluster_status": "RUNNING",
        "cluster_type": "YEEDU",
        "compute_engine_id": 1,
        "instance_size": 1,
        "is_spot_instance": false,
        "enable_public_ip": false,
        "block_project_ssh_keys": false,
        "min_instances": 1,
        "max_instances": 3,
        "total_ycu": null,
        "bootstrap_shell_script": null,
        "spark_config_id": null,
        "cluster_conf": {
          "cluster_conf_id": 1,
          "cluster_conf_name": "n1-standard-4",
          "description": null,
          "machine_type_category": "general_purpose",
          "machine_type": {
            "machine_type_id": 64,
            "name": "n1-standard-4",
            "vcpus": 4,
            "memory": "15 GiB",
            "has_cuda": false,
            "gpu_model": null,
            "gpus": null,
            "gpu_memory": null
          },
          "machine_volume_conf": {
            "volume_conf_id": 1,
            "name": "volume_gcp",
            "description": null,
            "encrypted": true,
            "size": 375,
            "disk_machine_type": {
              "disk_machine_type_id": 4,
              "cloud_provider_id": 0,
              "name": "local-ssd",
              "has_fixed_size": true,
              "min_size": 375,
              "max_size": 375
            },
            "machine_volume_num": 1,
            "machine_volume_strip_num": 1
          }
        },
        "cloud_env": {
          "cloud_env_id": 1,
          "name": "gcp_cloud_env",
          "description": "yeedu cloud environment",
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          },
          "availabilty_zone": {
            "availabilty_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          },
          "machine_network": {
            "machine_network_conf_id": 1,
            "name": "yeedu_gcp_network",
            "description": null,
            "network_project_id": "modak-yeedu",
            "network_name": "modak-yeedu-spark-vpc",
            "network_tags": [
              "yeedu",
              "iap-allow"
            ],
            "subnet": "custom-subnet-modak-yeedu",
            "machine_network_availability_zone": {
              "availability_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            }
          },
          "cloud_project": "modak-yeedu",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type": {
              "credential_type_id": 0,
              "name": "gcp",
              "cloud_provider_id": 0
            }
          },
          "boot_disk_image": {
            "boot_disk_image_id": 1,
            "name": "gcp_boot_disk",
            "description": "dev boot disk",
            "cloud_provider_id": 0,
            "linux_distro": {
              "linux_distro_id": 0,
              "distro_name": "UBUNTU",
              "distro_version": "20.04 LTS"
            },
            "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
          }
        },
        "hive_metastore_conf": {
          "hive_metastore_conf_id": null,
          "hive_metastore_conf_name": null
        },
        "spark_infra_version": {
          "spark_infra_version_id": 0,
          "spark_version": "3.2.2",
          "hive_version": "3.2.3",
          "hadoop_version": "3.2.4",
          "scala_version": "2.12.15",
          "python_version": "3.9.5",
          "notebook_support": true
        },
        "engine_cluster_spark_config": {
          "max_parallel_spark_job_execution_per_instance": 5,
          "standalone_workers_number": null
        },
        "object_storage_manager": {
          "object_storage_manager_id": 1,
          "name": "yeedu_osm",
          "description": null,
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type_name": "gcp"
          },
          "object_storage_bucket_name": "modak-yeedu-nabu"
        }
      },
      "workspace": {
        "workspace_id": 1,
        "name": "spark_jobs_test",
        "description": "Test Spark Jobs"
      },
      "job_count": 0,
      "spark_job_type": {
        "job_type": "JOB",
        "language": "Jar"
      },
      "max_concurrency": 0,
      "last_job_run": {
        "job_id": null,
        "job_status": null
      },
      "job_class_name": "org.apache.spark.examples.SparkPi",
      "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
      "job_arguments": "500",
      "job_rawScalaCode": null,
      "files": null,
      "properties_file": null,
      "conf": null,
      "packages": null,
      "repositories": null,
      "jars": null,
      "archives": null,
      "driver_memory": null,
      "driver_java_options": null,
      "driver_library_path": null,
      "driver_class_path": null,
      "executor_memory": null,
      "driver_cores": null,
      "total_executor_cores": null,
      "executor_cores": null,
      "num_executors": null,
      "principal": null,
      "keytab": null,
      "queue": null,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "active": true,
      "last_update_date": "2024-01-08T14:56:51.53996+00:00",
      "from_date": "2024-01-08T14:56:51.53996+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-conf

```bash
yeedu job get-conf -h
```

```bash
usage:  get-conf [-h] --workspace_id WORKSPACE_ID
                 [--job_conf_id JOB_CONF_ID]
                 [--job_conf_name JOB_CONF_NAME]
                 [--json-output [{pretty,default}]]
                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to get information about a specific Spark Job Configuration.
  --job_conf_id JOB_CONF_ID
                        Provide Job Config Id to get information about a specific Spark Job Configuration.
  --job_conf_name JOB_CONF_NAME
                        Provide Job Config name to get information about a specific Spark Job Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-conf example with optional and required argument passed.

```bash
yeedu job get-conf --workspace_id=1 --job_conf_id=1
```

- Console output

```bash
{
  "job_conf_id": 1,
  "name": "spark_examples",
  "cluster_info": {
    "cluster_id": 1,
    "name": "yeedu_instance",
    "description": "Test yeedu instance",
    "labels": {
      "test": "yeedu",
      "resource": "yeedu",
      "vm": "yeedu_node",
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
    },
    "idle_timeout_ms": 600000,
    "auto_shutdown": true,
    "cluster_status": "RUNNING",
    "cluster_type": "YEEDU",
    "compute_engine_id": 1,
    "instance_size": 1,
    "is_spot_instance": false,
    "enable_public_ip": false,
    "block_project_ssh_keys": false,
    "min_instances": 1,
    "max_instances": 3,
    "total_ycu": null,
    "bootstrap_shell_script": null,
    "spark_config_id": null,
    "cluster_conf": {
      "cluster_conf_id": 1,
      "cluster_conf_name": "n1-standard-4",
      "description": null,
      "machine_type_category": "general_purpose",
      "machine_type": {
        "machine_type_id": 64,
        "name": "n1-standard-4",
        "vcpus": 4,
        "memory": "15 GiB",
        "has_cuda": false,
        "gpu_model": null,
        "gpus": null,
        "gpu_memory": null
      },
      "machine_volume_conf": {
        "volume_conf_id": 1,
        "name": "volume_gcp",
        "description": null,
        "encrypted": true,
        "size": 375,
        "disk_machine_type": {
          "disk_machine_type_id": 4,
          "cloud_provider_id": 0,
          "name": "local-ssd",
          "has_fixed_size": true,
          "min_size": 375,
          "max_size": 375
        },
        "machine_volume_num": 1,
        "machine_volume_strip_num": 1
      }
    },
    "cloud_env": {
      "cloud_env_id": 1,
      "name": "gcp_cloud_env",
      "description": "yeedu cloud environment",
      "cloud_provider": {
        "cloud_provider_id": 0,
        "name": "gcp"
      },
      "availabilty_zone": {
        "availabilty_zone_id": 75,
        "name": "us-central1-a",
        "cloud_provider_id": 0,
        "region": "us-central1",
        "description": "Council Bluffs, Iowa, North America"
      },
      "machine_network": {
        "machine_network_conf_id": 1,
        "name": "yeedu_gcp_network",
        "description": null,
        "network_project_id": "modak-yeedu",
        "network_name": "modak-yeedu-spark-vpc",
        "network_tags": [
          "yeedu",
          "iap-allow"
        ],
        "subnet": "custom-subnet-modak-yeedu",
        "machine_network_availability_zone": {
          "availability_zone_id": 75,
          "name": "us-central1-a",
          "cloud_provider_id": 0,
          "region": "us-central1",
          "description": "Council Bluffs, Iowa, North America"
        }
      },
      "cloud_project": "modak-yeedu",
      "credentials_config": {
        "credential_config_id": 1,
        "name": "modakyeedu-svc",
        "description": null,
        "credential_type": {
          "credential_type_id": 0,
          "name": "gcp",
          "cloud_provider_id": 0
        }
      },
      "boot_disk_image": {
        "boot_disk_image_id": 1,
        "name": "gcp_boot_disk",
        "description": "dev boot disk",
        "cloud_provider_id": 0,
        "linux_distro": {
          "linux_distro_id": 0,
          "distro_name": "UBUNTU",
          "distro_version": "20.04 LTS"
        },
        "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
      }
    },
    "hive_metastore_conf": {
      "hive_metastore_conf_id": null,
      "hive_metastore_conf_name": null
    },
    "spark_infra_version": {
      "spark_infra_version_id": 0,
      "spark_version": "3.2.2",
      "hive_version": "3.2.3",
      "hadoop_version": "3.2.4",
      "scala_version": "2.12.15",
      "python_version": "3.9.5",
      "notebook_support": true
    },
    "engine_cluster_spark_config": {
      "max_parallel_spark_job_execution_per_instance": 5,
      "standalone_workers_number": null
    },
    "object_storage_manager": {
      "object_storage_manager_id": 1,
      "name": "yeedu_osm",
      "description": null,
      "credentials_config": {
        "credential_config_id": 1,
        "name": "modakyeedu-svc",
        "description": null,
        "credential_type_name": "gcp"
      },
      "object_storage_bucket_name": "modak-yeedu-nabu"
    }
  },
  "workspace": {
    "workspace_id": 1,
    "name": "spark_jobs_test",
    "description": "Test Spark Jobs"
  },
  "job_count": 0,
  "spark_job_type": {
    "job_type": "JOB",
    "language": "Jar"
  },
  "max_concurrency": 0,
  "last_job_run": {
    "job_id": null,
    "job_status": null
  },
  "job_class_name": "org.apache.spark.examples.SparkPi",
  "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
  "job_arguments": "500",
  "job_rawScalaCode": null,
  "files": null,
  "properties_file": null,
  "conf": null,
  "packages": null,
  "repositories": null,
  "jars": null,
  "archives": null,
  "driver_memory": null,
  "driver_java_options": null,
  "driver_library_path": null,
  "driver_class_path": null,
  "executor_memory": null,
  "driver_cores": null,
  "total_executor_cores": null,
  "executor_cores": null,
  "num_executors": null,
  "principal": null,
  "keytab": null,
  "queue": null,
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "active": true,
  "last_update_date": "2024-01-08T14:56:51.53996+00:00",
  "from_date": "2024-01-08T14:56:51.53996+00:00",
  "to_date": "infinity"
}
```

### edit-conf

```bash
yeedu job edit-conf -h
```

```bash
usage:  edit-conf [-h] --workspace_id WORKSPACE_ID
                  [--job_conf_id JOB_CONF_ID]
                  [--job_conf_name JOB_CONF_NAME]
                  [--cluster_id CLUSTER_ID]
                  [--cluster_name CLUSTER_NAME] [--files [FILES]]
                  [--properties-file [PROPERTIES_FILE]]
                  [--conf CONF [CONF ...]] [--packages [PACKAGES]]
                  [--repositories [REPOSITORIES]] [--jars [JARS]]
                  [--archives [ARCHIVES]]
                  [--driver-memory [DRIVER_MEMORY]]
                  [--driver-java-options [DRIVER_JAVA_OPTIONS]]
                  [--driver-library-path [DRIVER_LIBRARY_PATH]]
                  [--driver-class-path [DRIVER_CLASS_PATH]]
                  [--executor-memory [EXECUTOR_MEMORY]]
                  [--driver-cores [DRIVER_CORES]]
                  [--total-executor-cores [TOTAL_EXECUTOR_CORES]]
                  [--executor-cores [EXECUTOR_CORES]]
                  [--num-executors [NUM_EXECUTORS]]
                  [--principal [PRINCIPAL]] [--keytab [KEYTAB]]
                  [--queue [QUEUE]]
                  [--job-class-name [JOB_CLASS_NAME]] [--name [NAME]]
                  [--job-command [JOB_COMMAND]]
                  [--job-arguments [JOB_ARGUMENTS]]
                  [--job-raw-scala-code JOB_RAW_SCALA_CODE]
                  [--max_concurrency MAX_CONCURRENCY]
                  [--json-output [{pretty,default}]]
                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to edit a Spark Job Configuration.
  --job_conf_id JOB_CONF_ID
                        Provide Job Config Id to edit a Spark Job Configuration.
  --job_conf_name JOB_CONF_NAME
                        Provide Job Config Name to edit a Spark Job Configuration.
  --cluster_id CLUSTER_ID
                        Provide cluster_id to edit a Spark Job Configuration.
  --cluster_name CLUSTER_NAME
                        Provide cluster_name to edit a Spark Job Configuration.
  --files [FILES]       Provide files to edit a Spark Job Configuration.
  --properties-file [PROPERTIES_FILE]
                        Provide properties-file to edit a Spark Job Configuration.
  --conf CONF [CONF ...]
                        Provide conf to edit a Spark Job Configuration.
  --packages [PACKAGES]
                        Provide packages to edit a Spark Job Configuration.
  --repositories [REPOSITORIES]
                        Provide repositories to edit a Spark Job Configuration.
  --jars [JARS]         Provide jars to edit a Spark Job Configuration.
  --archives [ARCHIVES]
                        Provide archives to edit a Spark Job Configuration.
  --driver-memory [DRIVER_MEMORY]
                        Provide driver-memory to edit a Spark Job Configuration.
  --driver-java-options [DRIVER_JAVA_OPTIONS]
                        Provide driver-java-options to edit a Spark Job Configuration.
  --driver-library-path [DRIVER_LIBRARY_PATH]
                        Provide driver-library-path to edit a Spark Job Configuration.
  --driver-class-path [DRIVER_CLASS_PATH]
                        Provide driver-class-path to edit a Spark Job Configuration.
  --executor-memory [EXECUTOR_MEMORY]
                        Provide executor-memory to edit a Spark Job Configuration.
  --driver-cores [DRIVER_CORES]
                        Provide driver-cores to edit a Spark Job Configuration.
  --total-executor-cores [TOTAL_EXECUTOR_CORES]
                        Provide total-executor-cores to edit a Spark Job Configuration.
  --executor-cores [EXECUTOR_CORES]
                        Provide executor-cores to edit a Spark Job Configuration.
  --num-executors [NUM_EXECUTORS]
                        Provide num-executors to edit a Spark Job Configuration.
  --principal [PRINCIPAL]
                        Provide principal to edit a Spark Job Configuration.
  --keytab [KEYTAB]     Provide keytab to edit a Spark Job Configuration.
  --queue [QUEUE]       Provide queue to edit a Spark Job Configuration.
  --job-class-name [JOB_CLASS_NAME]
                        Provide job-class-name to edit a Spark Job Configuration.
  --name [NAME]         Provide name to edit a Spark Job Configuration.
  --job-command [JOB_COMMAND]
                        Provide job-command to edit a Spark Job Configuration.
  --job-arguments [JOB_ARGUMENTS]
                        Provide job-arguments to edit a Spark Job Configuration.
  --job-raw-scala-code JOB_RAW_SCALA_CODE
                        Provide job-raw-scala-code file path to edit a Spark Job Configuration.
  --max_concurrency MAX_CONCURRENCY
                        Provide max_concurrency number to limit the number of jobs submitted.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit-conf example with the required arguments and other optional arguments passed which is to be updated.

```bash
yeedu job edit-conf --workspace_id=1 --job_conf_name="spark_examples" --job-arguments=1000
```

- Console output

```bash
{
  "job_conf_id": "1",
  "name": "spark_examples",
  "cluster_id": "1",
  "workspace_id": "1",
  "spark_job_type_lang_id": 1,
  "max_concurrency": "0",
  "job_class_name": "org.apache.spark.examples.SparkPi",
  "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
  "job_arguments": "1000",
  "job_rawScalaCode": null,
  "files": null,
  "properties_file": null,
  "conf": null,
  "packages": null,
  "repositories": null,
  "jars": null,
  "archives": null,
  "driver_memory": null,
  "driver_java_options": null,
  "driver_library_path": null,
  "driver_class_path": null,
  "executor_memory": null,
  "driver_cores": null,
  "total_executor_cores": null,
  "executor_cores": null,
  "num_executors": null,
  "principal": null,
  "keytab": null,
  "queue": null,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T15:37:55.738Z",
  "from_date": "2024-01-08T14:56:51.539Z",
  "to_date": null
}
```

### enable-conf

```bash
yeedu job enable-conf -h
```

```bash
usage:  enable-conf [-h] --workspace_id WORKSPACE_ID
                    [--job_conf_id JOB_CONF_ID]
                    [--job_conf_name JOB_CONF_NAME]
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to enable the Spark Job Configuration.
  --job_conf_id JOB_CONF_ID
                        Provide Job Config Id to enable the Spark Job Configuration.
  --job_conf_name JOB_CONF_NAME
                        Provide Job Config Name to enable the Spark Job Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- enable-conf example with the required arguments passed.

```bash
yeedu job enable-conf --workspace_id=1 --job_conf_id=1
```

- Console output

```bash
{
  "job_conf_id": "1",
  "name": "spark_examples",
  "cluster_id": "1",
  "workspace_id": "1",
  "spark_job_type_lang_id": 1,
  "max_concurrency": "0",
  "job_class_name": "org.apache.spark.examples.SparkPi",
  "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
  "job_arguments": "1000",
  "job_rawScalaCode": null,
  "files": null,
  "properties_file": null,
  "conf": null,
  "packages": null,
  "repositories": null,
  "jars": null,
  "archives": null,
  "driver_memory": null,
  "driver_java_options": null,
  "driver_library_path": null,
  "driver_class_path": null,
  "executor_memory": null,
  "driver_cores": null,
  "total_executor_cores": null,
  "executor_cores": null,
  "num_executors": null,
  "principal": null,
  "keytab": null,
  "queue": null,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T15:45:35.462Z",
  "from_date": "2024-01-08T14:56:51.539Z",
  "to_date": null
}
```

### disable-conf

```bash
yeedu job disable-conf -h
```

```bash
usage:  disable-conf [-h] --workspace_id WORKSPACE_ID
                     [--job_conf_id JOB_CONF_ID]
                     [--job_conf_name JOB_CONF_NAME]
                     [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to disable the Spark Job Configuration.
  --job_conf_id JOB_CONF_ID
                        Provide Job Config Id to disable the Spark Job Configuration.
  --job_conf_name JOB_CONF_NAME
                        Provide Job Config Name to disable the Spark Job Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- disable-conf example with the required arguments passed.

```bash
yeedu job disable-conf --workspace_id=1 --job_conf_id=1
```

- Console output

```bash
{
  "job_conf_id": "1",
  "name": "spark_examples",
  "cluster_id": "1",
  "workspace_id": "1",
  "spark_job_type_lang_id": 1,
  "max_concurrency": "0",
  "job_class_name": "org.apache.spark.examples.SparkPi",
  "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
  "job_arguments": "1000",
  "job_rawScalaCode": null,
  "files": null,
  "properties_file": null,
  "conf": null,
  "packages": null,
  "repositories": null,
  "jars": null,
  "archives": null,
  "driver_memory": null,
  "driver_java_options": null,
  "driver_library_path": null,
  "driver_class_path": null,
  "executor_memory": null,
  "driver_cores": null,
  "total_executor_cores": null,
  "executor_cores": null,
  "num_executors": null,
  "principal": null,
  "keytab": null,
  "queue": null,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-08T15:45:24.088Z",
  "from_date": "2024-01-08T14:56:51.539Z",
  "to_date": "2024-01-08T15:45:24.088Z"
}
```

## Spark Job Instance

| Command Name             | Utility                                                                |
|--------------------------|------------------------------------------------------------------------|
|[start](#start-1)         | To run a Spark Job Instance.                                           |
|[list](#list-2)           | To list all the available Spark Job Instances.                         |
|[search](#search-2)       | To search Spark Job Instances by similar job id.                       |
|[get](#get-2)             | To get information about a specific Spark Job Instance.                |
|[stop](#stop-1)           | To stop a specific Spark Job Instance.                                 |
|[get-status](#get-status) | To get all the status information about a specific Spark Job Instance. |
|[logs](#logs-1)           | To download Spark Job Instance logs by job id.                         |

### start

```bash
yeedu job start -h
```

```bash
usage:  start [-h] [--job_conf_id JOB_CONF_ID]
              [--job_conf_name JOB_CONF_NAME] --workspace_id
              WORKSPACE_ID [--json-output [{pretty,default}]]
              [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --job_conf_id JOB_CONF_ID
                        To run a Spark Job Instance, enter job_conf_id.
  --job_conf_name JOB_CONF_NAME
                        To run a Spark Job Instance, enter job_conf_name.
  --workspace_id WORKSPACE_ID
                        To run a Spark Job Instance, enter workspace_id.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- start example with one of the required argument passed.

```bash
yeedu job start --workspace_id=1 --job_conf_id=1
```

- Console output

```bash
{
  "job_id": "1",
  "job_conf_id": "1",
  "cluster_id": "1",
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-09T07:06:00.301Z",
  "from_date": "2024-01-09T07:06:00.301Z",
  "to_date": null
}
```

### list

```bash
yeedu job list -h
```

```bash
usage:  list [-h] --workspace_id WORKSPACE_ID [--cluster_id CLUSTER_ID]
             [--job_conf_id JOB_CONF_ID] [--job_conf_name JOB_CONF_NAME]
             [--job_status {submitted,running,done,error,terminated,stopping,stopped}]
             [--page_number PAGE_NUMBER] [--limit LIMIT]
             [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        To list Spark Job Instances of a specific workspace_id.
  --cluster_id CLUSTER_ID
                        To list Spark Job Instances of a specific cluster_id.
  --job_conf_id JOB_CONF_ID
                        To list Spark Job Instances of a specific job_conf_id.
  --job_conf_name JOB_CONF_NAME
                        To list Spark Job Instances of a specific job_conf_name.
  --job_status {submitted,running,done,error,terminated,stopping,stopped}
                        To list Spark Job Instances of a specific job_status.
  --page_number PAGE_NUMBER
                        To list Spark Job Instances for a specific page_number.
                        (default: 1)
  --limit LIMIT         Provide limit to list number of job instances. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list example to with required and optional arguments passed.

```bash
yeedu job list --workspace_id=1 --limit=2
```

- Console output

```bash
{
  "data": [
    {
      "job_id": 3,
      "job_application_id": "app-20231004073629-0003",
      "job_status": "SUBMITTED",
      "total_job_time": 185.698294,
      "job_conf": {
        "job_conf_id": 1,
        "name": "spark_examples",
        "cluster_info": {
          "cluster_id": 1,
          "name": "yeedu_instance",
          "description": "Test yeedu instance",
          "labels": {
            "test": "yeedu",
            "resource": "yeedu",
            "vm": "yeedu_node",
            "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
          },
          "idle_timeout_ms": 600000,
          "auto_shutdown": true,
          "cluster_status": "RUNNING",
          "cluster_type": "YEEDU",
          "compute_engine_id": 1,
          "instance_size": 1,
          "is_spot_instance": false,
          "enable_public_ip": false,
          "block_project_ssh_keys": false,
          "min_instances": 1,
          "max_instances": 3,
          "total_ycu": null,
          "bootstrap_shell_script": null,
          "spark_config_id": null,
          "cluster_conf": {
            "cluster_conf_id": 1,
            "cluster_conf_name": "n1-standard-4",
            "description": null,
            "machine_type_category": "general_purpose",
            "machine_type": {
              "machine_type_id": 64,
              "name": "n1-standard-4",
              "vcpus": 4,
              "memory": "15 GiB",
              "has_cuda": false,
              "gpu_model": null,
              "gpus": null,
              "gpu_memory": null
            },
            "machine_volume_conf": {
              "volume_conf_id": 1,
              "name": "volume_gcp_1",
              "description": null,
              "encrypted": true,
              "size": 375,
              "disk_machine_type": {
                "disk_machine_type_id": 4,
                "cloud_provider_id": 0,
                "name": "local-ssd",
                "has_fixed_size": true,
                "min_size": 375,
                "max_size": 375
              },
              "machine_volume_num": 1,
              "machine_volume_strip_num": 1
            }
          },
          "cloud_env": {
            "cloud_env_id": 1,
            "name": "gcp_cloud_env",
            "description": "yeedu cloud environment",
            "cloud_provider": {
              "cloud_provider_id": 0,
              "name": "gcp"
            },
            "availabilty_zone": {
              "availabilty_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            },
            "machine_network": {
              "machine_network_conf_id": 1,
              "name": "yeedu_gcp_network",
              "description": null,
              "network_project_id": "modak-yeedu",
              "network_name": "modak-yeedu-spark-vpc",
              "network_tags": [
                "yeedu",
                "iap-allow"
              ],
              "subnet": "custom-subnet-modak-yeedu",
              "machine_network_availability_zone": {
                "availability_zone_id": 75,
                "name": "us-central1-a",
                "cloud_provider_id": 0,
                "region": "us-central1",
                "description": "Council Bluffs, Iowa, North America"
              }
            },
            "cloud_project": "modak-yeedu",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type": {
                "credential_type_id": 0,
                "name": "gcp",
                "cloud_provider_id": 0
              }
            },
            "boot_disk_image": {
              "boot_disk_image_id": 1,
              "name": "gcp_boot_disk",
              "description": "dev boot disk",
              "cloud_provider_id": 0,
              "linux_distro": {
                "linux_distro_id": 0,
                "distro_name": "UBUNTU",
                "distro_version": "20.04 LTS"
              },
              "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
            }
          },
          "hive_metastore_conf": {
            "hive_metastore_conf_id": null,
            "hive_metastore_conf_name": null
          },
          "spark_infra_version": {
            "spark_infra_version_id": 0,
            "spark_version": "2.4.8",
            "hive_version": "3.2.3",
            "hadoop_version": "2.10.1",
            "scala_version": "2.11.10",
            "python_version": "3.9.5",
            "notebook_support": false
          },
          "engine_cluster_spark_config": {
            "max_parallel_spark_job_execution_per_instance": 5,
            "standalone_workers_number": null
          },
          "object_storage_manager": {
            "object_storage_manager_id": 1,
            "name": "yeedu_osm",
            "description": "test",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type_name": "gcp"
            },
            "object_storage_bucket_name": "modak-yeedu-nabu"
          }
        },
        "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
        },
        "spark_job_type": {
          "job_type": "JOB",
          "language": "Jar"
        },
        "max_concurrency": 0,
        "job_class_name": "org.apache.spark.examples.SparkPi",
        "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
        "job_arguments": "250",
        "job_rawScalaCode": null,
        "files": null,
        "properties_file": null,
        "conf": null,
        "packages": null,
        "repositories": null,
        "jars": null,
        "archives": null,
        "driver_memory": null,
        "driver_java_options": "-Dderby.system.home=/yeedu/spark_metastores/1703774163-11129",
        "driver_library_path": null,
        "driver_class_path": null,
        "executor_memory": null,
        "driver_cores": null,
        "total_executor_cores": null,
        "executor_cores": null,
        "num_executors": null,
        "principal": null,
        "keytab": null,
        "queue": null
      },
      "workflow_job_instance_details": {
        "workflow_job_instance_status": {
          "workflow_job_instance_id": 6,
          "workflow_job_id": 6,
          "status": "SENT",
          "from_date": "2024-01-09T07:06:00.301753+00:00",
          "to_date": "infinity"
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-09T07:06:00.301753+00:00",
      "from_date": "2024-01-09T07:06:00.301753+00:00",
      "to_date": "infinity"
    },
    {
      "job_id": 1,
      "job_application_id": "app-20231004073629-0002",
      "job_status": "STOPPED",
      "total_job_time": 82.614248,
      "job_conf": {
        "job_conf_id": 1,
        "name": "spark_examples",
        "cluster_info": {
          "cluster_id": 1,
          "name": "yeedu_instance",
          "description": "Test yeedu instance",
          "labels": {
            "test": "yeedu",
            "resource": "yeedu",
            "vm": "yeedu_node",
            "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
          },
          "idle_timeout_ms": 600000,
          "auto_shutdown": true,
          "cluster_status": "RUNNING",
          "cluster_type": "YEEDU",
          "compute_engine_id": 1,
          "instance_size": 1,
          "is_spot_instance": false,
          "enable_public_ip": false,
          "block_project_ssh_keys": false,
          "min_instances": 1,
          "max_instances": 3,
          "total_ycu": null,
          "bootstrap_shell_script": null,
          "spark_config_id": null,
          "cluster_conf": {
            "cluster_conf_id": 1,
            "cluster_conf_name": "n1-standard-4",
            "description": null,
            "machine_type_category": "general_purpose",
            "machine_type": {
              "machine_type_id": 64,
              "name": "n1-standard-4",
              "vcpus": 4,
              "memory": "15 GiB",
              "has_cuda": false,
              "gpu_model": null,
              "gpus": null,
              "gpu_memory": null
            },
            "machine_volume_conf": {
              "volume_conf_id": 1,
              "name": "volume_gcp",
              "description": null,
              "encrypted": true,
              "size": 375,
              "disk_machine_type": {
                "disk_machine_type_id": 4,
                "cloud_provider_id": 0,
                "name": "local-ssd",
                "has_fixed_size": true,
                "min_size": 375,
                "max_size": 375
              },
              "machine_volume_num": 1,
              "machine_volume_strip_num": 1
            }
          },
          "cloud_env": {
            "cloud_env_id": 1,
            "name": "gcp_cloud_env",
            "description": "yeedu cloud environment",
            "cloud_provider": {
              "cloud_provider_id": 0,
              "name": "gcp"
            },
            "availabilty_zone": {
              "availabilty_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            },
            "machine_network": {
              "machine_network_conf_id": 1,
              "name": "yeedu_gcp_network",
              "description": null,
              "network_project_id": "modak-yeedu",
              "network_name": "modak-yeedu-spark-vpc",
              "network_tags": [
                "yeedu",
                "iap-allow"
              ],
              "subnet": "custom-subnet-modak-yeedu",
              "machine_network_availability_zone": {
                "availability_zone_id": 75,
                "name": "us-central1-a",
                "cloud_provider_id": 0,
                "region": "us-central1",
                "description": "Council Bluffs, Iowa, North America"
              }
            },
            "cloud_project": "modak-yeedu",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type": {
                "credential_type_id": 0,
                "name": "gcp",
                "cloud_provider_id": 0
              }
            },
            "boot_disk_image": {
              "boot_disk_image_id": 1,
              "name": "gcp_boot_disk",
              "description": "dev boot disk",
              "cloud_provider_id": 0,
              "linux_distro": {
                "linux_distro_id": 0,
                "distro_name": "UBUNTU",
                "distro_version": "20.04 LTS"
              },
              "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
            }
          },
          "hive_metastore_conf": {
            "hive_metastore_conf_id": null,
            "hive_metastore_conf_name": null
          },
          "spark_infra_version": {
            "spark_infra_version_id": 0,
            "spark_version": "2.4.8",
            "hive_version": "3.2.3",
            "hadoop_version": "2.10.1",
            "scala_version": "2.11.10",
            "python_version": "3.9.5",
            "notebook_support": false
          },
          "engine_cluster_spark_config": {
            "max_parallel_spark_job_execution_per_instance": 5,
            "standalone_workers_number": null
          },
          "object_storage_manager": {
            "object_storage_manager_id": 1,
            "name": "yeedu_osm",
            "description": "test",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type_name": "gcp"
            },
            "object_storage_bucket_name": "modak-yeedu-nabu"
          }
        },
        "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
        },
        "spark_job_type": {
          "job_type": "JOB",
          "language": "Jar"
        },
        "max_concurrency": 0,
        "job_class_name": "org.apache.spark.examples.SparkPi",
        "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
        "job_arguments": "250",
        "job_rawScalaCode": null,
        "files": null,
        "properties_file": null,
        "conf": null,
        "packages": null,
        "repositories": null,
        "jars": null,
        "archives": null,
        "driver_memory": null,
        "driver_java_options": "-Dderby.system.home=/yeedu/spark_metastores/1703774163-11129",
        "driver_library_path": null,
        "driver_class_path": null,
        "executor_memory": null,
        "driver_cores": null,
        "total_executor_cores": null,
        "executor_cores": null,
        "num_executors": null,
        "principal": null,
        "keytab": null,
        "queue": null
      },
      "workflow_job_instance_details": {
        "workflow_job_instance_status": {
          "workflow_job_instance_id": 3,
          "workflow_job_id": 3,
          "status": "DONE",
          "from_date": "2023-12-28T14:43:19.941574+00:00",
          "to_date": "2023-12-28T14:44:42.555822+00:00"
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-12-28T14:43:19.941574+00:00",
      "from_date": "2023-12-28T14:43:19.941574+00:00",
      "to_date": "2023-12-28T14:44:42.555822+00:00"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 2,
    "total_pages": 1,
    "limit": 100
  }
}
```

- list example to list spark jobs of a paricular workspace having specific spark job status.

```bash
yeedu job list --workspace_id=1 --job_status=done --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "job_id": 1,
      "job_application_id": "app-20231004073629-0002",
      "job_status": "DONE",
      "total_job_time": 82.614248,
      "job_conf": {
        "job_conf_id": 1,
        "name": "spark_examples",
        "cluster_info": {
          "cluster_id": 1,
          "name": "yeedu_instance",
          "description": "Test yeedu instance",
          "labels": {
            "test": "yeedu",
            "resource": "yeedu",
            "vm": "yeedu_node",
            "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
          },
          "idle_timeout_ms": 600000,
          "auto_shutdown": true,
          "cluster_status": "RUNNING",
          "cluster_type": "YEEDU",
          "compute_engine_id": 1,
          "instance_size": 1,
          "is_spot_instance": false,
          "enable_public_ip": false,
          "block_project_ssh_keys": false,
          "min_instances": 1,
          "max_instances": 3,
          "total_ycu": null,
          "bootstrap_shell_script": null,
          "spark_config_id": null,
          "cluster_conf": {
            "cluster_conf_id": 1,
            "cluster_conf_name": "n1-standard-4",
            "description": null,
            "machine_type_category": "general_purpose",
            "machine_type": {
              "machine_type_id": 64,
              "name": "n1-standard-4",
              "vcpus": 4,
              "memory": "15 GiB",
              "has_cuda": false,
              "gpu_model": null,
              "gpus": null,
              "gpu_memory": null
            },
            "machine_volume_conf": {
              "volume_conf_id": 1,
              "name": "volume_gcp",
              "description": null,
              "encrypted": true,
              "size": 375,
              "disk_machine_type": {
                "disk_machine_type_id": 4,
                "cloud_provider_id": 0,
                "name": "local-ssd",
                "has_fixed_size": true,
                "min_size": 375,
                "max_size": 375
              },
              "machine_volume_num": 1,
              "machine_volume_strip_num": 1
            }
          },
          "cloud_env": {
            "cloud_env_id": 1,
            "name": "gcp_cloud_env",
            "description": "yeedu cloud environment",
            "cloud_provider": {
              "cloud_provider_id": 0,
              "name": "gcp"
            },
            "availabilty_zone": {
              "availabilty_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            },
            "machine_network": {
              "machine_network_conf_id": 1,
              "name": "yeedu_gcp_network",
              "description": null,
              "network_project_id": "modak-yeedu",
              "network_name": "modak-yeedu-spark-vpc",
              "network_tags": [
                "yeedu",
                "iap-allow"
              ],
              "subnet": "custom-subnet-modak-yeedu",
              "machine_network_availability_zone": {
                "availability_zone_id": 75,
                "name": "us-central1-a",
                "cloud_provider_id": 0,
                "region": "us-central1",
                "description": "Council Bluffs, Iowa, North America"
              }
            },
            "cloud_project": "modak-yeedu",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type": {
                "credential_type_id": 0,
                "name": "gcp",
                "cloud_provider_id": 0
              }
            },
            "boot_disk_image": {
              "boot_disk_image_id": 1,
              "name": "gcp_boot_disk",
              "description": "dev boot disk",
              "cloud_provider_id": 0,
              "linux_distro": {
                "linux_distro_id": 0,
                "distro_name": "UBUNTU",
                "distro_version": "20.04 LTS"
              },
              "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
            }
          },
          "hive_metastore_conf": {
            "hive_metastore_conf_id": null,
            "hive_metastore_conf_name": null
          },
          "spark_infra_version": {
            "spark_infra_version_id": 0,
            "spark_version": "2.4.8",
            "hive_version": "3.2.3",
            "hadoop_version": "2.10.1",
            "scala_version": "2.11.10",
            "python_version": "3.9.5",
            "notebook_support": false
          },
          "engine_cluster_spark_config": {
            "max_parallel_spark_job_execution_per_instance": 5,
            "standalone_workers_number": null
          },
          "object_storage_manager": {
            "object_storage_manager_id": 1,
            "name": "yeedu_osm",
            "description": "test",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type_name": "gcp"
            },
            "object_storage_bucket_name": "modak-yeedu-nabu"
          }
        },
        "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
        },
        "spark_job_type": {
          "job_type": "JOB",
          "language": "Jar"
        },
        "max_concurrency": 0,
        "job_class_name": "org.apache.spark.examples.SparkPi",
        "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
        "job_arguments": "250",
        "job_rawScalaCode": null,
        "files": null,
        "properties_file": null,
        "conf": null,
        "packages": null,
        "repositories": null,
        "jars": null,
        "archives": null,
        "driver_memory": null,
        "driver_java_options": "-Dderby.system.home=/yeedu/spark_metastores/1703774163-11129",
        "driver_library_path": null,
        "driver_class_path": null,
        "executor_memory": null,
        "driver_cores": null,
        "total_executor_cores": null,
        "executor_cores": null,
        "num_executors": null,
        "principal": null,
        "keytab": null,
        "queue": null
      },
      "workflow_job_instance_details": {
        "workflow_job_instance_status": {
          "workflow_job_instance_id": 3,
          "workflow_job_id": 3,
          "status": "DONE",
          "from_date": "2023-12-28T14:43:19.941574+00:00",
          "to_date": "2023-12-28T14:44:42.555822+00:00"
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-12-28T14:43:19.941574+00:00",
      "from_date": "2023-12-28T14:43:19.941574+00:00",
      "to_date": "2023-12-28T14:44:42.555822+00:00"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 20,
    "total_pages": 20,
    "limit": 1,
    "next_page": 2
  }
}
```

### search

```bash
yeedu job search -h
```

```bash
usage:  search [-h] --workspace_id WORKSPACE_ID --job_id JOB_ID
               [--page_number PAGE_NUMBER] [--limit LIMIT]
               [--json-output [{pretty,default}]]
               [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to search Spark Job Instances in it.
  --job_id JOB_ID       Provide job id to search Spark Job Instances.
  --page_number PAGE_NUMBER
                        To search Spark Job Instances for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of Spark Job Instances. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search example to with required and optional arguments passed.

```bash
yeedu job search --workspace_id=1 --job_id=1 --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "job_id": 1,
      "job_application_id": "app-20231004073629-0002",
      "job_status": "DONE",
      "total_job_time": 82.614248,
      "job_conf": {
        "job_conf_id": 1,
        "name": "spark_examples",
        "cluster_info": {
          "cluster_id": 1,
          "name": "yeedu_instance",
          "description": "Test yeedu instance",
          "labels": {
            "test": "yeedu",
            "resource": "yeedu",
            "vm": "yeedu_node",
            "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
          },
          "idle_timeout_ms": 600000,
          "auto_shutdown": true,
          "cluster_status": "RUNNING",
          "cluster_type": "YEEDU",
          "compute_engine_id": 1,
          "instance_size": 1,
          "is_spot_instance": false,
          "enable_public_ip": false,
          "block_project_ssh_keys": false,
          "min_instances": 1,
          "max_instances": 3,
          "total_ycu": null,
          "bootstrap_shell_script": null,
          "spark_config_id": null,
          "cluster_conf": {
            "cluster_conf_id": 1,
            "cluster_conf_name": "n1-standard-4",
            "description": null,
            "machine_type_category": "general_purpose",
            "machine_type": {
              "machine_type_id": 64,
              "name": "n1-standard-4",
              "vcpus": 4,
              "memory": "15 GiB",
              "has_cuda": false,
              "gpu_model": null,
              "gpus": null,
              "gpu_memory": null
            },
            "machine_volume_conf": {
              "volume_conf_id": 1,
              "name": "volume_gcp",
              "description": null,
              "encrypted": true,
              "size": 375,
              "disk_machine_type": {
                "disk_machine_type_id": 4,
                "cloud_provider_id": 0,
                "name": "local-ssd",
                "has_fixed_size": true,
                "min_size": 375,
                "max_size": 375
              },
              "machine_volume_num": 1,
              "machine_volume_strip_num": 1
            }
          },
          "cloud_env": {
            "cloud_env_id": 1,
            "name": "gcp_cloud_env",
            "description": "yeedu cloud environment",
            "cloud_provider": {
              "cloud_provider_id": 0,
              "name": "gcp"
            },
            "availabilty_zone": {
              "availabilty_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            },
            "machine_network": {
              "machine_network_conf_id": 1,
              "name": "yeedu_gcp_network",
              "description": null,
              "network_project_id": "modak-yeedu",
              "network_name": "modak-yeedu-spark-vpc",
              "network_tags": [
                "yeedu",
                "iap-allow"
              ],
              "subnet": "custom-subnet-modak-yeedu",
              "machine_network_availability_zone": {
                "availability_zone_id": 75,
                "name": "us-central1-a",
                "cloud_provider_id": 0,
                "region": "us-central1",
                "description": "Council Bluffs, Iowa, North America"
              }
            },
            "cloud_project": "modak-yeedu",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type": {
                "credential_type_id": 0,
                "name": "gcp",
                "cloud_provider_id": 0
              }
            },
            "boot_disk_image": {
              "boot_disk_image_id": 1,
              "name": "gcp_boot_disk",
              "description": "dev boot disk",
              "cloud_provider_id": 0,
              "linux_distro": {
                "linux_distro_id": 0,
                "distro_name": "UBUNTU",
                "distro_version": "20.04 LTS"
              },
              "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
            }
          },
          "hive_metastore_conf": {
            "hive_metastore_conf_id": null,
            "hive_metastore_conf_name": null
          },
          "spark_infra_version": {
            "spark_infra_version_id": 0,
            "spark_version": "2.4.8",
            "hive_version": "3.2.3",
            "hadoop_version": "2.10.1",
            "scala_version": "2.11.10",
            "python_version": "3.9.5",
            "notebook_support": false
          },
          "engine_cluster_spark_config": {
            "max_parallel_spark_job_execution_per_instance": 5,
            "standalone_workers_number": null
          },
          "object_storage_manager": {
            "object_storage_manager_id": 1,
            "name": "yeedu_osm",
            "description": "test",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type_name": "gcp"
            },
            "object_storage_bucket_name": "modak-yeedu-nabu"
          }
        },
        "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
        },
        "spark_job_type": {
          "job_type": "JOB",
          "language": "Jar"
        },
        "max_concurrency": 0,
        "job_class_name": "org.apache.spark.examples.SparkPi",
        "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
        "job_arguments": "250",
        "job_rawScalaCode": null,
        "files": null,
        "properties_file": null,
        "conf": null,
        "packages": null,
        "repositories": null,
        "jars": null,
        "archives": null,
        "driver_memory": null,
        "driver_java_options": "-Dderby.system.home=/yeedu/spark_metastores/1703774163-11129",
        "driver_library_path": null,
        "driver_class_path": null,
        "executor_memory": null,
        "driver_cores": null,
        "total_executor_cores": null,
        "executor_cores": null,
        "num_executors": null,
        "principal": null,
        "keytab": null,
        "queue": null
      },
      "workflow_job_instance_details": {
        "workflow_job_instance_status": {
          "workflow_job_instance_id": 3,
          "workflow_job_id": 3,
          "status": "DONE",
          "from_date": "2023-12-28T14:43:19.941574+00:00",
          "to_date": "2023-12-28T14:44:42.555822+00:00"
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-12-28T14:43:19.941574+00:00",
      "from_date": "2023-12-28T14:43:19.941574+00:00",
      "to_date": "2023-12-28T14:44:42.555822+00:00"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 1
  }
}
```

### get

```bash
yeedu job get -h
```

```bash
usage:  get [-h] --job_id JOB_ID --workspace_id WORKSPACE_ID
            [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --job_id JOB_ID       Provide job_id to get information about a specific Spark Job
                        Instance.
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to get information about a specific Spark
                        Job Instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get example with all the required arguments passed.

```bash
yeedu job get --workspace_id=1 --job_id=90
```

- Console output

```bash
{
  "job_id": 1,
  "job_application_id": "app-20231004073629-0002",
  "job_status": "DONE",
  "total_job_time": 82.614248,
  "job_conf": {
    "job_conf_id": 1,
    "name": "spark_examples",
    "cluster_info": {
      "cluster_id": 1,
      "name": "yeedu_instance",
      "description": "Test yeedu instance",
      "labels": {
        "test": "yeedu",
        "resource": "yeedu",
        "vm": "yeedu_node",
        "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
      },
      "idle_timeout_ms": 600000,
      "auto_shutdown": true,
      "cluster_status": "RUNNING",
      "cluster_type": "YEEDU",
      "compute_engine_id": 1,
      "instance_size": 1,
      "is_spot_instance": false,
      "enable_public_ip": false,
      "block_project_ssh_keys": false,
      "min_instances": 1,
      "max_instances": 3,
      "total_ycu": null,
      "bootstrap_shell_script": null,
      "spark_config_id": null,
      "cluster_conf": {
        "cluster_conf_id": 1,
        "cluster_conf_name": "n1-standard-4",
        "description": null,
        "machine_type_category": "general_purpose",
        "machine_type": {
          "machine_type_id": 64,
          "name": "n1-standard-4",
          "vcpus": 4,
          "memory": "15 GiB",
          "has_cuda": false,
          "gpu_model": null,
          "gpus": null,
          "gpu_memory": null
        },
        "machine_volume_conf": {
          "volume_conf_id": 1,
          "name": "volume_gcp",
          "description": null,
          "encrypted": true,
          "size": 375,
          "disk_machine_type": {
            "disk_machine_type_id": 4,
            "cloud_provider_id": 0,
            "name": "local-ssd",
            "has_fixed_size": true,
            "min_size": 375,
            "max_size": 375
          },
          "machine_volume_num": 1,
          "machine_volume_strip_num": 1
        }
      },
      "cloud_env": {
        "cloud_env_id": 1,
        "name": "gcp_cloud_env",
        "description": "yeedu cloud environment",
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        },
        "availabilty_zone": {
          "availabilty_zone_id": 75,
          "name": "us-central1-a",
          "cloud_provider_id": 0,
          "region": "us-central1",
          "description": "Council Bluffs, Iowa, North America"
        },
        "machine_network": {
          "machine_network_conf_id": 1,
          "name": "yeedu_gcp_network",
          "description": null,
          "network_project_id": "modak-yeedu",
          "network_name": "modak-yeedu-spark-vpc",
          "network_tags": [
            "yeedu",
            "iap-allow"
          ],
          "subnet": "custom-subnet-modak-yeedu",
          "machine_network_availability_zone": {
            "availability_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          }
        },
        "cloud_project": "modak-yeedu",
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modakyeedu-svc",
          "description": null,
          "credential_type": {
            "credential_type_id": 0,
            "name": "gcp",
            "cloud_provider_id": 0
          }
        },
        "boot_disk_image": {
          "boot_disk_image_id": 1,
          "name": "gcp_boot_disk",
          "description": "dev boot disk",
          "cloud_provider_id": 0,
          "linux_distro": {
            "linux_distro_id": 0,
            "distro_name": "UBUNTU",
            "distro_version": "20.04 LTS"
          },
          "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
        }
      },
      "hive_metastore_conf": {
        "hive_metastore_conf_id": null,
        "hive_metastore_conf_name": null
      },
      "spark_infra_version": {
        "spark_infra_version_id": 0,
        "spark_version": "2.4.8",
        "hive_version": "3.2.3",
        "hadoop_version": "2.10.1",
        "scala_version": "2.11.10",
        "python_version": "3.9.5",
        "notebook_support": false
      },
      "engine_cluster_spark_config": {
        "max_parallel_spark_job_execution_per_instance": 5,
        "standalone_workers_number": null
      },
      "object_storage_manager": {
        "object_storage_manager_id": 1,
        "name": "yeedu_osm",
        "description": "test",
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modakyeedu-svc",
          "description": null,
          "credential_type_name": "gcp"
        },
        "object_storage_bucket_name": "modak-yeedu-nabu"
      }
    },
    "workspace": {
      "workspace_id": 1,
      "name": "spark_jobs_test",
      "description": "Test Spark Jobs"
    },
    "spark_job_type": {
      "job_type": "JOB",
      "language": "Jar"
    },
    "max_concurrency": 0,
    "job_class_name": "org.apache.spark.examples.SparkPi",
    "job_command": "file:///yeedu/object-storage-manager/spark-examples_2.11-2.4.8.jar",
    "job_arguments": "250",
    "job_rawScalaCode": null,
    "files": null,
    "properties_file": null,
    "conf": null,
    "packages": null,
    "repositories": null,
    "jars": null,
    "archives": null,
    "driver_memory": null,
    "driver_java_options": "-Dderby.system.home=/yeedu/spark_metastores/1703774163-11129",
    "driver_library_path": null,
    "driver_class_path": null,
    "executor_memory": null,
    "driver_cores": null,
    "total_executor_cores": null,
    "executor_cores": null,
    "num_executors": null,
    "principal": null,
    "keytab": null,
    "queue": null
  },
  "workflow_job_instance_details": {
    "workflow_job_instance_status": {
      "workflow_job_instance_id": 3,
      "workflow_job_id": 3,
      "status": "DONE",
      "from_date": "2023-12-28T14:43:19.941574+00:00",
      "to_date": "2023-12-28T14:44:42.555822+00:00"
    }
  },
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2023-12-28T14:43:19.941574+00:00",
  "from_date": "2023-12-28T14:43:19.941574+00:00",
  "to_date": "2023-12-28T14:44:42.555822+00:00"
}
```

### stop

```bash
yeedu job stop -h
```

```bash
usage:  stop [-h] --job_id JOB_ID --workspace_id WORKSPACE_ID
             [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --job_id JOB_ID       Provide job_id to stop a specific Spark Job Instance.
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to stop a specific Spark Job Instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- stop example with all the required argument passed.

```bash
yeedu job stop --workspace_id=1 --job_id=8
```

- Console output

```bash
{
  "SparkKill": {
    "workflow_job_id": 8,
    "workflow_job_instance_id": 8,
    "spark_job_instance_id": 8,
    "spark_job_id": 1,
    "compute_engine_id": 1
  }
}
```

### get-status

```bash
yeedu job get-status -h
```

```bash
usage:  get-status [-h] --job_id JOB_ID --workspace_id WORKSPACE_ID
                   [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --job_id JOB_ID       Provide job_id to get all the status information about a
                        specific Spark Job Instance.
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to get all the status information about a
                        specific Spark Job Instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-status example with all the required argument passed.

```bash
yeedu job get-status --workspace_id=1 --job_id=8
```

- Console output

```bash
[
  {
    "job_status": "SUBMITTED",
    "created_by": "YSU0000",
    "start_time": "2023-12-28T14:43:19.941574+00:00",
    "end_time": "2023-12-28T14:44:42.555822+00:00"
  },
  {
    "job_status": "RUNNING",
    "created_by": null,
    "start_time": "2023-12-28T14:44:42.555822+00:00",
    "end_time": "2023-12-28T14:44:42.555822+00:00"
  },
  {
    "job_status": "DONE",
    "created_by": null,
    "start_time": "2023-12-28T14:44:42.555822+00:00",
    "end_time": "infinity"
  }
]
```

### logs

```bash
yeedu job logs -h
```

```bash
usage:  logs [-h] --workspace_id WORKSPACE_ID --job_id JOB_ID
             [--log_type {stdout,stderr}] [--json-output [{pretty,default}]]
             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to download Spark Job Instance log records.
  --job_id JOB_ID       Provide job_id to download Spark Job Instance log records.
  --log_type {stdout,stderr}
                        Provide log_type to download Spark Job Instance log records.
                        (default: stdout)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- logs example with all the required arguments passed.

```bash
yeedu job logs --workspace_id=1 --job_id=1
```

- Console output

```bash
Pi is roughly 3.141355706778534
```

## Workflow Details By Spark Job Application ID

| Command Name                                           | Utility                                                    |
|--------------------------------------------------------|------------------------------------------------------------|
|[get-workflow-job-instance](#get-workflow-job-instance) | To get information about a specific Workflow Job Instance. |

### get-workflow-job-instance

```bash
yeedu job get-workflow-job-instance -h
```

```bash
usage:  get-workflow-job-instance [-h] --job_application_id JOB_APPLICATION_ID
                                  --workspace_id WORKSPACE_ID
                                  [--json-output [{pretty,default}]]
                                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --job_application_id JOB_APPLICATION_ID
                        Provide a job_application_id to get information about a specific
                        Workflow Job Instance.
  --workspace_id WORKSPACE_ID
                        Provide a workspace_id to get information about a specific
                        Workflow Job Instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-workflow-job-instance example with all the required arguments passed.

```bash
yeedu job get-workflow-job-instance --workspace_id=1 --job_application_id="local-1696317971700"
```

- Console output

```bash
{
  "job_id": 5,
  "job_application_id": "local-1696317971700",
  "job_status": "DONE",
  "compute_engine": 1,
  "cluster_id": "1",
  "workflow_job_instance_details": {
    "workflow_job_instance_status": {
      "workflow_job_instance_id": 7,
      "workflow_job_id": 7,
      "status": "DONE",
      "previous_status": [
        "NONE",
        "INIT",
        "SENT",
        "RECEIVED",
        "EXECUTING"
      ],
      "from_date": "2023-10-03T07:26:29.926692+00:00",
      "to_date": "infinity"
    },
    "workflow_execution_process": {
      "machine_pid_number": "116",
      "machine_hostname": "yeedu1-e0a10412-288a-449d-78d3-ea1726afb205",
      "machine_id": "e0a10412-288a-449d-78d3-ea1726afb205",
      "machine_pid_user": "root",
      "machine_node_number": "0"
    }
  },
  "tenant_id": "cf1f945f-01ce-4ac6-a070-8c733f2fa791",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2023-10-03T07:20:58.933317+00:00",
  "from_date": "2023-10-03T07:20:58.933317+00:00",
  "to_date": "2023-10-03T07:26:29.926692+00:00"
}
```

# Notebook

## Notebook Configuration

| Command Name                   | Utility                                                            |
|--------------------------------|--------------------------------------------------------------------|
|[create-conf](#create-conf-2)   | To create a Notebook Configuration.                                |
|[list-confs](#list-confs-2)     | To list all the available Notebook Configurations.                 |
|[search-confs](#search-confs-2) | To search Notebook Configurations by notebook name in a workspace. |
|[get-conf](#get-conf-2)         | To get the information about a specific Notebook Configuration.    |
|[edit-conf](#edit-conf-2)       | To edit the Notebook Configuration.                                |
|[enable-conf](#enable-conf-1)   | To enable a specific Notebook Configuration.                       |
|[disable-conf](#disable-conf-1) | To disable a specific Notebook Configuration.                      |

### create-conf

```bash
yeedu notebook create-conf -h
```

```bash
usage:  create-conf [-h] --workspace_id WORKSPACE_ID
                    [--cluster_id CLUSTER_ID]
                    [--cluster_name CLUSTER_NAME] --notebook_name
                    NOTEBOOK_NAME --notebook_type python3,scala
                    [--conf CONF [CONF ...]] [--files [FILES]]
                    [--jars [JARS]] [--packages [PACKAGES]]
                    [--driver-memory [DRIVER_MEMORY]]
                    [--executor-memory [EXECUTOR_MEMORY]]
                    [--driver-cores [DRIVER_CORES]]
                    [--total-executor-cores [TOTAL_EXECUTOR_CORES]]
                    [--executor-cores [EXECUTOR_CORES]]
                    [--num-executors [NUM_EXECUTORS]]
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to create a Notebook Configuration.
  --cluster_id CLUSTER_ID
                        Provide cluster_id to create a Notebook Configuration.
  --cluster_name CLUSTER_NAME
                        Provide cluster_name to create a Notebook Configuration.
  --notebook_name NOTEBOOK_NAME
                        Provide notebook_name to create a Notebook Configuration.
  --notebook_type python3,scala
                        Provide notebook type to create a Notebook Configuration.
  --conf CONF [CONF ...]
                        Provide conf to create a Notebook Configuration.
  --files [FILES]       Provide files to create a Notebook Configuration.
  --jars [JARS]         Provide jars to create a Notebook Configuration.
  --packages [PACKAGES]
                        Provide packages to create a Notebook Configuration.
  --driver-memory [DRIVER_MEMORY]
                        Provide driver-memory to create a Notebook Configuration.
  --executor-memory [EXECUTOR_MEMORY]
                        Provide executor-memory to create a Notebook Configuration.
  --driver-cores [DRIVER_CORES]
                        Provide driver-cores to create a Notebook Configuration.
  --total-executor-cores [TOTAL_EXECUTOR_CORES]
                        Provide total-executor-cores to create a Notebook Configuration.
  --executor-cores [EXECUTOR_CORES]
                        Provide executor-cores to create a Notebook Configuration.
  --num-executors [NUM_EXECUTORS]
                        Provide num-executors to create a Notebook Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-conf example with all the required and optional arguments passed.

```bash
yeedu notebook create-conf --cluster_id=1 --workspace_id=1 --notebook_name="test_notebook" --notebook_type="python3"
```

- Console output

```bash
{
  "notebook_conf_id": "21",
  "notebook_name": "test_notebook_01",
  "cluster_id": "1",
  "workspace_id": "1",
  "spark_job_type_lang_id": 3,
  "max_concurrency": "1",
  "notebook_cells": {
    "cells": [
      {
        "cell_uuid": "3516b29f-13a3-427d-a466-fc0c85d7ad0e",
        "order": 0,
        "code": "",
        "output": [],
        "runStatus": false,
        "executionCount": 0,
        "isOutputError": false
      }
    ]
  },
  "notebook_cells_auto_save": null,
  "conf": null,
  "packages": null,
  "jars": null,
  "files": null,
  "driver_memory": null,
  "executor_memory": null,
  "driver_cores": null,
  "total_executor_cores": null,
  "executor_cores": null,
  "num_executors": null,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-09T10:06:52.216Z",
  "from_date": "2024-01-09T10:06:52.216Z",
  "to_date": null
}
```

### list-confs

```bash
yeedu notebook list-confs -h
```

```bash
usage:  list-confs [-h] --workspace_id WORKSPACE_ID
                   [--enable [{true,false}]]
                   [--page_number PAGE_NUMBER] [--limit LIMIT]
                   [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        To list Notebook Configurations of a specific workspace.
  --enable [{true,false}]
                        Provide enable as true or false to list Notebook Configurations of a specific workspace.
  --page_number PAGE_NUMBER
                        To list Notebook Configurations for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of Notebook Configurations. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-confs example with required and optional arguments passed.

```bash
yeedu notebook list-confs --workspace_id=1 --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "notebook_conf_id": 21,
      "notebook_name": "test_notebook_01",
      "cluster_info": {
        "cluster_id": 1,
        "name": "yeedu_instance",
        "description": "Test yeedu instance",
        "labels": {
          "test": "yeedu",
          "resource": "yeedu",
          "vm": "yeedu_node",
          "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
        },
        "idle_timeout_ms": 600000,
        "auto_shutdown": true,
        "cluster_status": "RUNNING",
        "cluster_type": "YEEDU",
        "compute_engine_id": 1,
        "instance_size": 1,
        "is_spot_instance": false,
        "enable_public_ip": false,
        "block_project_ssh_keys": false,
        "min_instances": 1,
        "max_instances": 3,
        "total_ycu": null,
        "bootstrap_shell_script": null,
        "spark_config_id": null,
        "cluster_conf": {
          "cluster_conf_id": 1,
          "cluster_conf_name": "n1-standard-4",
          "description": null,
          "machine_type_category": "general_purpose",
          "machine_type": {
            "machine_type_id": 64,
            "name": "n1-standard-4",
            "vcpus": 4,
            "memory": "15 GiB",
            "has_cuda": false,
            "gpu_model": null,
            "gpus": null,
            "gpu_memory": null
          },
          "machine_volume_conf": {
            "volume_conf_id": 1,
            "name": "volume_gcp",
            "description": null,
            "encrypted": true,
            "size": 375,
            "disk_machine_type": {
              "disk_machine_type_id": 4,
              "cloud_provider_id": 0,
              "name": "local-ssd",
              "has_fixed_size": true,
              "min_size": 375,
              "max_size": 375
            },
            "machine_volume_num": 1,
            "machine_volume_strip_num": 1
          }
        },
        "cloud_env": {
          "cloud_env_id": 1,
          "name": "gcp_cloud_env",
          "description": "yeedu cloud environment",
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          },
          "availabilty_zone": {
            "availabilty_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          },
          "machine_network": {
            "machine_network_conf_id": 1,
            "name": "yeedu_gcp_network",
            "description": null,
            "network_project_id": "modak-yeedu",
            "network_name": "modak-yeedu-spark-vpc",
            "network_tags": [
              "yeedu",
              "iap-allow"
            ],
            "subnet": "custom-subnet-modak-yeedu",
            "machine_network_availability_zone": {
              "availability_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            }
          },
          "cloud_project": "modak-yeedu",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeed-svc",
            "description": null,
            "credential_type": {
              "credential_type_id": 0,
              "name": "gcp",
              "cloud_provider_id": 0
            }
          },
          "boot_disk_image": {
            "boot_disk_image_id": 1,
            "name": "gcp_boot_disk",
            "description": "dev boot disk",
            "cloud_provider_id": 0,
            "linux_distro": {
              "linux_distro_id": 0,
              "distro_name": "UBUNTU",
              "distro_version": "20.04 LTS"
            },
            "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
          }
        },
        "hive_metastore_conf": {
          "hive_metastore_conf_id": null,
          "hive_metastore_conf_name": null
        },
        "spark_infra_version": {
          "spark_infra_version_id": 1,
          "spark_version": "3.2.2",
          "hive_version": "3.2.3",
          "hadoop_version": "3.2.4",
          "scala_version": "2.12.15",
          "python_version": "3.9.5",
          "notebook_support": true
        },
        "engine_cluster_spark_config": {
          "max_parallel_spark_job_execution_per_instance": 5,
          "standalone_workers_number": null
        },
        "object_storage_manager": {
          "object_storage_manager_id": 1,
          "name": "yeedu_osm",
          "description": "test",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type_name": "gcp"
          },
          "object_storage_bucket_name": "modak-yeedu-nabu"
        }
      },
      "workspace": {
        "workspace_id": 1,
        "name": "spark_jobs_test",
        "description": "Test Spark Jobs"
      },
      "spark_job_type": {
        "job_type": "NOTEBOOK",
        "language": "Python3"
      },
      "max_concurrency": 1,
      "notebook_cells": {
        "cells": [
          {
            "cell_uuid": "3516b29f-13a3-427d-a466-fc0c85d7ad0e",
            "order": 0,
            "code": "",
            "output": [],
            "runStatus": false,
            "executionCount": 0,
            "isOutputError": false
          }
        ]
      },
      "last_notebook_run": {
        "notebook_id": null,
        "notebook_status": null
      },
      "conf": null,
      "packages": null,
      "jars": null,
      "files": null,
      "driver_memory": null,
      "executor_memory": null,
      "driver_cores": null,
      "total_executor_cores": null,
      "executor_cores": null,
      "num_executors": null,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "active": true,
      "last_update_date": "2024-01-09T10:06:52.21698+00:00",
      "from_date": "2024-01-09T10:06:52.21698+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 2,
    "total_pages": 2,
    "limit": 1,
    "next_page": 2
  }
}
```

### search-confs

```bash
yeedu notebook search-confs -h
```

```bash
usage:  search-confs [-h] --workspace_id WORKSPACE_ID --notebook_name NOTEBOOK_NAME
                     [--enable [{true,false}]] [--page_number PAGE_NUMBER]
                     [--limit LIMIT] [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace_id to search Notebook Configurations in it.
  --notebook_name NOTEBOOK_NAME
                        Provide notebook_name to search Notebook Configurations.
  --enable [{true,false}]
                        Provide enable as true or false to search Notebook
                        Configurations.
  --page_number PAGE_NUMBER
                        To search Notebook Configurations for a specific page_number.
                        (default: 1)
  --limit LIMIT         Provide limit to search number of Notebook Configurations.
                        (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-confs example with required and optional arguments passed.

```bash
yeedu notebook search-confs --workspace_id=1 --notebook_name="test_" --enable=true --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "notebook_conf_id": 21,
      "notebook_name": "test_notebook_01",
      "cluster_info": {
        "cluster_id": 1,
        "name": "yeedu_instance",
        "description": "Test yeedu instance",
        "labels": {
          "test": "yeedu",
          "resource": "yeedu",
          "vm": "yeedu_node",
          "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
        },
        "idle_timeout_ms": 600000,
        "auto_shutdown": true,
        "cluster_status": "RUNNING",
        "cluster_type": "YEEDU",
        "compute_engine_id": 1,
        "instance_size": 1,
        "is_spot_instance": false,
        "enable_public_ip": false,
        "block_project_ssh_keys": false,
        "min_instances": 1,
        "max_instances": 3,
        "total_ycu": null,
        "bootstrap_shell_script": null,
        "spark_config_id": null,
        "cluster_conf": {
          "cluster_conf_id": 1,
          "cluster_conf_name": "n1-standard-4",
          "description": null,
          "machine_type_category": "general_purpose",
          "machine_type": {
            "machine_type_id": 64,
            "name": "n1-standard-4",
            "vcpus": 4,
            "memory": "15 GiB",
            "has_cuda": false,
            "gpu_model": null,
            "gpus": null,
            "gpu_memory": null
          },
          "machine_volume_conf": {
            "volume_conf_id": 1,
            "name": "volume_gcp",
            "description": null,
            "encrypted": true,
            "size": 375,
            "disk_machine_type": {
              "disk_machine_type_id": 4,
              "cloud_provider_id": 0,
              "name": "local-ssd",
              "has_fixed_size": true,
              "min_size": 375,
              "max_size": 375
            },
            "machine_volume_num": 1,
            "machine_volume_strip_num": 1
          }
        },
        "cloud_env": {
          "cloud_env_id": 1,
          "name": "gcp_cloud_env",
          "description": "yeedu cloud environment",
          "cloud_provider": {
            "cloud_provider_id": 0,
            "name": "gcp"
          },
          "availabilty_zone": {
            "availabilty_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          },
          "machine_network": {
            "machine_network_conf_id": 1,
            "name": "yeedu_gcp_network",
            "description": null,
            "network_project_id": "modak-yeedu",
            "network_name": "modak-yeedu-spark-vpc",
            "network_tags": [
              "yeedu",
              "iap-allow"
            ],
            "subnet": "custom-subnet-modak-yeedu",
            "machine_network_availability_zone": {
              "availability_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            }
          },
          "cloud_project": "modak-yeedu",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeed-svc",
            "description": null,
            "credential_type": {
              "credential_type_id": 0,
              "name": "gcp",
              "cloud_provider_id": 0
            }
          },
          "boot_disk_image": {
            "boot_disk_image_id": 1,
            "name": "gcp_boot_disk",
            "description": "dev boot disk",
            "cloud_provider_id": 0,
            "linux_distro": {
              "linux_distro_id": 0,
              "distro_name": "UBUNTU",
              "distro_version": "20.04 LTS"
            },
            "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
          }
        },
        "hive_metastore_conf": {
          "hive_metastore_conf_id": null,
          "hive_metastore_conf_name": null
        },
        "spark_infra_version": {
          "spark_infra_version_id": 1,
          "spark_version": "3.2.2",
          "hive_version": "3.2.3",
          "hadoop_version": "3.2.4",
          "scala_version": "2.12.15",
          "python_version": "3.9.5",
          "notebook_support": true
        },
        "engine_cluster_spark_config": {
          "max_parallel_spark_job_execution_per_instance": 5,
          "standalone_workers_number": null
        },
        "object_storage_manager": {
          "object_storage_manager_id": 1,
          "name": "yeedu_osm",
          "description": "test",
          "credentials_config": {
            "credential_config_id": 1,
            "name": "modakyeedu-svc",
            "description": null,
            "credential_type_name": "gcp"
          },
          "object_storage_bucket_name": "modak-yeedu-nabu"
        }
      },
      "workspace": {
        "workspace_id": 1,
        "name": "spark_jobs_test",
        "description": "Test Spark Jobs"
      },
      "spark_job_type": {
        "job_type": "NOTEBOOK",
        "language": "Python3"
      },
      "max_concurrency": 1,
      "notebook_cells": {
        "cells": [
          {
            "cell_uuid": "3516b29f-13a3-427d-a466-fc0c85d7ad0e",
            "order": 0,
            "code": "",
            "output": [],
            "runStatus": false,
            "executionCount": 0,
            "isOutputError": false
          }
        ]
      },
      "last_notebook_run": {
        "notebook_id": null,
        "notebook_status": null
      },
      "conf": null,
      "packages": null,
      "jars": null,
      "files": null,
      "driver_memory": null,
      "executor_memory": null,
      "driver_cores": null,
      "total_executor_cores": null,
      "executor_cores": null,
      "num_executors": null,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "active": true,
      "last_update_date": "2024-01-09T10:06:52.21698+00:00",
      "from_date": "2024-01-09T10:06:52.21698+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 2,
    "total_pages": 2,
    "limit": 1,
    "next_page": 2
  }
}
```

### get-conf

```bash
yeedu notebook get-conf -h
```

```bash
usage:  get-conf [-h] --workspace_id WORKSPACE_ID
                 [--notebook_conf_id NOTEBOOK_CONF_ID]
                 [--notebook_name NOTEBOOK_NAME]
                 [--json-output [{pretty,default}]]
                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to get information about a specific Notebook Configuration.
  --notebook_conf_id NOTEBOOK_CONF_ID
                        Provide Notebook Conf Id to get information about a specific Notebook Configuration.
  --notebook_name NOTEBOOK_NAME
                        Provide Notebook Name to get information about a specific Notebook Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-conf example with optional and required argument passed.

```bash
yeedu notebook get-conf --workspace_id=1 --notebook_conf_id=1
```

- Console output

```bash
{
  "notebook_conf_id": 1,
  "notebook_name": "test_notebook_01",
  "cluster_info": {
    "cluster_id": 1,
    "name": "yeedu_instance",
    "description": "Test yeedu instance",
    "labels": {
      "test": "yeedu",
      "resource": "yeedu",
      "vm": "yeedu_node",
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
    },
    "idle_timeout_ms": 600000,
    "auto_shutdown": true,
    "cluster_status": "RUNNING",
    "cluster_type": "YEEDU",
    "compute_engine_id": 1,
    "instance_size": 1,
    "is_spot_instance": false,
    "enable_public_ip": false,
    "block_project_ssh_keys": false,
    "min_instances": 1,
    "max_instances": 3,
    "total_ycu": null,
    "bootstrap_shell_script": null,
    "spark_config_id": null,
    "cluster_conf": {
      "cluster_conf_id": 1,
      "cluster_conf_name": "n1-standard-4",
      "description": null,
      "machine_type_category": "general_purpose",
      "machine_type": {
        "machine_type_id": 64,
        "name": "n1-standard-4",
        "vcpus": 4,
        "memory": "15 GiB",
        "has_cuda": false,
        "gpu_model": null,
        "gpus": null,
        "gpu_memory": null
      },
      "machine_volume_conf": {
        "volume_conf_id": 1,
        "name": "volume_gcp",
        "description": null,
        "encrypted": true,
        "size": 375,
        "disk_machine_type": {
          "disk_machine_type_id": 4,
          "cloud_provider_id": 0,
          "name": "local-ssd",
          "has_fixed_size": true,
          "min_size": 375,
          "max_size": 375
        },
        "machine_volume_num": 1,
        "machine_volume_strip_num": 1
      }
    },
    "cloud_env": {
      "cloud_env_id": 1,
      "name": "gcp_cloud_env",
      "description": "yeedu cloud environment",
      "cloud_provider": {
        "cloud_provider_id": 0,
        "name": "gcp"
      },
      "availabilty_zone": {
        "availabilty_zone_id": 75,
        "name": "us-central1-a",
        "cloud_provider_id": 0,
        "region": "us-central1",
        "description": "Council Bluffs, Iowa, North America"
      },
      "machine_network": {
        "machine_network_conf_id": 1,
        "name": "yeedu_gcp_network",
        "description": null,
        "network_project_id": "modak-yeedu",
        "network_name": "modak-yeedu-spark-vpc",
        "network_tags": [
          "yeedu",
          "iap-allow"
        ],
        "subnet": "custom-subnet-modak-yeedu",
        "machine_network_availability_zone": {
          "availability_zone_id": 75,
          "name": "us-central1-a",
          "cloud_provider_id": 0,
          "region": "us-central1",
          "description": "Council Bluffs, Iowa, North America"
        }
      },
      "cloud_project": "modak-yeedu",
      "credentials_config": {
        "credential_config_id": 1,
        "name": "modakyeed-svc",
        "description": null,
        "credential_type": {
          "credential_type_id": 0,
          "name": "gcp",
          "cloud_provider_id": 0
        }
      },
      "boot_disk_image": {
        "boot_disk_image_id": 1,
        "name": "gcp_boot_disk",
        "description": "dev boot disk",
        "cloud_provider_id": 0,
        "linux_distro": {
          "linux_distro_id": 0,
          "distro_name": "UBUNTU",
          "distro_version": "20.04 LTS"
        },
        "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
      }
    },
    "hive_metastore_conf": {
      "hive_metastore_conf_id": null,
      "hive_metastore_conf_name": null
    },
    "spark_infra_version": {
      "spark_infra_version_id": 1,
      "spark_version": "3.2.2",
      "hive_version": "3.2.3",
      "hadoop_version": "3.2.4",
      "scala_version": "2.12.15",
      "python_version": "3.9.5",
      "notebook_support": true
    },
    "engine_cluster_spark_config": {
      "max_parallel_spark_job_execution_per_instance": 5,
      "standalone_workers_number": null
    },
    "object_storage_manager": {
      "object_storage_manager_id": 1,
      "name": "yeedu_osm",
      "description": "test",
      "credentials_config": {
        "credential_config_id": 1,
        "name": "modakyeedu-svc",
        "description": null,
        "credential_type_name": "gcp"
      },
      "object_storage_bucket_name": "modak-yeedu-nabu"
    }
  },
  "workspace": {
    "workspace_id": 1,
    "name": "spark_jobs_test",
    "description": "Test Spark Jobs"
  },
  "spark_job_type": {
    "job_type": "NOTEBOOK",
    "language": "Python3"
  },
  "max_concurrency": 1,
  "notebook_cells": {
    "cells": [
      {
        "cell_uuid": "3516b29f-13a3-427d-a466-fc0c85d7ad0e",
        "order": 0,
        "code": "",
        "output": [],
        "runStatus": false,
        "executionCount": 0,
        "isOutputError": false
      }
    ]
  },
  "last_notebook_run": {
    "notebook_id": null,
    "notebook_status": null
  },
  "conf": null,
  "packages": null,
  "jars": null,
  "files": null,
  "driver_memory": null,
  "executor_memory": null,
  "driver_cores": null,
  "total_executor_cores": null,
  "executor_cores": null,
  "num_executors": null,
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "active": true,
  "last_update_date": "2024-01-09T10:06:52.21698+00:00",
  "from_date": "2024-01-09T10:06:52.21698+00:00",
  "to_date": "infinity"
}
```

### edit-conf

```bash
yeedu notebook edit-conf -h
```

```bash
usage:  edit-conf [-h] --workspace_id WORKSPACE_ID
                  [--notebook_conf_id NOTEBOOK_CONF_ID]
                  [--notebook_name NOTEBOOK_NAME]
                  [--cluster_id CLUSTER_ID]
                  [--cluster_name CLUSTER_NAME] [--name [NAME]]
                  [--conf CONF [CONF ...]] [--files [FILES]]
                  [--jars [JARS]] [--packages [PACKAGES]]
                  [--driver-memory [DRIVER_MEMORY]]
                  [--executor-memory [EXECUTOR_MEMORY]]
                  [--driver-cores [DRIVER_CORES]]
                  [--total-executor-cores [TOTAL_EXECUTOR_CORES]]
                  [--executor-cores [EXECUTOR_CORES]]
                  [--num-executors [NUM_EXECUTORS]]
                  [--json-output [{pretty,default}]]
                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to edit a Notebook Configuration.
  --notebook_conf_id NOTEBOOK_CONF_ID
                        Provide Notbeook Conf Id to edit a Notebook Configuration.
  --notebook_name NOTEBOOK_NAME
                        Provide Notebook Name to edit a Notebook Configuration.
  --cluster_id CLUSTER_ID
                        Provide cluster_id to edit a Notebook Configuration.
  --cluster_name CLUSTER_NAME
                        Provide cluster_name to edit a Notebook Configuration.
  --name [NAME]         Provide name to edit notebook_name of a Notebook Configuration.
  --conf CONF [CONF ...]
                        Provide conf to edit a Notebook Configuration.
  --files [FILES]       Provide files to edit a Notebook Configuration.
  --jars [JARS]         Provide jars to edit a Notebook Configuration.
  --packages [PACKAGES]
                        Provide packages to edit a Notebook Configuration.
  --driver-memory [DRIVER_MEMORY]
                        Provide driver-memory to edit a Notebook Configuration.
  --executor-memory [EXECUTOR_MEMORY]
                        Provide executor-memory to edit a Notebook Configuration.
  --driver-cores [DRIVER_CORES]
                        Provide driver-cores to edit a Notebook Configuration.
  --total-executor-cores [TOTAL_EXECUTOR_CORES]
                        Provide total-executor-cores to edit a Notebook Configuration.
  --executor-cores [EXECUTOR_CORES]
                        Provide executor-cores to edit a Notebook Configuration.
  --num-executors [NUM_EXECUTORS]
                        Provide num-executors to edit a Notebook Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit-conf example with the required arguments and other optional arguments passed which is to be updated.

```bash
yeedu notebook edit-conf --workspace_id=1 --notebook_conf_id=21 --name=Notebook_01
```

- Console output

```bash
{
  "notebook_conf_id": "21",
  "notebook_name": "Notebook_01",
  "cluster_id": "1",
  "workspace_id": "1",
  "spark_job_type_lang_id": 3,
  "max_concurrency": "1",
  "notebook_cells": {
    "cells": [
      {
        "cell_uuid": "3516b29f-13a3-427d-a466-fc0c85d7ad0e",
        "order": 0,
        "code": "",
        "output": [],
        "runStatus": false,
        "executionCount": 0,
        "isOutputError": false
      }
    ]
  },
  "notebook_cells_auto_save": null,
  "conf": null,
  "packages": null,
  "jars": null,
  "files": null,
  "driver_memory": null,
  "executor_memory": null,
  "driver_cores": null,
  "total_executor_cores": null,
  "executor_cores": null,
  "num_executors": null,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-09T10:15:19.396Z",
  "from_date": "2024-01-09T10:06:52.216Z",
  "to_date": null
}
```

### enable-conf

```bash
yeedu notebook enable-conf -h
```

```bash
usage:  enable-conf [-h] --workspace_id WORKSPACE_ID
                    [--notebook_conf_id NOTEBOOK_CONF_ID]
                    [--notebook_name NOTEBOOK_NAME]
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to enable the Notebook Configuration.
  --notebook_conf_id NOTEBOOK_CONF_ID
                        Provide Notebook Conf Id to enable the Notebook Configuration.
  --notebook_name NOTEBOOK_NAME
                        Provide Notebook Name to enable the Notebook Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- enable-conf example with the required arguments passed.

```bash
yeedu notebook enable-conf --workspace_id=1 --notebook_conf_id=140
```

- Console output

```bash
{
  "notebook_conf_id": "21",
  "notebook_name": "Notebook_01",
  "cluster_id": "1",
  "workspace_id": "1",
  "spark_job_type_lang_id": 3,
  "max_concurrency": "1",
  "notebook_cells": {
    "cells": [
      {
        "cell_uuid": "3516b29f-13a3-427d-a466-fc0c85d7ad0e",
        "order": 0,
        "code": "",
        "output": [],
        "runStatus": false,
        "executionCount": 0,
        "isOutputError": false
      }
    ]
  },
  "notebook_cells_auto_save": null,
  "conf": null,
  "packages": null,
  "jars": null,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-09T10:23:13.631Z",
  "from_date": "2024-01-09T10:06:52.216Z",
  "to_date": null
}
```

### disable-conf

```bash
yeedu notebook disable-conf -h
```

```bash
usage:  disable-conf [-h] --workspace_id WORKSPACE_ID
                     [--notebook_conf_id NOTEBOOK_CONF_ID]
                     [--notebook_name NOTEBOOK_NAME]
                     [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to disable the Notebook Configuration.
  --notebook_conf_id NOTEBOOK_CONF_ID
                        Provide Notebook Conf Id to disable the Notebook Configuration.
  --notebook_name NOTEBOOK_NAME
                        Provide Notebook Name to disable the Notebook Configuration.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- disable-conf example with the required arguments passed.

```bash
yeedu notebook disable-conf --workspace_id=1 --notebook_conf_id=140
```

- Console output

```bash
{
  "notebook_conf_id": "21",
  "notebook_name": "Notebook_01",
  "cluster_id": "1",
  "workspace_id": "1",
  "spark_job_type_lang_id": 3,
  "max_concurrency": "1",
  "notebook_cells": {
    "cells": [
      {
        "cell_uuid": "3516b29f-13a3-427d-a466-fc0c85d7ad0e",
        "order": 0,
        "code": "",
        "output": [],
        "runStatus": false,
        "executionCount": 0,
        "isOutputError": false
      }
    ]
  },
  "notebook_cells_auto_save": null,
  "conf": null,
  "packages": null,
  "jars": null,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-09T10:22:42.399Z",
  "from_date": "2024-01-09T10:06:52.216Z",
  "to_date": "2024-01-09T10:22:42.399Z"
}
```

## Notebook Instance

| Command Name                         | Utility                                                |
|--------------------------------------|--------------------------------------------------------|
|[start](#start-2)                     | To start a Notebook Instance.                          |
|[kernel-start](#kernel-start)         | To start a kernel of a Notebook Instance.              |
|[kernel-interrupt](#kernel-interrupt) | To interrupt a kernel of a Notebook Instance.          |
|[kernel-restart](#kernel-restart)     | To restart a kernel of a Notebook Instance.            |
|[list](#list-3)                       | To list all the available Notebook Instances.          |
|[search](#search-3)                   | To search Notebook Instances by similar notebook name. |
|[get](#get-3)                         | To get information about a specific Notebook Instance. |
|[stop](#stop-2)                       | To stop a specific Notebook Instance.                  |
|[logs](#logs-2)                       | To download Notebook Instance logs.                    |

### start

```bash
yeedu notebook start -h
```

```bash
usage:  start [-h] --workspace_id WORKSPACE_ID
              [--notebook_conf_id NOTEBOOK_CONF_ID]
              [--notebook_name NOTEBOOK_NAME]
              [--json-output [{pretty,default}]]
              [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        To start a Notebook Instance, enter workspace_id.
  --notebook_conf_id NOTEBOOK_CONF_ID
                        To start a Notebook Instance, enter notebook_conf_id.
  --notebook_name NOTEBOOK_NAME
                        To start a Notebook Instance, enter notebook_name.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- start example with one of the required argument passed.

```bash
yeedu notebook start --workspace_id=1 --notebook_conf_id=1
```

- Console output

```bash
{
  "notebook_id": "4",
  "notebook_conf_id": "21",
  "cluster_id": "1",
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-09T11:39:06.698Z",
  "from_date": "2024-01-09T11:39:06.698Z",
  "to_date": null
}
```

### kernel-start

```bash
yeedu notebook kernel-start -h
```

```bash
usage:  kernel-start [-h] --workspace_id WORKSPACE_ID --notebook_id NOTEBOOK_ID
                     [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        To start a kernel of a Notebook Instance, enter workspace_id.
  --notebook_id NOTEBOOK_ID
                        To start a kernel of a Notebook Instance, enter notebook
                        instance id.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- kernel-start example to with all the required arguments passed.

```bash
yeedu notebook kernel-start --workspace_id=1 --notebook_id=142
```

- Console output

```bash
{
  "notebook_id": 142,
  "kernel_info": {
    "kernel_id": "71e6acb5-d4d8-4311-a4a3-7f8a8d6a0291",
    "kernel_status": "starting"
  }
}
```

### kernel-interrupt

```bash
yeedu notebook kernel-interrupt -h
```

```bash
usage:  kernel-interrupt [-h] --workspace_id WORKSPACE_ID --notebook_id NOTEBOOK_ID
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        To interrupt a kernel of a Notebook Instance, enter
                        workspace_id.
  --notebook_id NOTEBOOK_ID
                        To interrupt a kernel of a Notebook Instance, enter notebook
                        instance id.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- kernel-interrupt example to with required and optional arguments passed.

```bash
yeedu notebook kernel-interrupt --workspace_id=1 --notebook_id=142
```

- Console output

```bash
{
  "notebook_id": 142,
  "kernel_info": {
    "kernel_id": "71e6acb5-d4d8-4311-a4a3-7f8a8d6a0291",
    "kernel_status": "starting"
  }
}
```

### kernel-restart

```bash
yeedu notebook kernel-restart -h
```

```bash
usage:  kernel-restart [-h] --workspace_id WORKSPACE_ID --notebook_id NOTEBOOK_ID
                       [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        To restart a kernel of a Notebook Instance, enter workspace_id.
  --notebook_id NOTEBOOK_ID
                        To restart a kernel of a Notebook Instance, enter notebook
                        instance id.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- kernel-restart example with all the required arguments passed.

```bash
yeedu notebook kernel-restart --workspace_id=1 --notebook_id=142
```

- Console output

```bash
{
  "notebook_id": 142,
  "kernel_info": {
    "kernel_id": "71e6acb5-d4d8-4311-a4a3-7f8a8d6a0291",
    "kernel_status": "idle"
  }
}
```

### list

```bash
yeedu notebook list -h
```

```bash
usage:  list [-h] --workspace_id WORKSPACE_ID
             [--cluster_id CLUSTER_ID]
             [--notebook_conf_id NOTEBOOK_CONF_ID]
             [--notebook_name NOTEBOOK_NAME]
             [--notebook_status {submitted,running,done,error,terminated,stopping,stopped}]
             [--page_number PAGE_NUMBER] [--limit LIMIT]
             [--json-output [{pretty,default}]]
             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        To list Notebook Instances of a specific workspace_id.
  --cluster_id CLUSTER_ID
                        To list Notebook Instances of a specific cluster_id.
  --notebook_conf_id NOTEBOOK_CONF_ID
                        To list Notebook Instances of a specific notebook_conf_id.
  --notebook_name NOTEBOOK_NAME
                        To list Notebook Instances of a specific notebook_name.
  --notebook_status {submitted,running,done,error,terminated,stopping,stopped}
                        To list Notebook Instances of a specific notebook_status.
  --page_number PAGE_NUMBER
                        To list Notebook Instances for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of job instances. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list example to with all the required and optional arguments passed.

```bash
yeedu notebook list --workspace_id=1 --notebook_status=running
```

- Console output

```bash
{
  "data": [
    {
      "notebook_id": 2,
      "notebook_url": "http://yeedu3-87cdc71b-e8ad-cbda-15b3-ec4694e7826a.us-central1-a.c.modak-yeedu.internal:8888",
      "notebook_status": "RUNNING",
      "notebook_conf": {
        "notebook_conf_id": 2,
        "notebook_name": "test_notebook",
        "cluster_info": {
          "cluster_id": 2,
          "name": "yeedu_instance",
          "description": "Test yeedu instance",
          "labels": {
            "test": "yeedu",
            "resource": "yeedu",
            "vm": "yeedu_node",
            "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
          },
          "idle_timeout_ms": 1200000,
          "auto_shutdown": true,
          "cluster_status": "RUNNING",
          "cluster_type": "YEEDU",
          "compute_engine_id": 2,
          "instance_size": 1,
          "is_spot_instance": false,
          "enable_public_ip": false,
          "block_project_ssh_keys": false,
          "min_instances": 1,
          "max_instances": 3,
          "total_ycu": null,
          "bootstrap_shell_script": null,
          "spark_config_id": null,
          "cluster_conf": {
            "cluster_conf_id": 1,
            "cluster_conf_name": "n1-standard-4",
            "description": null,
            "machine_type_category": "general_purpose",
            "machine_type": {
              "machine_type_id": 64,
              "name": "n1-standard-4",
              "vcpus": 4,
              "memory": "15 GiB",
              "has_cuda": false,
              "gpu_model": null,
              "gpus": null,
              "gpu_memory": null
            },
            "machine_volume_conf": {
              "volume_conf_id": 1,
              "name": "volume_gcp",
              "description": null,
              "encrypted": true,
              "size": 375,
              "disk_machine_type": {
                "disk_machine_type_id": 4,
                "cloud_provider_id": 0,
                "name": "local-ssd",
                "has_fixed_size": true,
                "min_size": 375,
                "max_size": 375
              },
              "machine_volume_num": 1,
              "machine_volume_strip_num": 1
            }
          },
          "cloud_env": {
            "cloud_env_id": 1,
            "name": "gcp_cloud_env",
            "description": "yeedu cloud environment",
            "cloud_provider": {
              "cloud_provider_id": 0,
              "name": "gcp"
            },
            "availabilty_zone": {
              "availabilty_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            },
            "machine_network": {
              "machine_network_conf_id": 1,
              "name": "yeedu_gcp_network",
              "description": null,
              "network_project_id": "modak-yeedu",
              "network_name": "modak-yeedu-spark-vpc",
              "network_tags": [
                "yeedu",
                "iap-allow"
              ],
              "subnet": "custom-subnet-modak-yeedu",
              "machine_network_availability_zone": {
                "availability_zone_id": 75,
                "name": "us-central1-a",
                "cloud_provider_id": 0,
                "region": "us-central1",
                "description": "Council Bluffs, Iowa, North America"
              }
            },
            "cloud_project": "modak-yeedu",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type": {
                "credential_type_id": 0,
                "name": "gcp",
                "cloud_provider_id": 0
              }
            },
            "boot_disk_image": {
              "boot_disk_image_id": 1,
              "name": "gcp_boot_disk",
              "description": "dev boot disk",
              "cloud_provider_id": 0,
              "linux_distro": {
                "linux_distro_id": 0,
                "distro_name": "UBUNTU",
                "distro_version": "20.04 LTS"
              },
              "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
            }
          },
          "hive_metastore_conf": {
            "hive_metastore_conf_id": null,
            "hive_metastore_conf_name": null
          },
          "spark_infra_version": {
            "spark_infra_version_id": 1,
            "spark_version": "3.2.2",
            "hive_version": "3.2.3",
            "hadoop_version": "3.2.4",
            "scala_version": "2.12.15",
            "python_version": "3.9.5",
            "notebook_support": true
          },
          "engine_cluster_spark_config": {
            "max_parallel_spark_job_execution_per_instance": 5,
            "standalone_workers_number": null
          },
          "object_storage_manager": {
            "object_storage_manager_id": 1,
            "name": "yeedu_osm",
            "description": "test",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type_name": "gcp"
            },
            "object_storage_bucket_name": "modak-yeedu-nabu"
          }
        },
        "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
        },
        "notebook_job_type": {
          "job_type": "NOTEBOOK",
          "language": "Python3"
        },
        "max_concurrency": 1,
        "notebook_cells": {
          "cells": [
            {
              "cell_uuid": "70538495-aeb0-4df6-bb26-2b20f5663f0c",
              "order": 0,
              "code": "",
              "output": [],
              "runStatus": false,
              "executionCount": 0,
              "isOutputError": false
            }
          ]
        },
        "notebook_cells_auto_save": null,
        "conf": null,
        "packages": null,
        "jars": null
      },
      "workflow_job_instance_details": {
        "workflow_job_instance_status": {
          "workflow_job_instance_id": 4,
          "workflow_job_id": 4,
          "status": "DONE",
          "from_date": "2023-12-28T14:44:12.047802+00:00",
          "to_date": "2023-12-28T14:44:59.648713+00:00"
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-01T14:44:12.047802+00:00",
      "from_date": "2024-01-01T14:44:12.047802+00:00",
      "to_date": "2024-01-01T14:44:59.648713+00:00"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search

```bash
yeedu notebook search -h
```

```bash
usage:  search [-h] --workspace_id WORKSPACE_ID --notebook_name NOTEBOOK_NAME
               [--page_number PAGE_NUMBER] [--limit LIMIT]
               [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to search Notebook Instances in it.
  --notebook_name NOTEBOOK_NAME
                        Provide notebook_name to search Notebook Instances.
  --page_number PAGE_NUMBER
                        To search Notebook Instances for a specific page_number.
                        (default: 1)
  --limit LIMIT         Provide limit to search number of Notebook Instances. (default:
                        100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search example to with all the required and optional arguments passed.

```bash
yeedu notebook search --workspace_id=1 --notebook_name="test_" --limit=1
```

- Console output

```bash
{
  "data": [
    {
      "notebook_id": 2,
      "notebook_url": "http://yeedu3-87cdc71b-e8ad-cbda-15b3-ec4694e7826a.us-central1-a.c.modak-yeedu.internal:8888",
      "notebook_status": "RUNNING",
      "notebook_conf": {
        "notebook_conf_id": 2,
        "notebook_name": "test_notebook",
        "cluster_info": {
          "cluster_id": 2,
          "name": "yeedu_instance",
          "description": "Test yeedu instance",
          "labels": {
            "test": "yeedu",
            "resource": "yeedu",
            "vm": "yeedu_node",
            "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
          },
          "idle_timeout_ms": 1200000,
          "auto_shutdown": true,
          "cluster_status": "RUNNING",
          "cluster_type": "YEEDU",
          "compute_engine_id": 2,
          "instance_size": 1,
          "is_spot_instance": false,
          "enable_public_ip": false,
          "block_project_ssh_keys": false,
          "min_instances": 1,
          "max_instances": 3,
          "total_ycu": null,
          "bootstrap_shell_script": null,
          "spark_config_id": null,
          "cluster_conf": {
            "cluster_conf_id": 1,
            "cluster_conf_name": "n1-standard-4",
            "description": null,
            "machine_type_category": "general_purpose",
            "machine_type": {
              "machine_type_id": 64,
              "name": "n1-standard-4",
              "vcpus": 4,
              "memory": "15 GiB",
              "has_cuda": false,
              "gpu_model": null,
              "gpus": null,
              "gpu_memory": null
            },
            "machine_volume_conf": {
              "volume_conf_id": 1,
              "name": "volume_gcp",
              "description": null,
              "encrypted": true,
              "size": 375,
              "disk_machine_type": {
                "disk_machine_type_id": 4,
                "cloud_provider_id": 0,
                "name": "local-ssd",
                "has_fixed_size": true,
                "min_size": 375,
                "max_size": 375
              },
              "machine_volume_num": 1,
              "machine_volume_strip_num": 1
            }
          },
          "cloud_env": {
            "cloud_env_id": 1,
            "name": "gcp_cloud_env",
            "description": "yeedu cloud environment",
            "cloud_provider": {
              "cloud_provider_id": 0,
              "name": "gcp"
            },
            "availabilty_zone": {
              "availabilty_zone_id": 75,
              "name": "us-central1-a",
              "cloud_provider_id": 0,
              "region": "us-central1",
              "description": "Council Bluffs, Iowa, North America"
            },
            "machine_network": {
              "machine_network_conf_id": 1,
              "name": "yeedu_gcp_network",
              "description": null,
              "network_project_id": "modak-yeedu",
              "network_name": "modak-yeedu-spark-vpc",
              "network_tags": [
                "yeedu",
                "iap-allow"
              ],
              "subnet": "custom-subnet-modak-yeedu",
              "machine_network_availability_zone": {
                "availability_zone_id": 75,
                "name": "us-central1-a",
                "cloud_provider_id": 0,
                "region": "us-central1",
                "description": "Council Bluffs, Iowa, North America"
              }
            },
            "cloud_project": "modak-yeedu",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type": {
                "credential_type_id": 0,
                "name": "gcp",
                "cloud_provider_id": 0
              }
            },
            "boot_disk_image": {
              "boot_disk_image_id": 1,
              "name": "gcp_boot_disk",
              "description": "dev boot disk",
              "cloud_provider_id": 0,
              "linux_distro": {
                "linux_distro_id": 0,
                "distro_name": "UBUNTU",
                "distro_version": "20.04 LTS"
              },
              "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
            }
          },
          "hive_metastore_conf": {
            "hive_metastore_conf_id": null,
            "hive_metastore_conf_name": null
          },
          "spark_infra_version": {
            "spark_infra_version_id": 1,
            "spark_version": "3.2.2",
            "hive_version": "3.2.3",
            "hadoop_version": "3.2.4",
            "scala_version": "2.12.15",
            "python_version": "3.9.5",
            "notebook_support": true
          },
          "engine_cluster_spark_config": {
            "max_parallel_spark_job_execution_per_instance": 5,
            "standalone_workers_number": null
          },
          "object_storage_manager": {
            "object_storage_manager_id": 1,
            "name": "yeedu_osm",
            "description": "test",
            "credentials_config": {
              "credential_config_id": 1,
              "name": "modakyeedu-svc",
              "description": null,
              "credential_type_name": "gcp"
            },
            "object_storage_bucket_name": "modak-yeedu-nabu"
          }
        },
        "workspace": {
          "workspace_id": 1,
          "name": "spark_jobs_test",
          "description": "Test Spark Jobs"
        },
        "notebook_job_type": {
          "job_type": "NOTEBOOK",
          "language": "Python3"
        },
        "max_concurrency": 1,
        "notebook_cells": {
          "cells": [
            {
              "cell_uuid": "70538495-aeb0-4df6-bb26-2b20f5663f0c",
              "order": 0,
              "code": "",
              "output": [],
              "runStatus": false,
              "executionCount": 0,
              "isOutputError": false
            }
          ]
        },
        "notebook_cells_auto_save": null,
        "conf": null,
        "packages": null,
        "jars": null
      },
      "workflow_job_instance_details": {
        "workflow_job_instance_status": {
          "workflow_job_instance_id": 4,
          "workflow_job_id": 4,
          "status": "DONE",
          "from_date": "2023-12-28T14:44:12.047802+00:00",
          "to_date": "2023-12-28T14:44:59.648713+00:00"
        }
      },
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-01T14:44:12.047802+00:00",
      "from_date": "2024-01-01T14:44:12.047802+00:00",
      "to_date": "2024-01-01T14:44:59.648713+00:00"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get

```bash
yeedu notebook get -h
```

```bash
usage:  get [-h] --workspace_id WORKSPACE_ID --notebook_id NOTEBOOK_ID
            [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to get information about a specific
                        Notebook Instance.
  --notebook_id NOTEBOOK_ID
                        Provide notebook instance id to get information about a specific
                        Notebook Instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get example with all the required arguments passed.

```bash
yeedu notebook get --workspace_id=1 --notebook_id=142
```

- Console output

```bash
{
  "notebook_id": 2,
  "notebook_url": "http://yeedu3-87cdc71b-e8ad-cbda-15b3-ec4694e7826a.us-central1-a.c.modak-yeedu.internal:8888",
  "notebook_status": "RUNNING",
  "notebook_conf": {
    "notebook_conf_id": 2,
    "notebook_name": "test_notebook",
    "cluster_info": {
      "cluster_id": 2,
      "name": "yeedu_instance",
      "description": "Test yeedu instance",
      "labels": {
        "test": "yeedu",
        "resource": "yeedu",
        "vm": "yeedu_node",
        "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615"
      },
      "idle_timeout_ms": 1200000,
      "auto_shutdown": true,
      "cluster_status": "RUNNING",
      "cluster_type": "YEEDU",
      "compute_engine_id": 2,
      "instance_size": 1,
      "is_spot_instance": false,
      "enable_public_ip": false,
      "block_project_ssh_keys": false,
      "min_instances": 1,
      "max_instances": 3,
      "total_ycu": null,
      "bootstrap_shell_script": null,
      "spark_config_id": null,
      "cluster_conf": {
        "cluster_conf_id": 1,
        "cluster_conf_name": "n1-standard-4",
        "description": null,
        "machine_type_category": "general_purpose",
        "machine_type": {
          "machine_type_id": 64,
          "name": "n1-standard-4",
          "vcpus": 4,
          "memory": "15 GiB",
          "has_cuda": false,
          "gpu_model": null,
          "gpus": null,
          "gpu_memory": null
        },
        "machine_volume_conf": {
          "volume_conf_id": 1,
          "name": "volume_gcp",
          "description": null,
          "encrypted": true,
          "size": 375,
          "disk_machine_type": {
            "disk_machine_type_id": 4,
            "cloud_provider_id": 0,
            "name": "local-ssd",
            "has_fixed_size": true,
            "min_size": 375,
            "max_size": 375
          },
          "machine_volume_num": 1,
          "machine_volume_strip_num": 1
        }
      },
      "cloud_env": {
        "cloud_env_id": 1,
        "name": "gcp_cloud_env",
        "description": "yeedu cloud environment",
        "cloud_provider": {
          "cloud_provider_id": 0,
          "name": "gcp"
        },
        "availabilty_zone": {
          "availabilty_zone_id": 75,
          "name": "us-central1-a",
          "cloud_provider_id": 0,
          "region": "us-central1",
          "description": "Council Bluffs, Iowa, North America"
        },
        "machine_network": {
          "machine_network_conf_id": 1,
          "name": "yeedu_gcp_network",
          "description": null,
          "network_project_id": "modak-yeedu",
          "network_name": "modak-yeedu-spark-vpc",
          "network_tags": [
            "yeedu",
            "iap-allow"
          ],
          "subnet": "custom-subnet-modak-yeedu",
          "machine_network_availability_zone": {
            "availability_zone_id": 75,
            "name": "us-central1-a",
            "cloud_provider_id": 0,
            "region": "us-central1",
            "description": "Council Bluffs, Iowa, North America"
          }
        },
        "cloud_project": "modak-yeedu",
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modakyeedu-svc",
          "description": null,
          "credential_type": {
            "credential_type_id": 0,
            "name": "gcp",
            "cloud_provider_id": 0
          }
        },
        "boot_disk_image": {
          "boot_disk_image_id": 1,
          "name": "gcp_boot_disk",
          "description": "dev boot disk",
          "cloud_provider_id": 0,
          "linux_distro": {
            "linux_distro_id": 0,
            "distro_name": "UBUNTU",
            "distro_version": "20.04 LTS"
          },
          "boot_disk_image": "ubuntu-os-cloud/ubuntu-2004-lts"
        }
      },
      "hive_metastore_conf": {
        "hive_metastore_conf_id": null,
        "hive_metastore_conf_name": null
      },
      "spark_infra_version": {
        "spark_infra_version_id": 1,
        "spark_version": "3.2.2",
        "hive_version": "3.2.3",
        "hadoop_version": "3.2.4",
        "scala_version": "2.12.15",
        "python_version": "3.9.5",
        "notebook_support": true
      },
      "engine_cluster_spark_config": {
        "max_parallel_spark_job_execution_per_instance": 5,
        "standalone_workers_number": null
      },
      "object_storage_manager": {
        "object_storage_manager_id": 1,
        "name": "yeedu_osm",
        "description": "test",
        "credentials_config": {
          "credential_config_id": 1,
          "name": "modakyeedu-svc",
          "description": null,
          "credential_type_name": "gcp"
        },
        "object_storage_bucket_name": "modak-yeedu-nabu"
      }
    },
    "workspace": {
      "workspace_id": 1,
      "name": "spark_jobs_test",
      "description": "Test Spark Jobs"
    },
    "notebook_job_type": {
      "job_type": "NOTEBOOK",
      "language": "Python3"
    },
    "max_concurrency": 1,
    "notebook_cells": {
      "cells": [
        {
          "cell_uuid": "70538495-aeb0-4df6-bb26-2b20f5663f0c",
          "order": 0,
          "code": "",
          "output": [],
          "runStatus": false,
          "executionCount": 0,
          "isOutputError": false
        }
      ]
    },
    "notebook_cells_auto_save": null,
    "conf": null,
    "packages": null,
    "jars": null
  },
  "workflow_job_instance_details": {
    "workflow_job_instance_status": {
      "workflow_job_instance_id": 4,
      "workflow_job_id": 4,
      "status": "DONE",
      "from_date": "2023-12-28T14:44:12.047802+00:00",
      "to_date": "2023-12-28T14:44:59.648713+00:00"
    }
  },
  "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2024-01-01T14:44:12.047802+00:00",
  "from_date": "2024-01-01T14:44:12.047802+00:00",
  "to_date": "2024-01-01T14:44:59.648713+00:00"
}
```

### stop

```bash
yeedu notebook stop -h
```

```bash
usage:  stop [-h] --workspace_id WORKSPACE_ID --notebook_id NOTEBOOK_ID
             [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide workspace id to stop a specific Notebook Instance.
  --notebook_id NOTEBOOK_ID
                        Provide notebook instance id to stop a specific Notebook
                        Instance.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- stop example with all the required argument passed.

```bash
yeedu notebook stop --workspace_id=1 --notebook_id=139
```

- Console output

```bash
{
  "SparkKill": {
    "workflow_job_id": 275,
    "workflow_job_instance_id": 275,
    "spark_job_instance_id": 139,
    "spark_job_id": 140,
    "compute_engine_id": 3
  }
}
```

### logs

```bash
yeedu notebook logs -h
```

```bash
usage:  logs [-h] --workspace_id WORKSPACE_ID --notebook_id NOTEBOOK_ID
             [--log_type {stdout,stderr}] [--json-output [{pretty,default}]]
             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --workspace_id WORKSPACE_ID
                        Provide Workspace Id to download Notebook Instance logs.
  --notebook_id NOTEBOOK_ID
                        Provide Notebook Id to download Notebook Instance logs.
  --log_type {stdout,stderr}
                        Provide log type to download Notebook Instance logs. (default:
                        stdout)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- logs example with all the required arguments passed.

```bash
yeedu notebook logs --workspace_id=1 --notebook_id=2 --log_type="stderr"
```

- Console output

```bash
[I 2023-10-04 11:15:25.902 ServerApp] Package notebook took 0.0000s to import
[I 2023-10-04 11:15:25.912 ServerApp] Package jupyter_lsp took 0.0092s to import
[W 2023-10-04 11:15:25.912 ServerApp] A `_jupyter_server_extension_points` function was not found in jupyter_lsp. Instead, a `_jupyter_server_extension_paths` function was found and will be used for now. This function name will be deprecated in future releases of Jupyter Server.
[I 2023-10-04 11:15:25.917 ServerApp] Package jupyter_server_terminals took 0.0049s to import
[I 2023-10-04 11:15:25.918 ServerApp] Package jupyterlab took 0.0000s to import
[I 2023-10-04 11:15:25.943 ServerApp] Package notebook_shim took 0.0000s to import
[W 2023-10-04 11:15:25.943 ServerApp] A `_jupyter_server_extension_points` function was not found in notebook_shim. Instead, a `_jupyter_server_extension_paths` function was found and will be used for now. This function name will be deprecated in future releases of Jupyter Server.
[I 2023-10-04 11:15:25.943 ServerApp] jupyter_lsp | extension was successfully linked.
[I 2023-10-04 11:15:25.947 ServerApp] jupyter_server_terminals | extension was successfully linked.
[I 2023-10-04 11:15:25.952 ServerApp] jupyterlab | extension was successfully linked.
[I 2023-10-04 11:15:25.956 ServerApp] notebook | extension was successfully linked.
[I 2023-10-04 11:15:26.143 ServerApp] notebook_shim | extension was successfully linked.
[I 2023-10-04 11:15:26.164 ServerApp] notebook_shim | extension was successfully loaded.
[I 2023-10-04 11:15:26.166 ServerApp] jupyter_lsp | extension was successfully loaded.
[I 2023-10-04 11:15:26.167 ServerApp] jupyter_server_terminals | extension was successfully loaded.
[I 2023-10-04 11:15:26.169 LabApp] JupyterLab extension loaded from /usr/local/lib/python3.9/dist-packages/jupyterlab
[I 2023-10-04 11:15:26.169 LabApp] JupyterLab application directory is /usr/local/share/jupyter/lab
[I 2023-10-04 11:15:26.169 LabApp] Extension Manager is 'pypi'.
[I 2023-10-04 11:15:26.173 ServerApp] jupyterlab | extension was successfully loaded.
[I 2023-10-04 11:15:26.175 ServerApp] notebook | extension was successfully loaded.
[I 2023-10-04 11:15:26.184 ServerApp] Serving notebooks from local directory: /opt/spark
[I 2023-10-04 11:15:26.184 ServerApp] Jupyter Server 2.7.2 is running at:
[I 2023-10-04 11:15:26.184 ServerApp] http://yeedu3-87cdc71b-e8ad-cbda-15b3-ec4694e7826a.us-central1-a.c.modak-yeedu.internal:8888/tree?token=d192e22dbccc3245500f0a873020769534abc908be299686
...
...
...
[I 2023-10-04 11:15:49.712 ServerApp] Kernel started: 71e6acb5-d4d8-4311-a4a3-7f8a8d6a0291
[I 2023-10-04 11:18:24.166 ServerApp] Kernel interrupted: 71e6acb5-d4d8-4311-a4a3-7f8a8d6a0291
[I 2023-10-04 11:19:38.766 ServerApp] Kernel restarted: 71e6acb5-d4d8-4311-a4a3-7f8a8d6a0291
```

# IAM (Identity and Access Management)

## User

| Command Name                         | Utility                                                   |
|--------------------------------------|-----------------------------------------------------------|
|[get-user-info](#get-user-info)       | To get information about current session user.            |
|[get-user-roles](#get-user-roles)     | To get all the roles of current session user.             |

### get-user-info

```bash
yeedu iam get-user-info -h
```

```bash
usage:  get-user-info [-h] [--json-output [{pretty,default}]]
                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-user-info example without any optional arguments passed.

```bash
yeedu iam get-user-info
```

- Console output

```bash
{
  "user_id": "1",
  "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
  "username": "USER",
  "email": "user@yeedu.com",
  "group_info": [
    {
      "group_id": 1,
      "groupname": "yeedu-user"
    }
  ],
  "from_date": "2024-01-01T15:49:50.399Z",
  "to_date": null
}
```

### get-user-roles

```bash
yeedu iam get-user-roles -h
```

```bash
usage:  get-user-roles [-h] [--json-output [{pretty,default}]]
                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-user-roles example without any optional arguments passed.

```bash
yeedu iam get-user-roles
```

- Console output

```bash
{
  "user_id": 2,
  "username": "RU0000",
  "user_roles": [
    "User"
  ],
  "group_roles": [
    {
      "group_id": 8,
      "group_name": "Yeedu",
      "role_id": 2,
      "group_role": "Admin"
    }
  ]

}
```

## Shared Platform and Admin

| Command Name                          | Utility                                        |
|---------------------------------------|------------------------------------------------|
|[sync-user](#sync-user)                | To get the information about a specific User.  |
|[sync-group](#sync-group)              | To get the information about a specific Group. |
|[list-user-groups](#list-user-groups)  | To list all the Groups for a specific User.    |
|[list-users](#list-users-2)            | To list all the available Users.               |
|[search-users](#search-users-1)        | To search the users based on username.         |
|[match-user](#match-user-1)            | To match exactly the user for the given username.|
|[list-group-users](#list-group-users)  | To list all the Users for a specific Group.    |
|[list-groups](#list-groups-2)          | To list all the available Groups.              |
|[search-groups](#search-groups)        | To search the groups based on groupname.       |
|[match-group](#match-group-1)          | To match exactly the group for the given groupname.|

### sync-user

```bash
yeedu iam sync-user -h
```

```bash
usage:  sync-user [-h] --username USERNAME
                  [--json-output [{pretty,default}]]
                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --username USERNAME   Provide username to get information about a specific User.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- sync-user example with required argument '--username' passed.

```bash
yeedu iam sync-user --username="USER"
```

- Console output

```bash
{
  "user_id": "1",
  "username": "USER",
  "email": "user@yeedu.com",
  "from_date": "2024-01-01T10:03:06.200Z",
  "to_date": null
}
```

### sync-group

```bash
yeedu iam sync-group -h
```

```bash
usage:  sync-group [-h] --groupname GROUPNAME
                   [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --groupname GROUPNAME
                        Provide groupname to get information about a specific Group.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- sync-group example with required argument '--groupname' passed.

```bash
yeedu iam sync-group --groupname="yeedu"
```

- Console output

```bash
{
  "group_id": "1",
  "group_name": "yeedu",
  "from_date": "2024-01-01T14:30:20.723Z",
  "to_date": null
}
```

### list-user-groups

```bash
yeedu iam list-user-groups -h
```

```bash
usage:  list-user-groups [-h] --user_id USER_ID
                         [--page_number PAGE_NUMBER] [--limit LIMIT]
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --user_id USER_ID     Provide user_id to list all the groups for a specific User.
  --page_number PAGE_NUMBER
                        To list groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-user-groups example with required argument '--user_id' passed.

```bash
yeedu iam list-user-groups --user_id=1
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 2,
      "group_name": "Yeedu",
      "group_type": null,
      "from_date": "2024-01-01T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 1,
      "group_name": "Modak Yeedu",
      "group_type": "Unified",
      "from_date": "2023-01-01T14:01:50.367429+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 2,
    "total_pages": 1,
    "limit": 100
  }
}
```

### list-users

```bash
yeedu iam list-users -h
```

```bash
usage:  list-users [-h] [--group_id GROUP_ID]
                   [--page_number PAGE_NUMBER] [--limit LIMIT]
                   [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --group_id GROUP_ID   Provide group_id to list all the users for a specific group.
  --page_number PAGE_NUMBER
                        To list users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-users example without any optional arguments passed.

```bash
yeedu iam list-users
```

- Console output

```bash
{
  "data": [
    {
      "user_id": 1,
      "username": "YSU0000",
      "email": "ysu0000@modak.com"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-users

```bash
yeedu iam search-users -h
```

```bash
usage:  search-users [-h] --username USERNAME [--group_id GROUP_ID]
                     [--page_number PAGE_NUMBER] [--limit LIMIT]
                     [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --username USERNAME   Provide username to search users matching username.
  --group_id GROUP_ID   Provide group_id to search all the users of a specific group.
  --page_number PAGE_NUMBER
                        To search users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-users example with required argument passed.

```bash
yeedu iam search-users --username="Y"
```

- Console output

```bash
{
  "data": [
    {
      "user_id": 1,
      "username": "YSU0000",
      "email": "ysu000@modak.com"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### match-user

```bash
yeedu iam match-user -h
```

```bash
usage:  match-user [-h] --username USERNAME
                   [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --username USERNAME   Provide username to get user details.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- match-user example with required argument passed.

```bash
yeedu iam match-user --username="YSU0000"
```

- Console output

```bash
{
  "user_id": 1,
  "username": "YSU0000",
  "email": "ysu0000@modak.com",
  "from_date": "2024-01-01T14:01:50.367429+00:00",
  "to_date": "infinity"
}
```

### list-group-users

```bash
yeedu iam list-group-users -h
```

```bash
usage:  list-group-users [-h] --group_id GROUP_ID
                         [--page_number PAGE_NUMBER] [--limit LIMIT]
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --group_id GROUP_ID   Provide group_id to list all the users for a specific Group.
  --page_number PAGE_NUMBER
                        To list users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-group-users example with required argument '--group_id' passed.

```bash
yeedu iam list-group-users --group_id=2
```

- Console output

```bash
{
  "data": [
    {
      "user_id": 1,
      "username": "YSU0000",
      "email": "ysu0000@modak.com"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### list-groups

```bash
yeedu iam list-groups -h
```

```bash
usage:  list-groups [-h] [--user_id USER_ID]
                    [--page_number PAGE_NUMBER] [--limit LIMIT]
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --user_id USER_ID     Provide user_id to list all the groups of a specific user.
  --page_number PAGE_NUMBER
                        To list users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-groups example without any optional arguments passed.

```bash
yeedu iam list-groups
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 1,
      "group_name": "modakanalytics.com",
      "group_type": "Unified",
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 2,
      "group_name": "All Users",
      "group_type": "DynamicMembership",
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 3,
      "group_name": "Spark and Scala- N",
      "group_type": "Unified",
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 4,
      "group_name": "Team Training & KT",
      "group_type": "Unified",
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 5,
      "group_name": "Modak_Executors",
      "group_type": null,
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 6,
      "group_name": "ModakitesIndia",
      "group_type": null,
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 6,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-groups

```bash
yeedu iam search-groups -h
```

```bash
usage:  search-groups [-h] --groupname GROUPNAME [--user_id USER_ID]
                      [--page_number PAGE_NUMBER] [--limit LIMIT]
                      [--json-output [{pretty,default}]]
                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --groupname GROUPNAME
                        To search all the groups matching provided groupname.
  --user_id USER_ID     Provide user_id to search all the groups of a specific user.
  --page_number PAGE_NUMBER
                        To search groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-groups example with required argument passed.

```bash
yeedu iam search-groups --groupname="Yeedu"
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 7,
      "group_name": "Yeedu",
      "group_type": null,
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 8,
      "group_name": "Yeedu",
      "group_type": "Unified",
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 9,
      "group_name": "G_Yeedu",
      "group_type": null,
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 10,
      "group_name": "Modak Yeedu",
      "group_type": "Unified",
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 11,
      "group_name": "Yeedu Dev_Team",
      "group_type": null,
      "from_date": "2023-12-28T14:01:50.367429+00:00",
      "to_date": "infinity"
    },
    {
      "group_id": 25,
      "group_name": "Yeedu_Backend",
      "group_type": null,
      "from_date": "2024-01-02T09:19:25.770823+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 6,
    "total_pages": 1,
    "limit": 100
  }
}

```

### match-group

```bash
yeedu iam match-group -h
```

```bash
usage:  match-group [-h] --groupname GROUPNAME
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --groupname GROUPNAME
                        Provide groupname to get information about matching groups.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- match-group example with required argument passed.

```bash
yeedu iam match-group --groupname="Yeedu"
```

- Console output

```bash
[
  {
    "group_id": 8,
    "group_name": "Yeedu",
    "group_type": "Unified",
    "from_date": "2023-12-28T14:01:50.367429+00:00",
    "to_date": "infinity"
  },
  {
    "group_id": 7,
    "group_name": "Yeedu",
    "group_type": null,
    "from_date": "2023-12-28T14:01:50.367429+00:00",
    "to_date": "infinity"
  }
]
```

## Lookup

| Command Name                         | Utility                                                 |
|--------------------------------------|---------------------------------------------------------|
|[list-resources](#list-resources)     | To get all the resources.                               |
|[get-resource](#get-resource)         | To get resource details for a specific Resource.        |
|[list-permissions](#list-permissions) | To get all the Permission Types.                        |
|[get-permission](#get-permission)     | To get resource details for a specific Permission Type. |
|[list-roles](#list-roles)             | To get all the Roles.                                   |
|[get-role](#get-role)                 | To get resource details for a specific Role.            |
|[list-rules](#list-rules)             | To get all the Rules.                                   |
|[get-rule](#get-rule)                 | To get resource details for a specific Rule.            |

### list-resources

```bash
yeedu iam list-resources -h
```

```bash
usage:  list-resources [-h] [--json-output [{pretty,default}]]
                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-resources example without optional argument passed for output format.

```bash
yeedu iam list-resources
```

- Console output

```bash
[
  {
    "resource_id": 0,
    "resource_path": "/api/v1/lookup_cloud_providers",
    "from_date": "2023-09-29T15:47:59.340Z",
    "to_date": null
  },
  {
    "resource_id": 1,
    "resource_path": "/api/v1/lookup_cloud_providers/:cloud_provider_id",
    "from_date": "2023-09-29T15:47:59.340Z",
    "to_date": null
  },
  ...
  {
    "resource_id": 163,
    "resource_path": "/api/v1/cluster/confs/search/:cluster_conf_name",
    "from_date": "2023-09-29T15:47:59.340Z",
    "to_date": null
  }
]
```

### get-resource

```bash
yeedu iam get-resource -h
```

```bash
usage:  get-resource [-h] --resource_id RESOURCE_ID [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --resource_id RESOURCE_ID
                        Provide the resource_id to get information about a specific
                        Resource.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-resource example with required argument '--resource_id' passed.

```bash
yeedu iam get-resource --resource_id=18
```

- Console output

```bash
{
  "resource_id": 18,
  "resource_path": "/api/v1/machine/networks",
  "from_date": "2023-09-29T15:47:59.340Z",
  "to_date": null
}
```

### list-permissions

```bash
yeedu iam list-permissions -h
```

```bash
usage:  list-permissions [-h] [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-permissions example without optional argument passed for output format.

```bash
yeedu iam list-permissions
```

- Console output

```bash
[
  {
    "permission_id": 0,
    "permission": "GET",
    "description": "To list a resource",
    "from_date": "2023-09-29T15:47:59.339Z",
    "to_date": null
  },
  ...
  {
    "permission_id": 3,
    "permission": "DELETE",
    "description": "To delete a resource",
    "from_date": "2023-09-29T15:47:59.339Z",
    "to_date": null
  }
]
```

### get-permission

```bash
yeedu iam get-permission -h
```

```bash
usage:  get-permission [-h] --permission_id PERMISSION_ID
                       [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --permission_id PERMISSION_ID
                        Provide the permission_id to get information about a specific
                        Permission Type.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-permission example with required argument '--permission_id' passed.

```bash
yeedu iam get-permission --permission_id=1
```

- Console output

```bash
{
  "permission_id": 1,
  "permission": "POST",
  "description": "To create a resource",
  "from_date": "2023-09-29T15:47:59.339Z",
  "to_date": null
}
```

### list-roles

```bash
yeedu iam list-roles -h
```

```bash
usage:  list-roles [-h] [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-roles example without any optional arguments passed.

```bash
yeedu iam list-roles
```

- Console output

```bash
[
  {
    "role_id": 0,
    "role": "User",
    "description": "GET (Lookup, Volume Config, Network Config, Boot Disk Image Config, Credentials Config, Object Storage Manager, Object Storage Manager Files, Hive Metastore Config, Cluster Configuration, Cluster Instance, Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance, User) PUT (Spark Job Config, Workspace) POST (Object Storage Manager Files, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance) DELETE (Object Storage Manager Files, Workspace, Workspace Access Control, Spark Job Config)",
    "from_date": "2023-10-18T12:28:01.369Z",
    "to_date": null
  },
  {
    "role_id": 1,
    "role": "Provider",
    "description": "GET (Lookup, Volume Config, Network Config, Boot Disk Image Config, Credentials Config, Object Storage Manager, Object Storage Manager Files, Hive Metastore Config, Cluster Configuration, Cluster Instance, Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance, User) PUT (Cluster Instance, Spark Job Config, Workspace) POST (Cluster Instance, Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance) DELETE (Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config)",
    "from_date": "2023-10-18T12:28:01.369Z",
    "to_date": null
  },
  {
    "role_id": 2,
    "role": "Admin",
    "description": "Can add and remove user and group roles and perform all actions within a tenant.",
    "from_date": "2023-10-18T12:28:01.369Z",
    "to_date": null
  },
  {
    "role_id": 3,
    "role": "Platform Admin",
    "description": "Can access and add or remove tenants across all tenants",
    "from_date": "2023-10-18T12:28:01.369Z",
    "to_date": null
  }
]
```

### get-role

```bash
yeedu iam get-role -h
```

```bash
usage:  get-role [-h] --role_id ROLE_ID [--json-output [{pretty,default}]]
                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --role_id ROLE_ID     Provide the role_id to get information about a specific Role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-role example with required argument '--role_id' passed.

```bash
yeedu iam get-role --role_id=1
```

- Console output

```bash
{
  "role_id": 1,
  "role": "Provider",
  "description": "GET (Lookup, Volume Config, Network Config, Boot Disk Image Config, Credentials Config, Object Storage Manager, Object Storage Manager Files, Hive Metastore Config, Cluster Configuration, Cluster Instance, Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance, User) PUT (Cluster Instance, Spark Job Config, Workspace) POST (Cluster Instance, Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance) DELETE (Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config)",
  "from_date": "2023-09-29T15:47:59.342Z",
  "to_date": null
}
```

### list-rules

```bash
yeedu iam list-rules -h
```

```bash
usage:  list-rules [-h] [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-rules example without any optional arguments passed.

```bash
yeedu iam list-rules
```

- Console output

```bash
[
  {
    "rule_id": "0",
    "permission_type": {
      "permission_id": 0,
      "permission": "GET",
      "description": "To list a resource"
    },
    "resource": {
      "resource_id": 0,
      "resource_path": "/api/v1/lookup_cloud_providers"
    },
    "role": {
      "role_id": 0,
      "role": "User",
      "description": "GET (Lookup, Volume Config, Network Config, Boot Disk Image Config, Credentials Config, Object Storage Manager, Object Storage Manager Files, Hive Metastore Config, Cluster Configuration, Cluster Instance, Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance, User) PUT (Spark Job Config, Workspace) POST (Object Storage Manager Files, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance) DELETE (Object Storage Manager Files, Workspace, Workspace Access Control, Spark Job Config)"
    },
    "from_date": "2023-09-29T15:47:59.350Z",
    "to_date": null
  },
  ...
  {
    "rule_id": "629",
    "permission_type": {
      "permission_id": 0,
      "permission": "GET",
      "description": "To list a resource"
    },
    "resource": {
      "resource_id": 163,
      "resource_path": "/api/v1/cluster/confs/search/:cluster_conf_name"
    },
    "role": {
      "role_id": 3,
      "role": "Platform Admin",
      "description": "Can access everything across tenants and add or remove tenants."
    },
    "from_date": "2023-09-29T15:47:59.350Z",
    "to_date": null
  }
]
```

### get-rule

```bash
yeedu iam get-rule -h
```

```bash
usage:  get-rule [-h] --rule_id RULE_ID [--json-output [{pretty,default}]]
                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --rule_id RULE_ID     Provide the rule_id to get information about a specific Rule.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-rule example with required argument '--rule_id' passed.

```bash
yeedu iam get-rule --rule_id=108
```

- Console output

```bash
{
  "rule_id": "108",
  "permission_type": {
    "permission_id": 0,
    "permission": "GET",
    "description": "To list a resource"
  },
  "resource": {
    "resource_id": 39,
    "resource_path": "/api/v1/cluster/stats"
  },
  "role": {
    "role_id": 1,
    "role": "Provider",
    "description": "GET (Lookup, Volume Config, Network Config, Boot Disk Image Config, Credentials Config, Object Storage Manager, Object Storage Manager Files, Hive Metastore Config, Cluster Configuration, Cluster Instance, Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance, User) PUT (Cluster Instance, Spark Job Config, Workspace) POST (Cluster Instance, Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config, Spark Job Instance) DELETE (Cluster Access Control, Workspace, Workspace Access Control, Spark Job Config)"
  },
  "from_date": "2023-09-29T15:47:59.350Z",
  "to_date": null
}
```

### list-workspace-permissions

```bash
yeedu iam list-workspace-permissions -h
```

```bash
usage:  list-workspace-permissions [-h] [--json-output [{pretty,default}]]
                                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-workspace-permissions example.

```bash
yeedu iam list-workspace-permissions
```

- Console output

```bash
[
  {
    "permission_id": 0,
    "name": "VIEW",
    "description": "To list the jobs inside the workspace",
    "from_date": "2024-01-17T08:22:15.874Z",
    "to_date": null
  },
  {
    "permission_id": 1,
    "name": "RUN",
    "description": "To list and run the jobs within a workspace",
    "from_date": "2024-01-17T08:22:15.874Z",
    "to_date": null
  },
  {
    "permission_id": 2,
    "name": "EDIT",
    "description": "To list, run and edit a spark job configuration in a workspace",
    "from_date": "2024-01-17T08:22:15.874Z",
    "to_date": null
  },
  {
    "permission_id": 3,
    "name": "MANAGE",
    "description": "To list jobs, run jobs, edit Spark job configurations, and manage workspace access by adding or removing permissions",
    "from_date": "2024-01-17T08:22:15.874Z",
    "to_date": null
  }
]
```

### get-workspace-permission

```bash
yeedu iam get-workspace-permission -h
```

```bash
usage:  get-workspace-permission [-h] --permission_id PERMISSION_ID
                                 [--json-output [{pretty,default}]]
                                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --permission_id PERMISSION_ID
                        Provide the permission_id to get information about a specific
                        Workspace Access Control Permission.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-workspace-permission example with required argument '--permission_id' passed.

```bash
yeedu iam get-workspace-permission --permission_id=108
```

- Console output

```bash
{
  "permission_id": 1,
  "name": "RUN",
  "description": "To list and run the jobs within a workspace",
  "from_date": "2024-01-17T08:22:15.874Z",
  "to_date": null
}
```

# Platform-Admin

## Tenant

| Command Name                     | Utility                                     |
|----------------------------------|---------------------------------------------|
|[create-tenant](#create-tenant)   | To create a Tenant.                         |
|[list-tenants](#list-tenants-1)   | To list all the available Tenants.          |
|[search-tenants](#search-tenants) | To search the tenants with the given name.  |
|[get-tenant](#get-tenant)         | To get information about a specific Tenant. |
|[edit-tenant](#edit-tenant)       | To edit a specific Tenant.                  |
|[delete-tenant](#delete-tenant)   | To delete a specific Tenant.                |

### create-tenant

```bash
yeedu platform-admin create-tenant -h
```

```bash
usage:  create-tenant [-h] --name NAME [--description DESCRIPTION]
                      [--json-output [{pretty,default}]]
                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --name NAME           Provide name to create-tenant.
  --description DESCRIPTION
                        Provide description to create-tenant.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-tenant example with all the required and optional arguments passed.

```bash
yeedu platform-admin create-tenant --name="tenant_01" --description="Yeedu Tenant-1"
```

- Console output

```bash
{
  "tenant_id": "69bf9c44-7ec8-409c-8f48-a573eb7ca29b",
  "name": "tenant1",
  "description": "Yeedu Tenant-1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-09T14:38:09.865Z",
  "from_date": "2024-01-09T14:38:09.865Z",
  "to_date": null
}
```

### list-tenants

```bash
yeedu platform-admin list-tenants -h
```

```bash
usage:  list-tenants [-h] [--page_number PAGE_NUMBER] [--limit LIMIT]
                     [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]
options:
  -h, --help            show this help message and exit
  --page_number PAGE_NUMBER
                        To list tenants for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of tenants. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-tenants example without any optional arguments passed.

```bash
yeedu platform-admin list-tenants
```

- Console output

```bash
{
  "data": [
    {
      "tenant_id": "69bf9c44-7ec8-409c-8f48-a573eb7ca29b",
      "name": "tenant_01",
      "description": "Yeedu Tenant-1",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-09T14:38:09.865497+00:00",
      "from_date": "2024-01-09T14:38:09.865497+00:00",
      "to_date": "infinity"
    },
    {
      "tenant_id": "1ea17e91-257b-4a6c-82aa-265568d31615",
      "name": "test",
      "description": null,
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2023-12-28T14:01:58.072463+00:00",
      "from_date": "2023-12-28T14:01:58.072463+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 2,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-tenants

```bash
yeedu platform-admin search-tenants -h
```

```bash
usage:  search-tenants [-h] --tenant_name TENANT_NAME
                       [--page_number PAGE_NUMBER] [--limit LIMIT]
                       [--json-output [{pretty,default}]]
                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_name TENANT_NAME
                        Provide the tenant name to get all the matching tenants.
  --page_number PAGE_NUMBER
                        To search tenants on a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of tenants. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-tenants example with required arguments passed.

```bash
yeedu platform-admin search-tenants --tenant_name="tenant"
```

- Console output

```bash
{
  "data": [
    {
      "tenant_id": "69bf9c44-7ec8-409c-8f48-a573eb7ca29b",
      "name": "tenant_01",
      "description": "Yeedu Tenant-1",
      "created_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "modified_by": {
        "user_id": 1,
        "username": "YSU0000"
      },
      "last_update_date": "2024-01-09T14:38:09.865497+00:00",
      "from_date": "2024-01-09T14:38:09.865497+00:00",
      "to_date": "infinity"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-tenant

```bash
yeedu platform-admin get-tenant -h
```

```bash
usage:  get-tenant [-h] [--tenant_id TENANT_ID]
                   [--tenant_name TENANT_NAME]
                   [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide the tenant_id to get information about a specific Tenant.
  --tenant_name TENANT_NAME
                        Provide the tenant_name to get information about a specific Tenant.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-tenant example with any one of the required argument passed.

```bash
yeedu platform-admin get-tenant --tenant_name="tenant_01"
```

- Console output

```bash
{
  "tenant_id": "69bf9c44-7ec8-409c-8f48-a573eb7ca29b",
  "name": "tenant_01",
  "description": "Yeedu Tenant-1",
  "created_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "modified_by": {
    "user_id": 1,
    "username": "YSU0000"
  },
  "last_update_date": "2024-01-09T14:38:09.865497+00:00",
  "from_date": "2024-01-09T14:38:09.865497+00:00",
  "to_date": "infinity"
}
```

### edit-tenant

```bash
yeedu platform-admin edit-tenant -h
```

```bash
usage:  edit-tenant [-h] [--tenant_id TENANT_ID]
                    [--tenant_name TENANT_NAME] [--name [NAME]]
                    [--description [DESCRIPTION]]
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide a specific tenant Id to edit-tenant.
  --tenant_name TENANT_NAME
                        Provide a specific tenant Name to edit-tenant.
  --name [NAME]         Provide name to edit-tenant.
  --description [DESCRIPTION]
                        Provide description to edit-tenant.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- edit-tenant example with any one of the required argument and other optional argument is passed which is to be updated.

```bash
yeedu platform-admin edit-tenant --tenant_id="69bf9c44-7ec8-409c-8f48-a573eb7ca29b" --description="Yeedu Tenant 1"
```

- Console output

```bash
{
  "tenant_id": "69bf9c44-7ec8-409c-8f48-a573eb7ca29b",
  "name": "tenant1",
  "description": "Yeedu Tenant 1",
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-09T14:50:29.676Z",
  "from_date": "2024-01-09T14:38:09.865Z",
  "to_date": null
}
```

### delete-tenant

```bash
yeedu platform-admin delete-tenant -h
```

```bash
usage:  delete-tenant [-h] [--tenant_id TENANT_ID]
                      [--tenant_name TENANT_NAME]
                      [--json-output [{pretty,default}]]
                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide the tenant_id to delete a specific Tenant.
  --tenant_name TENANT_NAME
                        Provide the tenant_name to delete a specific Tenant.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-tenant example with any one of the required argument passed.

```bash
yeedu platform-admin delete-tenant --tenant_id="69bf9c44-7ec8-409c-8f48-a573eb7ca29b"
```

- Console output

```bash
{
  "message": "Deleted Tenant Id: 69bf9c44-7ec8-409c-8f48-a573eb7ca29b"
}
```

## User

| Command Name                               | Utility                                                       |
|--------------------------------------------|---------------------------------------------------------------|
|[list-user-tenants](#list-user-tenants)     | To list all the tenants associated to an user.                |
|[list-tenant-users](#list-tenant-users)     | To list all the users present in a tenant.                    |
|[search-tenant-users](#search-tenant-users) | To search all the users present in a tenant.                  |
|[get-tenant-user](#get-tenant-user)         | To get information about a User present in a specific tenant. |
|[get-user-roles](#get-user-roles-1)         | To get all the roles of an User present in a specific tenant. |
|[list-users-roles](#list-users-roles)       | To list all the Users Roles in a specific tenant.             |
|[get-role-users](#get-role-users)           | To get all the users of a Role present in a specific tenant.  |
|[create-user-role](#create-user-role)       | To create an User Role for a specific tenant.                 |
|[delete-user-role](#delete-user-role)       | To delete an User Role of a specific tenant.                  |

### list-user-tenants

```bash
yeedu platform-admin list-user-tenants -h
```

```bash
usage:  list-user-tenants [-h] --user_id USER_ID
                          [--page_number PAGE_NUMBER] [--limit LIMIT]
                          [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --user_id USER_ID     Provide User Id to list all the tenants.
  --page_number PAGE_NUMBER
                        To list tenants for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of tenants. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-user-tenants example with required argument passed.

```bash
yeedu platform-admin list-user-tenants --user_id=1
```

- Console output

```bash
{
  "data": [
    {
      "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
      "name": "tenant1",
      "description": "Yeedu Tenant 1"
    },
    {
      "tenant_id": "cf1f945f-01ce-4ac6-a070-8c733f2fa791",
      "name": "tenant3",
      "description": "Yeedu Tenant 3"
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 2,
    "total_pages": 1,
    "limit": 100
  }
}
```

### list-tenant-users

```bash
yeedu platform-admin list-tenant-users -h
```

```bash
usage:  list-tenant-users [-h] --tenant_id TENANT_ID
                          [--page_number PAGE_NUMBER] [--limit LIMIT]
                          [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to list all the users present in it.
  --page_number PAGE_NUMBER
                        To list tenant users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of tenant users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-tenant-users example with required arguments passed.

```bash
yeedu platform-admin list-tenant-users --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38"
```

- Console output

```bash
{
  "data": {
    "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
    "users": [
      {
        "user_id": 1,
        "username": "YSU0000",
        "email": "YSU0000"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-tenant-users

```bash
yeedu platform-admin search-tenant-users -h
```

```bash
usage:  search-tenant-users [-h] --username USERNAME --tenant_id TENANT_ID
                            [--page_number PAGE_NUMBER] [--limit LIMIT]
                            [--json-output [{pretty,default}]]
                            [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --username USERNAME   Provide username to search all the matching users present in it.
  --tenant_id TENANT_ID
                        Provide Tenant Id to search all the users present in it.
  --page_number PAGE_NUMBER
                        To search tenant users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of tenant users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-tenant-users example with required arguments passed.

```bash
yeedu platform-admin search-tenant-users --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --username="YS"
```

- Console output

```bash
{
  "data": {
    "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
    "users": [
      {
        "user_id": 1,
        "username": "YSU0000",
        "email": "YSU0000"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-tenant-user

```bash
yeedu platform-admin get-tenant-user -h
```

```bash
usage:  get-tenant-user [-h] --tenant_id TENANT_ID --user_id USER_ID
                        [--json-output [{pretty,default}]]
                        [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to get information about a specific User.
  --user_id USER_ID     Provide User Id to get information about a specific User.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-tenant-user example with all the required arguments passed.

```bash
yeedu platform-admin get-tenant-user --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --user_id=1
```

- Console output

```bash
{
  "user_id": 1,
  "username": "USER",
  "email": "user@yeedu.com",
  "from_date": "2024-01-01T15:49:50.399852+00:00",
  "to_date": "infinity"
}
```

### get-user-roles

```bash
yeedu platform-admin get-user-roles -h
```

```bash
usage:  get-user-roles [-h] --tenant_id TENANT_ID --user_id USER_ID
                       [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to get roles of a specific User.
  --user_id USER_ID     Provide User Id to get roles of a specific User.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-user-roles example with the required arguments '--tenant_id' and '--user_id' passed.

```bash
yeedu platform-admin get-user-roles --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --user_id=1
```

- Console output

```bash
{
  "user_id": 1,
  "username": "YSU0000",
  "user_roles": [
    {
      "role_id": 3,
      "user_role": "Platform Admin"
    }
  ],
  "group_roles": [
    {
      "group_id": 8,
      "group_name": "Yeedu",
      "role_id": 2,
      "group_role": "Admin"
    }
  ]
}
```

### list-users-roles

```bash
yeedu platform-admin list-users-roles -h
```

```bash
usage:  list-users-roles [-h] --tenant_id TENANT_ID
                         [--page_number PAGE_NUMBER] [--limit LIMIT]
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to list User roles.
  --page_number PAGE_NUMBER
                        To list users roles for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of users roles. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-users-roles example with the required argument '--tenant_id' passed.

```bash
yeedu platform-admin list-users-roles --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38"
```

- Console output

```bash
{
  "data": [
    {
      "user_id": 1,
      "username": "YSU0000",
      "user_roles": [
        "Platform Admin"
      ],
      "group_roles": [
        "Admin"
      ]
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-role-users

```bash
yeedu platform-admin get-role-users -h
```

```bash
usage:  get-role-users [-h] --tenant_id TENANT_ID --role_id ROLE_ID
                       [--page_number PAGE_NUMBER] [--limit LIMIT]
                       [--json-output [{pretty,default}]]
                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to get users in a specific Role.
  --role_id ROLE_ID     Provide Role Id to get users in a specific Role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-role-users example with the required '--tenant_id' arguments passed.

```bash
yeedu platform-admin get-role-users --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --role_id=3
```

- Console output

```bash
{
  "data": {
    "role_id": 3,
    "users": [
      {
        "user_id": 1,
        "username": "YSU0000",
        "email": "YSU0000"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### create-user-role

```bash
yeedu platform-admin create-user-role -h
```

```bash
usage:  create-user-role [-h] [--tenant_id TENANT_ID] --user_id
                         USER_ID --role_id ROLE_ID
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to create-user-role.
  --user_id USER_ID     Provide User Id to create-user-role.
  --role_id ROLE_ID     Provide Role Id to create-user-role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-user-role example with all the required and optional arguments passed.

```bash
yeedu platform-admin create-user-role --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --user_id=2 --role_id=1
```

- Console output

```bash
{
  "user_roles_id": "2",
  "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
  "user_id": "2",
  "role_id": 1,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2023-10-05T12:50:27.826Z",
  "from_date": "2023-10-05T12:50:27.826Z",
  "to_date": null
}
```

### delete-user-role

```bash
yeedu platform-admin delete-user-role -h
```

```bash
usage:  delete-user-role [-h] [--tenant_id TENANT_ID] --user_id USER_ID --role_id ROLE_ID
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to delete-user-role.
  --user_id USER_ID     Provide User Id to delete-user-role.
  --role_id ROLE_ID     Provide Role Id to delete-user-role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-user-role example with the required '--tenant_id' argument passed.

```bash
yeedu platform-admin delete-user-role --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --user_id=2 --role_id=1
```

- Console output

```bash
{
  "message": "Deleted User Roles for the provided tenant_id: '6423f466-ff56-4ba4-8c2d-8229beb67e38', user_id: 2 and role_id: 1."
}
```

## Group

| Command Name                                 | Utility                                                                    |
|----------------------------------------------|----------------------------------------------------------------------------|
|[list-tenant-groups](#list-tenant-groups)     | To list all the groups present in a tenant.                                |
|[search-tenant-groups](#search-tenant-groups) | To search all the groups present in a tenant.                              |
|[get-tenant-group](#get-tenant-group)         | To get information about a Group present in a specific tenant.             |
|[get-group-roles](#get-group-roles)           | To get all the roles of a Group present in a specific tenant.              |
|[list-groups-roles](#list-groups-roles)       | To list all the Groups Roles in a specific tenant.                         |
|[get-role-groups](#get-role-groups)           | To get all the groups having a specific Role present in a specific tenant. |
|[create-group-role](#create-group-role)       | To create a Group Role for a specific tenant.                              |
|[delete-group-role](#delete-group-role)       | To delete a Group Role of a specific tenant.                               |

### list-tenant-groups

```bash
yeedu platform-admin list-tenant-groups -h
```

```bash
usage:  list-tenant-groups [-h] --tenant_id TENANT_ID
                           [--page_number PAGE_NUMBER] [--limit LIMIT]
                           [--json-output [{pretty,default}]]
                           [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to list all the groups present in it.
  --page_number PAGE_NUMBER
                        To list tenant groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of tenant groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-tenant-groups example with required and optional arguments passed.

```bash
yeedu platform-admin list-tenant-groups --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38"
```

- Console output

```bash
{
  "data": {
    "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
    "groups": [
      {
        "group_id": 8,
        "group_name": "Yeedu",
        "group_type": "Unified"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-tenant-groups

```bash
yeedu platform-admin search-tenant-groups -h
```

```bash
usage:  search-tenant-groups [-h] --groupname GROUPNAME --tenant_id TENANT_ID
                             [--page_number PAGE_NUMBER] [--limit LIMIT]
                             [--json-output [{pretty,default}]]
                             [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --groupname GROUPNAME
                        Provide groupname to search all the matching groups present in
                        it.
  --tenant_id TENANT_ID
                        Provide Tenant Id to search all the groups present in it.
  --page_number PAGE_NUMBER
                        To search tenant groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of tenant groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-tenant-groups example with required and optional arguments passed.

```bash
yeedu platform-admin search-tenant-groups --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --groupname="Yeed"
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 8,
      "group_name": "Yeedu",
      "group_type": "Unified",
      "roles": [
        "Admin"
      ]
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-tenant-group

```bash
yeedu platform-admin get-tenant-group -h
```

```bash
usage:  get-tenant-group [-h] --tenant_id TENANT_ID --group_id GROUP_ID
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID Provide Tenant Id to get information about a specific Group.
  --group_id GROUP_ID   Provide Group Id to get information about a specific Group.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-tenant-group example with required arguments passed.

```bash
yeedu platform-admin get-tenant-group --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --group_id=1
```

- Console output

```bash
{
  "group_id": 1,
  "group_name": "yeedu-manager",
  "from_date": "2024-01-01T15:49:50.399852+00:00",
  "to_date": "infinity"
}
```

### get-group-roles

```bash
yeedu platform-admin get-group-roles -h
```

```bash
usage:  get-group-roles [-h] --tenant_id TENANT_ID --group_id GROUP_ID
                        [--json-output [{pretty,default}]] [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to get roles of a specific Group.
  --group_id GROUP_ID   Provide Group Id to get roles of a specific Group.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-group-roles example with the required '--tenant_id' and '--group_id' arguments passed.

```bash
yeedu platform-admin get-group-roles --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --group_id=1
```

- Console output

```bash
{
  "group_id": 1,
  "group_name": "Yeedu",
  "group_type": "Unified",
  "roles": [
    "Admin"
  ]
}
```

### list-groups-roles

```bash
yeedu platform-admin list-groups-roles -h
```

```bash
usage:  list-groups-roles [-h] --tenant_id TENANT_ID
                          [--page_number PAGE_NUMBER] [--limit LIMIT]
                          [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to list Group roles.
  --page_number PAGE_NUMBER
                        To list groups roles for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of groups roles. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-groups-roles example with the required arguments '--tenant_id' passed.

```bash
yeedu platform-admin list-groups-roles --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --limit=2
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 1,
      "group_name": "yeedu-manager",
      "group_type": "Unified",
      "roles": [
        "Provider"
      ]
    },
    {
      "group_id": 3,
      "group_name": "yeedu-user",
      "group_type": "Unified",
      "roles": [
        "User"
      ]
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 2,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-role-groups

```bash
yeedu platform-admin get-role-groups -h
```

```bash
usage:  get-role-groups [-h] --tenant_id TENANT_ID --role_id ROLE_ID
                        [--page_number PAGE_NUMBER] [--limit LIMIT]
                        [--json-output [{pretty,default}]]
                        [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to get groups in a specific Role.
  --role_id ROLE_ID     Provide Role Id to get groups in a specific Role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-role-groups example with the required arguments '--tenant_id' and '--role_id' passed.

```bash
yeedu platform-admin get-role-groups --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --role_id=2
```

- Console output

```bash
{
  "data": {
    "role_id": 2,
    "groups": [
      {
        "group_id": 2,
        "group_name": "Yeedu",
        "group_type": "Unified"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### create-group-role

```bash
yeedu platform-admin create-group-role -h
```

```bash
usage:  create-group-role [-h] [--tenant_id TENANT_ID] --group_id GROUP_ID --role_id
                          ROLE_ID [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to create-group-role.
  --group_id GROUP_ID   Provide Group Id to create-group-role.
  --role_id ROLE_ID     Provide Role Id to create-group-role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-group-role example with all the required and optional arguments passed.

```bash
yeedu platform-admin create-group-role --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --group_id=1 --role_id=0
```

- Console output

```bash
{
  "group_roles_id": "1",
  "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
  "group_id": "1",
  "role_id": 0,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-01T13:10:15.840Z",
  "from_date": "2023-01-01T13:10:15.840Z",
  "to_date": null
}
```

### delete-group-role

```bash
yeedu platform-admin delete-group-role -h
```

```bash
usage:  delete-group-role [-h] [--tenant_id TENANT_ID] --group_id GROUP_ID --role_id
                          ROLE_ID [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --tenant_id TENANT_ID
                        Provide Tenant Id to delete-group-role.
  --group_id GROUP_ID   Provide Group Id to delete-group-role.
  --role_id ROLE_ID     Provide Role Id to delete-group-role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-group-role example with all the required argument passed.

```bash
yeedu platform-admin delete-group-role --tenant_id="6423f466-ff56-4ba4-8c2d-8229beb67e38" --group_id=1 --role_id=0
```

- Console output

```bash
{
  "message": "Deleted Group Role for the provided Tenant Id: '6423f466-ff56-4ba4-8c2d-8229beb67e38', Group Id: 1, and Role Id: 0"
}
```

# Admin

## User

| Command Name                           | Utility                                    |
|----------------------------------------|--------------------------------------------|
|[list-users](#list-users-3)             | To list all the users present in tenant.   |
|[search-users](#search-users-2)         | To search all the users present in tenant. |
|[get-user](#get-user)                   | To get information about a specific User.  |
|[get-user-roles](#get-user-roles-2)     | To get all the roles of a specific User.   |
|[list-users-roles](#list-users-roles-1) | To list all the Users Roles.               |
|[get-role-users](#get-role-users-1)     | To get all the users in a specific Role.   |
|[create-user-role](#create-user-role-1) | To create an User Role.                    |
|[delete-user-role](#delete-user-role-1) | To delete an User Role.                    |

### list-users

```bash
yeedu admin list-users -h
```

```bash
usage:  list-users [-h] [--page_number PAGE_NUMBER] [--limit LIMIT]
                   [--json-output [{pretty,default}]]
                   [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --page_number PAGE_NUMBER
                        To list users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-users example with optional arguments passed.

```bash
yeedu admin list-users --limit=2
```

- Console output

```bash
{
  "data": {
    "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
    "users": [
      {
        "user_id": 1,
        "username": "YSU0000",
        "email": "YSU0000"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-users

```bash
yeedu admin search-users -h
```

```bash
usage:  search-users [-h] --username USERNAME
                     [--page_number PAGE_NUMBER] [--limit LIMIT]
                     [--json-output [{pretty,default}]]
                     [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --username USERNAME   Provide username to search matching users.
  --page_number PAGE_NUMBER
                        To search users for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of users. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-users example with required and optional arguments passed.

```bash
yeedu admin search-users --username="YS"
```

- Console output

```bash
{
  "data": {
    "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
    "users": [
      {
        "user_id": 1,
        "username": "YSU0000",
        "email": "YSU0000"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-user

```bash
yeedu admin get-user -h
```

```bash
usage:  get-user [-h] --user_id USER_ID
                 [--json-output [{pretty,default}]]
                 [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --user_id USER_ID     Provide User Id to get information about a specific User.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-user example with required argument passed.

```bash
yeedu admin get-user --user_id=1
```

- Console output

```bash
{
  "user_id": 1,
  "username": "YSU0000",
  "email": "ysu0000@yeedu.com",
  "from_date": "2024-01-01T15:49:50.399852+00:00",
  "to_date": "infinity"
}
```

### get-user-roles

```bash
yeedu admin get-user-roles -h
```

```bash
usage:  get-user-roles [-h] --user_id USER_ID
                       [--json-output [{pretty,default}]]
                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --user_id USER_ID     Provide User Id to get roles of a specific User.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-user-roles example with the required arguments '--user_id' passed.

```bash
yeedu admin get-user-roles --user_id=1
```

- Console output

```bash
{
  "user_id": 1,
  "username": "YSU0000",
  "user_roles": [
    {
      "role_id": 3,
      "user_role": "Platform Admin"
    }
  ],
  "group_roles": [
    {
      "group_id": 8,
      "group_name": "Yeedu",
      "role_id": 2,
      "group_role": "Admin"
    }
  ]
}
```

### list-users-roles

```bash
yeedu admin list-users-roles -h
```

```bash
usage:  list-users-roles [-h] [--page_number PAGE_NUMBER]
                         [--limit LIMIT]
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --page_number PAGE_NUMBER
                        To list users roles for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of users roles. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-users-roles example with optional arguments passed.

```bash
yeedu admin list-users-roles
```

- Console output

```bash
{
  "data": [
    {
      "user_id": 1,
      "username": "YSU0000",
      "user_roles": [
        "Platform Admin"
      ],
      "group_roles": [
        "Admin"
      ]
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-role-users

```bash
yeedu admin get-role-users -h
```

```bash
usage:  get-role-users [-h] --role_id ROLE_ID
                       [--page_number PAGE_NUMBER] [--limit LIMIT]
                       [--json-output [{pretty,default}]]
                       [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --role_id ROLE_ID     Provide Role Id to get users in a specific Role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-role-users example with the required '--role_id' arguments passed.

```bash
yeedu admin get-role-users --role_id=3
```

- Console output

```bash
{
  "data": {
    "role_id": 3,
    "users": [
      {
        "user_id": 1,
        "username": "YSU0000",
        "email": "YSU0000"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### create-user-role

```bash
yeedu admin create-user-role -h
```

```bash
usage:  create-user-role [-h] --user_id USER_ID --role_id ROLE_ID
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --user_id USER_ID     Provide User Id to create-user-role.
  --role_id ROLE_ID     Provide Role Id to create-user-role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-user-role example with all the required and optional arguments passed.

```bash
yeedu admin create-user-role --user_id=2 --role_id=1
```

- Console output

```bash
{
  "user_roles_id": "2",
  "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
  "user_id": "2",
  "role_id": 1,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-01T12:50:27.826Z",
  "from_date": "2024-01-01T12:50:27.826Z",
  "to_date": null
}
```

### delete-user-role

```bash
yeedu admin delete-user-role -h
```

```bash
usage:  delete-user-role [-h] --user_id USER_ID --role_id ROLE_ID
                         [--json-output [{pretty,default}]]
                         [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --user_id USER_ID     Provide User Id to delete-user-role.
  --role_id ROLE_ID     Provide Role Id to delete-user-role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-user-role example with all the required argument passed.

```bash
yeedu admin delete-user-role --user_id=2 --role_id=1
```

- Console output

```bash
{
  "message": "Deleted User Roles for the provided User Id: 2 and Role Id: 1."
}
```

## Group

| Command Name                             | Utility                                     |
|------------------------------------------|---------------------------------------------|
|[list-groups](#list-groups-2)             | To list all the groups present in tenant.   |
|[search-groups](#search-groups-2)         | To search all the groups present in tenant. |
|[get-group](#get-group)                   | To get information about a specific Group.  |
|[get-group-roles](#get-group-roles-1)     | To get all the roles of a specific Group.   |
|[list-groups-roles](#list-groups-roles-1) | To list all the Groups Roles.               |
|[get-role-groups](#get-role-groups-1)     | To get all the groups in a specific Role.   |
|[create-group-role](#create-group-role-1) | To create a Group Role.                     |
|[delete-group-role](#delete-group-role-1) | To delete a group Role.                     |

### list-groups

```bash
yeedu admin list-groups -h
```

```bash
usage:  list-groups [-h] [--page_number PAGE_NUMBER] [--limit LIMIT]
                    [--json-output [{pretty,default}]]
                    [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --page_number PAGE_NUMBER
                        To list groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-groups example with optional argument passed.

```bash
yeedu admin list-groups
```

- Console output

```bash
{
  "data": {
    "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
    "groups": [
      {
        "group_id": 8,
        "group_name": "Yeedu",
        "group_type": "Unified"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### search-groups

```bash
yeedu admin search-groups -h
```

```bash
usage:  search-groups [-h] --groupname GROUPNAME
                      [--page_number PAGE_NUMBER] [--limit LIMIT]
                      [--json-output [{pretty,default}]]
                      [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --groupname GROUPNAME
                        Provide groupname to search matching groups.
  --page_number PAGE_NUMBER
                        To search groups for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to search number of groups. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- search-groups example with required and optional arguments passed.

```bash
yeedu admin search-groups --groupname="Yeed"
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 8,
      "group_name": "Yeedu",
      "group_type": "Unified",
      "roles": [
        "Admin"
      ]
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-group

```bash
yeedu admin get-group -h
```

```bash
usage:  get-group [-h] --group_id GROUP_ID
                  [--json-output [{pretty,default}]]
                  [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --group_id GROUP_ID   Provide Group Id to get information about a specific Group.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-group example with the required argument '--group_id' passed.

```bash
yeedu admin get-group --group_id=1
```

- Console output

```bash
{
  "group_id": 1,
  "group_name": "yeedu-manager",
  "from_date": "2024-01-01T15:49:50.399852+00:00",
  "to_date": "infinity"
}
```

### get-group-roles

```bash
yeedu admin get-group-roles -h
```

```bash
usage:  get-group-roles [-h] --group_id GROUP_ID
                        [--json-output [{pretty,default}]]
                        [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --group_id GROUP_ID   Provide Group Id to get roles of a specific Group.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-group-roles example with the required argument '--group_id' passed.

```bash
yeedu admin get-group-roles --group_id=1
```

- Console output

```bash
{
  "group_id": 1,
  "group_name": "Yeedu",
  "group_type": "Unified",
  "roles": [
    "Admin"
  ]
}
```

### list-groups-roles

```bash
yeedu admin list-groups-roles -h
```

```bash
usage:  list-groups-roles [-h] [--page_number PAGE_NUMBER] [--limit LIMIT]
                          [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --page_number PAGE_NUMBER
                        To list groups roles for a specific page_number. (default: 1)
  --limit LIMIT         Provide limit to list number of groups roles. (default: 100)
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- list-groups-roles example without any optional arguments passed.

```bash
yeedu admin list-groups-roles
```

- Console output

```bash
{
  "data": [
    {
      "group_id": 1,
      "group_name": "yeedu-manager",
      "group_type": "Unified",
      "roles": [
        "Provider"
      ]
    },
    {
      "group_id": 3,
      "group_name": "yeedu-user",
      "group_type": "Unified",
      "roles": [
        "User"
      ]
    }
  ],
  "result_set": {
    "current_page": 1,
    "total_objects": 2,
    "total_pages": 1,
    "limit": 100
  }
}
```

### get-role-groups

```bash
yeedu admin get-role-groups -h
```

```bash
usage:  get-role-groups [-h] --role_id ROLE_ID [--json-output [{pretty,default}]]
                        [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --role_id ROLE_ID     Provide Role Id to get groups in a specific Role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- get-role-groups example with the required argument '--role_id' passed.

```bash
yeedu admin get-role-groups --role_id=2
```

- Console output

```bash
{
  "data": {
    "role_id": 2,
    "groups": [
      {
        "group_id": 2,
        "group_name": "Yeedu",
        "group_type": "Unified"
      }
    ]
  },
  "result_set": {
    "current_page": 1,
    "total_objects": 1,
    "total_pages": 1,
    "limit": 100
  }
}
```

### create-group-role

```bash
yeedu admin create-group-role -h
```

```bash
usage:  create-group-role [-h] --group_id GROUP_ID --role_id ROLE_ID
                          [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --group_id GROUP_ID   Provide Group Id to create-group-role.
  --role_id ROLE_ID     Provide Role Id to create-group-role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- create-group-role example with all the required arguments passed.

```bash
yeedu admin create-group-role --group_id=1 --role_id=0
```

- Console output

```bash
{
  "group_roles_id": "1",
  "tenant_id": "6423f466-ff56-4ba4-8c2d-8229beb67e38",
  "group_id": "1",
  "role_id": 0,
  "created_by_id": "1",
  "modified_by_id": "1",
  "last_update_date": "2024-01-01T13:10:15.840Z",
  "from_date": "2024-01-01T13:10:15.840Z",
  "to_date": null
}
```

### delete-group-role

```bash
yeedu admin delete-group-role -h
```

```bash
usage:  delete-group-role [-h] --group_id GROUP_ID --role_id ROLE_ID
                          [--json-output [{pretty,default}]]
                          [--yaml-output [{true,false}]]

options:
  -h, --help            show this help message and exit
  --group_id GROUP_ID   Provide Group Id to delete-group-role.
  --role_id ROLE_ID     Provide Role Id to delete-group-role.
  --json-output [{pretty,default}]
                        Provide the format of JSON output. (default: pretty)
  --yaml-output [{true,false}]
                        Provide true to get output in YAML format. (default: false)
```

- delete-group-role example with all the required argument passed.

```bash
yeedu admin delete-group-role --group_id=1 --role_id=0
```

- Console output

```bash
{
  "message": "Deleted Group Role for the provided Group Id: 1 and Role Id: 0"
}
```
